//////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2010, 2024 Contributors to the Eclipse Foundation
//
// See the NOTICE file(s) distributed with this work for additional
// information regarding copyright ownership.
//
// This program and the accompanying materials are made available
// under the terms of the MIT License which is available at
// https://opensource.org/licenses/MIT
//
// SPDX-License-Identifier: MIT
//////////////////////////////////////////////////////////////////////////////

// Disable Eclipse Java formatter for generated code file:
// @formatter:off

package org.eclipse.escet.tooldef.parser;

import static org.eclipse.escet.common.java.Strings.fmt;

import java.io.IOException;
import java.util.List;

import org.eclipse.escet.setext.runtime.Parser;
import org.eclipse.escet.setext.runtime.ParserHooksBase;
import org.eclipse.escet.setext.runtime.Token;
import org.eclipse.escet.tooldef.metamodel.tooldef.Declaration;
import org.eclipse.escet.tooldef.metamodel.tooldef.Script;
import org.eclipse.escet.tooldef.metamodel.tooldef.ToolParameter;
import org.eclipse.escet.tooldef.metamodel.tooldef.TypeDecl;
import org.eclipse.escet.tooldef.metamodel.tooldef.TypeParam;
import org.eclipse.escet.tooldef.metamodel.tooldef.expressions.Expression;
import org.eclipse.escet.tooldef.metamodel.tooldef.expressions.MapEntry;
import org.eclipse.escet.tooldef.metamodel.tooldef.expressions.ToolArgument;
import org.eclipse.escet.tooldef.metamodel.tooldef.expressions.ToolInvokeExpression;
import org.eclipse.escet.tooldef.metamodel.tooldef.expressions.ToolRef;
import org.eclipse.escet.tooldef.metamodel.tooldef.statements.AddressableDecl;
import org.eclipse.escet.tooldef.metamodel.tooldef.statements.ElifStatement;
import org.eclipse.escet.tooldef.metamodel.tooldef.statements.Statement;
import org.eclipse.escet.tooldef.metamodel.tooldef.types.ToolDefType;

/**
 * ToolDefParser.
 *
 * <p>This parser is generated by SeText for main symbol
 * "Script".</p>
 */
@SuppressWarnings("unchecked")
public final class ToolDefParser extends Parser<Script> {
    /** The names of the non-terminals, ordered by their unique ids. */
    private static final String[] NON_TERMINAL_NAMES = {
        "BuiltInIoTool",
        "BuiltInGenericTool",
        "BuiltInPathTool",
        "BuiltInFileTool",
        "BuiltInDataTool",
        "Script",
        "Decls",
        "Decl",
        "Import",
        "ImportParts",
        "TypeDecls",
        "TypeDecl",
        "OptTypeParams",
        "ToolParameters",
        "ToolParams",
        "ToolParam",
        "OptStatements",
        "Statement",
        "VarDecls",
        "VarDecl",
        "OptElifStatements",
        "OptElseStatement",
        "AddressableDecls",
        "AddressableDecl",
        "Addressables",
        "Addressable",
        "Projections",
        "Projection",
        "Types",
        "Type",
        "Expressions",
        "OptExpression",
        "Expression",
        "AndExpression",
        "CompareExpression",
        "AddExpression",
        "MulExpression",
        "UnaryExpression",
        "ProjExpression",
        "ExpressionFactor",
        "MapEntries",
        "ToolInvokeExpression",
        "ToolRef",
        "BuiltInTool",
        "ToolArgs",
        "Names",
        "Name",
        "OptComma",
    };

    /**
     * The entry symbol names for each of the parser states, and {@code null}
     * for the initial state.
     */
    private static final String[] ENTRY_SYMBOL_NAMES = new String[] {
        null,
        "BOOLKW",
        "BREAKKW",
        "CONTINUEKW",
        "DOUBLEKW",
        "EXITKW",
        "FORKW",
        "FROMKW",
        "IFKW",
        "IMPORTKW",
        "INTKW",
        "LISTKW",
        "LONGKW",
        "MAPKW",
        "OBJECTKW",
        "RETURNKW",
        "SETKW",
        "STRINGKW",
        "TOOLKW",
        "TUPLEKW",
        "TYPEKW",
        "WHILEKW",
        "ERRKW",
        "ERRLNKW",
        "OUTKW",
        "OUTLNKW",
        "APPKW",
        "EXECKW",
        "TOOLDEFKW",
        "ABSPATHKW",
        "BASENAMEKW",
        "CHDIRKW",
        "CHFILEEXTKW",
        "CURDIRKW",
        "DIRNAMEKW",
        "FILEEXTKW",
        "HASFILEEXTKW",
        "PATHJOINKW",
        "SCRIPTPATHKW",
        "CPDIRKW",
        "CPFILEKW",
        "DIFFKW",
        "EXISTSKW",
        "FILENEWERKW",
        "FILESIZEKW",
        "FINDKW",
        "ISDIRKW",
        "ISFILEKW",
        "MKDIRKW",
        "MVDIRKW",
        "MVFILEKW",
        "READLINESKW",
        "RMDIRKW",
        "RMFILEKW",
        "WRITEFILEKW",
        "ABSKW",
        "CEILKW",
        "CONTAINSKW",
        "DELKW",
        "DELIDXKW",
        "EMPTYKW",
        "ENDSWITHKW",
        "ENTRIESKW",
        "ENUMERATEKW",
        "FLOORKW",
        "FMTKW",
        "INDEXOFKW",
        "JOINKW",
        "KEYSKW",
        "LASTINDEXOFKW",
        "LNKW",
        "LOGKW",
        "LOWERKW",
        "LTRIMKW",
        "MAXKW",
        "MINKW",
        "POWKW",
        "RANGEKW",
        "REPLACEKW",
        "REVERSEKW",
        "ROUNDKW",
        "RTRIMKW",
        "SIZEKW",
        "SORTEDKW",
        "SPLITKW",
        "SQRTKW",
        "STARTSWITHKW",
        "STRKW",
        "STRDUPKW",
        "SUBSETKW",
        "TRIMKW",
        "UPPERKW",
        "VALUESKW",
        "PAROPENTK",
        "IDENTIFIERTK",
        "RELATIVENAMETK",
        "Addressable",
        "Addressables",
        "BuiltInDataTool",
        "BuiltInFileTool",
        "BuiltInGenericTool",
        "BuiltInIoTool",
        "BuiltInPathTool",
        "BuiltInTool",
        "Decl",
        "Decls",
        "Import",
        "Name",
        "Script",
        "Statement",
        "ToolInvokeExpression",
        "ToolRef",
        "Type",
        "IDENTIFIERTK",
        "VarDecl",
        "VarDecls",
        "COMMATK",
        "SEMICOLTK",
        "VarDecl",
        "EQTK",
        "FALSEKW",
        "NULLKW",
        "TRUEKW",
        "NOTKW",
        "CUROPENTK",
        "LTTK",
        "MINUSTK",
        "PAROPENTK",
        "PLUSTK",
        "SQOPENTK",
        "IDENTIFIERTK",
        "NUMBERTK",
        "DOUBLETK",
        "STRINGTK",
        "AddExpression",
        "AndExpression",
        "CompareExpression",
        "Expression",
        "ExpressionFactor",
        "MulExpression",
        "Name",
        "ProjExpression",
        "ToolInvokeExpression",
        "UnaryExpression",
        "SQOPENTK",
        "Expression",
        "OptExpression",
        "COLONTK",
        "Expression",
        "OptExpression",
        "SQCLOSETK",
        "ORKW",
        "AndExpression",
        "ANDKW",
        "CompareExpression",
        "EQEQTK",
        "GETK",
        "GTTK",
        "LETK",
        "LTTK",
        "NETK",
        "AddExpression",
        "MINUSTK",
        "PLUSTK",
        "MulExpression",
        "DIVKW",
        "MODKW",
        "ASTERISKTK",
        "SLASHTK",
        "UnaryExpression",
        "UnaryExpression",
        "UnaryExpression",
        "UnaryExpression",
        "MulExpression",
        "AddExpression",
        "AddExpression",
        "AddExpression",
        "AddExpression",
        "AddExpression",
        "SQCLOSETK",
        "SQCLOSETK",
        "Expression",
        "Expressions",
        "COMMATK",
        "OptComma",
        "SQCLOSETK",
        "Expression",
        "UnaryExpression",
        "Expression",
        "COMMATK",
        "PARCLOSETK",
        "Expressions",
        "OptComma",
        "PARCLOSETK",
        "UnaryExpression",
        "Name",
        "Type",
        "GTTK",
        "ExpressionFactor",
        "CURCLOSETK",
        "Expression",
        "Expressions",
        "MapEntries",
        "COMMATK",
        "OptComma",
        "CURCLOSETK",
        "Expression",
        "COLONTK",
        "Expression",
        "OptComma",
        "CURCLOSETK",
        "COLONTK",
        "Expression",
        "UnaryExpression",
        "PAROPENTK",
        "PARCLOSETK",
        "IDENTIFIERTK",
        "Expression",
        "ToolArgs",
        "COMMATK",
        "OptComma",
        "PARCLOSETK",
        "IDENTIFIERTK",
        "Expression",
        "EQTK",
        "Expression",
        "EQTK",
        "Expression",
        "SEMICOLTK",
        "Decl",
        "COMMATK",
        "EQTK",
        "Expressions",
        "COMMATK",
        "SEMICOLTK",
        "IDENTIFIERTK",
        "Addressable",
        "SQOPENTK",
        "Projection",
        "Projections",
        "Projection",
        "Expression",
        "SQCLOSETK",
        "Addressable",
        "COMMATK",
        "Addressables",
        "PARCLOSETK",
        "Expression",
        "COLONCOLONTK",
        "COLONTK",
        "OptStatements",
        "ENDKW",
        "Statement",
        "Statement",
        "IDENTIFIERTK",
        "TypeDecl",
        "TypeDecls",
        "COMMATK",
        "SEMICOLTK",
        "TypeDecl",
        "EQTK",
        "Type",
        "PAROPENTK",
        "QUESTIONTK",
        "PAROPENTK",
        "Type",
        "COMMATK",
        "Type",
        "Types",
        "COMMATK",
        "PARCLOSETK",
        "Type",
        "Type",
        "COMMATK",
        "Types",
        "PARCLOSETK",
        "IDENTIFIERTK",
        "Types",
        "IDENTIFIERTK",
        "LTTK",
        "OptTypeParams",
        "PAROPENTK",
        "ToolParameters",
        "COLONTK",
        "OptStatements",
        "ENDKW",
        "PARCLOSETK",
        "ToolParams",
        "Type",
        "DOTSTK",
        "IDENTIFIERTK",
        "ToolParam",
        "EQTK",
        "Expression",
        "ToolParam",
        "COMMATK",
        "PARCLOSETK",
        "Type",
        "DOTSTK",
        "ToolParam",
        "ToolParam",
        "Name",
        "Names",
        "COMMATK",
        "GTTK",
        "Name",
        "OptTypeParams",
        "ToolParameters",
        "COLONTK",
        "OptStatements",
        "ENDKW",
        "QUESTIONTK",
        "QUESTIONTK",
        "Type",
        "Type",
        "SEMICOLTK",
        "Expressions",
        "SEMICOLTK",
        "QUESTIONTK",
        "PAROPENTK",
        "QUESTIONTK",
        "PAROPENTK",
        "Type",
        "COLONTK",
        "Type",
        "PARCLOSETK",
        "Type",
        "COLONTK",
        "Type",
        "PARCLOSETK",
        "QUESTIONTK",
        "QUESTIONTK",
        "Type",
        "Type",
        "QUESTIONTK",
        "STRINGTK",
        "Name",
        "ASKW",
        "COLONTK",
        "SEMICOLTK",
        "Name",
        "ASKW",
        "SEMICOLTK",
        "IDENTIFIERTK",
        "SEMICOLTK",
        "IDENTIFIERTK",
        "SEMICOLTK",
        "ASKW",
        "SEMICOLTK",
        "IDENTIFIERTK",
        "SEMICOLTK",
        "Expression",
        "COLONCOLONTK",
        "COLONTK",
        "OptStatements",
        "OptElifStatements",
        "ELIFKW",
        "ELSEKW",
        "OptElseStatement",
        "ENDKW",
        "OptStatements",
        "Expression",
        "COLONTK",
        "OptStatements",
        "Statement",
        "STRINGTK",
        "IMPORTKW",
        "ASTERISKTK",
        "IDENTIFIERTK",
        "ImportParts",
        "COMMATK",
        "SEMICOLTK",
        "ASTERISKTK",
        "IDENTIFIERTK",
        "ASKW",
        "IDENTIFIERTK",
        "ASKW",
        "IDENTIFIERTK",
        "PAROPENTK",
        "IDENTIFIERTK",
        "AddressableDecl",
        "AddressableDecls",
        "INKW",
        "COMMATK",
        "AddressableDecl",
        "Expression",
        "COLONCOLONTK",
        "COLONTK",
        "OptStatements",
        "ENDKW",
        "Statement",
        "AddressableDecl",
        "COMMATK",
        "AddressableDecls",
        "PARCLOSETK",
        "SEMICOLTK",
        "Expression",
        "SEMICOLTK",
        "QUESTIONTK",
        "SEMICOLTK",
        "SEMICOLTK",
        "QUESTIONTK",
    };

    /** Parser call back hook methods. */
    private final ToolDefHooks hooks;

    /** Whether parsing has completed (final result has been accepted). */
    private boolean accept;

    /** The parse result, but only if {@code #accept} is {@code true}. */
    private Script acceptObject;

    /** The current scanner token to process, if any. */
    private Token token;

    /** Whether parsing has resulted in a reduce action. */
    private boolean reduce;

    /** The state from which to reduce, if {@code #reduce} is {@code true}. */
    private int reduceState;

    /** The non-terminal to reduce, if {@code #reduce} is {@code true}. */
    private int reduceNonTerminal;

    /** Constructor for the {@link ToolDefParser} class. */
    public ToolDefParser() {
        super(new ToolDefScanner());
        entrySymbolNames = ENTRY_SYMBOL_NAMES;
        firstTerminals = FirstTerminals.FIRST_TERMINALS;
        firstTerminalsReduced = FirstTerminalsReduced.FIRST_TERMINALS_REDUCED;
        reducibleNonTerminals = ReducibleNonTerminals.REDUCIBLE_NON_TERMINALS;
        reducibleNonTerminalsReduced = ReducibleNonTerminalsReduced.REDUCIBLE_NON_TERMINALS_REDUCED;
        hooks = ((ToolDefScanner)scanner).hooks;
    }

    @Override
    public ParserHooksBase getHooks() {
        return hooks;
    }

    @Override
    protected final Script parse() throws IOException {
        token = nextToken();
        int state;

        accept = false;

        while (true) {
            // Perform action.
            state = getCurrentState();
            reduce = false;

            switch (state) {
                case 0:
                    action0();
                    break;
                case 1:
                    action1();
                    break;
                case 2:
                    action2();
                    break;
                case 3:
                    action3();
                    break;
                case 4:
                    action4();
                    break;
                case 5:
                    action5();
                    break;
                case 6:
                    action6();
                    break;
                case 7:
                    action7();
                    break;
                case 8:
                    action8();
                    break;
                case 9:
                    action9();
                    break;
                case 10:
                    action10();
                    break;
                case 11:
                    action11();
                    break;
                case 12:
                    action12();
                    break;
                case 13:
                    action13();
                    break;
                case 14:
                    action14();
                    break;
                case 15:
                    action15();
                    break;
                case 16:
                    action16();
                    break;
                case 17:
                    action17();
                    break;
                case 18:
                    action18();
                    break;
                case 19:
                    action19();
                    break;
                case 20:
                    action20();
                    break;
                case 21:
                    action21();
                    break;
                case 22:
                    action22();
                    break;
                case 23:
                    action23();
                    break;
                case 24:
                    action24();
                    break;
                case 25:
                    action25();
                    break;
                case 26:
                    action26();
                    break;
                case 27:
                    action27();
                    break;
                case 28:
                    action28();
                    break;
                case 29:
                    action29();
                    break;
                case 30:
                    action30();
                    break;
                case 31:
                    action31();
                    break;
                case 32:
                    action32();
                    break;
                case 33:
                    action33();
                    break;
                case 34:
                    action34();
                    break;
                case 35:
                    action35();
                    break;
                case 36:
                    action36();
                    break;
                case 37:
                    action37();
                    break;
                case 38:
                    action38();
                    break;
                case 39:
                    action39();
                    break;
                case 40:
                    action40();
                    break;
                case 41:
                    action41();
                    break;
                case 42:
                    action42();
                    break;
                case 43:
                    action43();
                    break;
                case 44:
                    action44();
                    break;
                case 45:
                    action45();
                    break;
                case 46:
                    action46();
                    break;
                case 47:
                    action47();
                    break;
                case 48:
                    action48();
                    break;
                case 49:
                    action49();
                    break;
                case 50:
                    action50();
                    break;
                case 51:
                    action51();
                    break;
                case 52:
                    action52();
                    break;
                case 53:
                    action53();
                    break;
                case 54:
                    action54();
                    break;
                case 55:
                    action55();
                    break;
                case 56:
                    action56();
                    break;
                case 57:
                    action57();
                    break;
                case 58:
                    action58();
                    break;
                case 59:
                    action59();
                    break;
                case 60:
                    action60();
                    break;
                case 61:
                    action61();
                    break;
                case 62:
                    action62();
                    break;
                case 63:
                    action63();
                    break;
                case 64:
                    action64();
                    break;
                case 65:
                    action65();
                    break;
                case 66:
                    action66();
                    break;
                case 67:
                    action67();
                    break;
                case 68:
                    action68();
                    break;
                case 69:
                    action69();
                    break;
                case 70:
                    action70();
                    break;
                case 71:
                    action71();
                    break;
                case 72:
                    action72();
                    break;
                case 73:
                    action73();
                    break;
                case 74:
                    action74();
                    break;
                case 75:
                    action75();
                    break;
                case 76:
                    action76();
                    break;
                case 77:
                    action77();
                    break;
                case 78:
                    action78();
                    break;
                case 79:
                    action79();
                    break;
                case 80:
                    action80();
                    break;
                case 81:
                    action81();
                    break;
                case 82:
                    action82();
                    break;
                case 83:
                    action83();
                    break;
                case 84:
                    action84();
                    break;
                case 85:
                    action85();
                    break;
                case 86:
                    action86();
                    break;
                case 87:
                    action87();
                    break;
                case 88:
                    action88();
                    break;
                case 89:
                    action89();
                    break;
                case 90:
                    action90();
                    break;
                case 91:
                    action91();
                    break;
                case 92:
                    action92();
                    break;
                case 93:
                    action93();
                    break;
                case 94:
                    action94();
                    break;
                case 95:
                    action95();
                    break;
                case 96:
                    action96();
                    break;
                case 97:
                    action97();
                    break;
                case 98:
                    action98();
                    break;
                case 99:
                    action99();
                    break;
                case 100:
                    action100();
                    break;
                case 101:
                    action101();
                    break;
                case 102:
                    action102();
                    break;
                case 103:
                    action103();
                    break;
                case 104:
                    action104();
                    break;
                case 105:
                    action105();
                    break;
                case 106:
                    action106();
                    break;
                case 107:
                    action107();
                    break;
                case 108:
                    action108();
                    break;
                case 109:
                    action109();
                    break;
                case 110:
                    action110();
                    break;
                case 111:
                    action111();
                    break;
                case 112:
                    action112();
                    break;
                case 113:
                    action113();
                    break;
                case 114:
                    action114();
                    break;
                case 115:
                    action115();
                    break;
                case 116:
                    action116();
                    break;
                case 117:
                    action117();
                    break;
                case 118:
                    action118();
                    break;
                case 119:
                    action119();
                    break;
                case 120:
                    action120();
                    break;
                case 121:
                    action121();
                    break;
                case 122:
                    action122();
                    break;
                case 123:
                    action123();
                    break;
                case 124:
                    action124();
                    break;
                case 125:
                    action125();
                    break;
                case 126:
                    action126();
                    break;
                case 127:
                    action127();
                    break;
                case 128:
                    action128();
                    break;
                case 129:
                    action129();
                    break;
                case 130:
                    action130();
                    break;
                case 131:
                    action131();
                    break;
                case 132:
                    action132();
                    break;
                case 133:
                    action133();
                    break;
                case 134:
                    action134();
                    break;
                case 135:
                    action135();
                    break;
                case 136:
                    action136();
                    break;
                case 137:
                    action137();
                    break;
                case 138:
                    action138();
                    break;
                case 139:
                    action139();
                    break;
                case 140:
                    action140();
                    break;
                case 141:
                    action141();
                    break;
                case 142:
                    action142();
                    break;
                case 143:
                    action143();
                    break;
                case 144:
                    action144();
                    break;
                case 145:
                    action145();
                    break;
                case 146:
                    action146();
                    break;
                case 147:
                    action147();
                    break;
                case 148:
                    action148();
                    break;
                case 149:
                    action149();
                    break;
                case 150:
                    action150();
                    break;
                case 151:
                    action151();
                    break;
                case 152:
                    action152();
                    break;
                case 153:
                    action153();
                    break;
                case 154:
                    action154();
                    break;
                case 155:
                    action155();
                    break;
                case 156:
                    action156();
                    break;
                case 157:
                    action157();
                    break;
                case 158:
                    action158();
                    break;
                case 159:
                    action159();
                    break;
                case 160:
                    action160();
                    break;
                case 161:
                    action161();
                    break;
                case 162:
                    action162();
                    break;
                case 163:
                    action163();
                    break;
                case 164:
                    action164();
                    break;
                case 165:
                    action165();
                    break;
                case 166:
                    action166();
                    break;
                case 167:
                    action167();
                    break;
                case 168:
                    action168();
                    break;
                case 169:
                    action169();
                    break;
                case 170:
                    action170();
                    break;
                case 171:
                    action171();
                    break;
                case 172:
                    action172();
                    break;
                case 173:
                    action173();
                    break;
                case 174:
                    action174();
                    break;
                case 175:
                    action175();
                    break;
                case 176:
                    action176();
                    break;
                case 177:
                    action177();
                    break;
                case 178:
                    action178();
                    break;
                case 179:
                    action179();
                    break;
                case 180:
                    action180();
                    break;
                case 181:
                    action181();
                    break;
                case 182:
                    action182();
                    break;
                case 183:
                    action183();
                    break;
                case 184:
                    action184();
                    break;
                case 185:
                    action185();
                    break;
                case 186:
                    action186();
                    break;
                case 187:
                    action187();
                    break;
                case 188:
                    action188();
                    break;
                case 189:
                    action189();
                    break;
                case 190:
                    action190();
                    break;
                case 191:
                    action191();
                    break;
                case 192:
                    action192();
                    break;
                case 193:
                    action193();
                    break;
                case 194:
                    action194();
                    break;
                case 195:
                    action195();
                    break;
                case 196:
                    action196();
                    break;
                case 197:
                    action197();
                    break;
                case 198:
                    action198();
                    break;
                case 199:
                    action199();
                    break;
                case 200:
                    action200();
                    break;
                case 201:
                    action201();
                    break;
                case 202:
                    action202();
                    break;
                case 203:
                    action203();
                    break;
                case 204:
                    action204();
                    break;
                case 205:
                    action205();
                    break;
                case 206:
                    action206();
                    break;
                case 207:
                    action207();
                    break;
                case 208:
                    action208();
                    break;
                case 209:
                    action209();
                    break;
                case 210:
                    action210();
                    break;
                case 211:
                    action211();
                    break;
                case 212:
                    action212();
                    break;
                case 213:
                    action213();
                    break;
                case 214:
                    action214();
                    break;
                case 215:
                    action215();
                    break;
                case 216:
                    action216();
                    break;
                case 217:
                    action217();
                    break;
                case 218:
                    action218();
                    break;
                case 219:
                    action219();
                    break;
                case 220:
                    action220();
                    break;
                case 221:
                    action221();
                    break;
                case 222:
                    action222();
                    break;
                case 223:
                    action223();
                    break;
                case 224:
                    action224();
                    break;
                case 225:
                    action225();
                    break;
                case 226:
                    action226();
                    break;
                case 227:
                    action227();
                    break;
                case 228:
                    action228();
                    break;
                case 229:
                    action229();
                    break;
                case 230:
                    action230();
                    break;
                case 231:
                    action231();
                    break;
                case 232:
                    action232();
                    break;
                case 233:
                    action233();
                    break;
                case 234:
                    action234();
                    break;
                case 235:
                    action235();
                    break;
                case 236:
                    action236();
                    break;
                case 237:
                    action237();
                    break;
                case 238:
                    action238();
                    break;
                case 239:
                    action239();
                    break;
                case 240:
                    action240();
                    break;
                case 241:
                    action241();
                    break;
                case 242:
                    action242();
                    break;
                case 243:
                    action243();
                    break;
                case 244:
                    action244();
                    break;
                case 245:
                    action245();
                    break;
                case 246:
                    action246();
                    break;
                case 247:
                    action247();
                    break;
                case 248:
                    action248();
                    break;
                case 249:
                    action249();
                    break;
                case 250:
                    action250();
                    break;
                case 251:
                    action251();
                    break;
                case 252:
                    action252();
                    break;
                case 253:
                    action253();
                    break;
                case 254:
                    action254();
                    break;
                case 255:
                    action255();
                    break;
                case 256:
                    action256();
                    break;
                case 257:
                    action257();
                    break;
                case 258:
                    action258();
                    break;
                case 259:
                    action259();
                    break;
                case 260:
                    action260();
                    break;
                case 261:
                    action261();
                    break;
                case 262:
                    action262();
                    break;
                case 263:
                    action263();
                    break;
                case 264:
                    action264();
                    break;
                case 265:
                    action265();
                    break;
                case 266:
                    action266();
                    break;
                case 267:
                    action267();
                    break;
                case 268:
                    action268();
                    break;
                case 269:
                    action269();
                    break;
                case 270:
                    action270();
                    break;
                case 271:
                    action271();
                    break;
                case 272:
                    action272();
                    break;
                case 273:
                    action273();
                    break;
                case 274:
                    action274();
                    break;
                case 275:
                    action275();
                    break;
                case 276:
                    action276();
                    break;
                case 277:
                    action277();
                    break;
                case 278:
                    action278();
                    break;
                case 279:
                    action279();
                    break;
                case 280:
                    action280();
                    break;
                case 281:
                    action281();
                    break;
                case 282:
                    action282();
                    break;
                case 283:
                    action283();
                    break;
                case 284:
                    action284();
                    break;
                case 285:
                    action285();
                    break;
                case 286:
                    action286();
                    break;
                case 287:
                    action287();
                    break;
                case 288:
                    action288();
                    break;
                case 289:
                    action289();
                    break;
                case 290:
                    action290();
                    break;
                case 291:
                    action291();
                    break;
                case 292:
                    action292();
                    break;
                case 293:
                    action293();
                    break;
                case 294:
                    action294();
                    break;
                case 295:
                    action295();
                    break;
                case 296:
                    action296();
                    break;
                case 297:
                    action297();
                    break;
                case 298:
                    action298();
                    break;
                case 299:
                    action299();
                    break;
                case 300:
                    action300();
                    break;
                case 301:
                    action301();
                    break;
                case 302:
                    action302();
                    break;
                case 303:
                    action303();
                    break;
                case 304:
                    action304();
                    break;
                case 305:
                    action305();
                    break;
                case 306:
                    action306();
                    break;
                case 307:
                    action307();
                    break;
                case 308:
                    action308();
                    break;
                case 309:
                    action309();
                    break;
                case 310:
                    action310();
                    break;
                case 311:
                    action311();
                    break;
                case 312:
                    action312();
                    break;
                case 313:
                    action313();
                    break;
                case 314:
                    action314();
                    break;
                case 315:
                    action315();
                    break;
                case 316:
                    action316();
                    break;
                case 317:
                    action317();
                    break;
                case 318:
                    action318();
                    break;
                case 319:
                    action319();
                    break;
                case 320:
                    action320();
                    break;
                case 321:
                    action321();
                    break;
                case 322:
                    action322();
                    break;
                case 323:
                    action323();
                    break;
                case 324:
                    action324();
                    break;
                case 325:
                    action325();
                    break;
                case 326:
                    action326();
                    break;
                case 327:
                    action327();
                    break;
                case 328:
                    action328();
                    break;
                case 329:
                    action329();
                    break;
                case 330:
                    action330();
                    break;
                case 331:
                    action331();
                    break;
                case 332:
                    action332();
                    break;
                case 333:
                    action333();
                    break;
                case 334:
                    action334();
                    break;
                case 335:
                    action335();
                    break;
                case 336:
                    action336();
                    break;
                case 337:
                    action337();
                    break;
                case 338:
                    action338();
                    break;
                case 339:
                    action339();
                    break;
                case 340:
                    action340();
                    break;
                case 341:
                    action341();
                    break;
                case 342:
                    action342();
                    break;
                case 343:
                    action343();
                    break;
                case 344:
                    action344();
                    break;
                case 345:
                    action345();
                    break;
                case 346:
                    action346();
                    break;
                case 347:
                    action347();
                    break;
                case 348:
                    action348();
                    break;
                case 349:
                    action349();
                    break;
                case 350:
                    action350();
                    break;
                case 351:
                    action351();
                    break;
                case 352:
                    action352();
                    break;
                case 353:
                    action353();
                    break;
                case 354:
                    action354();
                    break;
                case 355:
                    action355();
                    break;
                case 356:
                    action356();
                    break;
                case 357:
                    action357();
                    break;
                case 358:
                    action358();
                    break;
                case 359:
                    action359();
                    break;
                case 360:
                    action360();
                    break;
                case 361:
                    action361();
                    break;
                case 362:
                    action362();
                    break;
                case 363:
                    action363();
                    break;
                case 364:
                    action364();
                    break;
                case 365:
                    action365();
                    break;
                case 366:
                    action366();
                    break;
                case 367:
                    action367();
                    break;
                case 368:
                    action368();
                    break;
                case 369:
                    action369();
                    break;
                case 370:
                    action370();
                    break;
                case 371:
                    action371();
                    break;
                case 372:
                    action372();
                    break;
                case 373:
                    action373();
                    break;
                case 374:
                    action374();
                    break;
                case 375:
                    action375();
                    break;
                case 376:
                    action376();
                    break;
                case 377:
                    action377();
                    break;
                case 378:
                    action378();
                    break;
                case 379:
                    action379();
                    break;
                case 380:
                    action380();
                    break;
                case 381:
                    action381();
                    break;
                case 382:
                    action382();
                    break;
                case 383:
                    action383();
                    break;
                case 384:
                    action384();
                    break;
                case 385:
                    action385();
                    break;
                case 386:
                    action386();
                    break;
                case 387:
                    action387();
                    break;
                case 388:
                    action388();
                    break;
                case 389:
                    action389();
                    break;
                case 390:
                    action390();
                    break;
                case 391:
                    action391();
                    break;
                case 392:
                    action392();
                    break;
                case 393:
                    action393();
                    break;
                case 394:
                    action394();
                    break;
                case 395:
                    action395();
                    break;
                case 396:
                    action396();
                    break;
                case 397:
                    action397();
                    break;
                case 398:
                    action398();
                    break;
                case 399:
                    action399();
                    break;
                case 400:
                    action400();
                    break;
                case 401:
                    action401();
                    break;
                default:
                    String msg = "Unknown parser state: " + state;
                    throw new RuntimeException(msg);
            }

            // Accept action.
            if (accept) {
                return acceptObject;
            }

            // Shift action.
            if (!reduce) {
                continue;
            }

            // Perform goto (as part of a reduce action).
            switch (reduceState) {
                case 0:
                    goto0();
                    break;
                case 1:
                    goto1();
                    break;
                case 2:
                    goto2();
                    break;
                case 3:
                    goto3();
                    break;
                case 4:
                    goto4();
                    break;
                case 5:
                    goto5();
                    break;
                case 6:
                    goto6();
                    break;
                case 7:
                    goto7();
                    break;
                case 8:
                    goto8();
                    break;
                case 9:
                    goto9();
                    break;
                case 10:
                    goto10();
                    break;
                case 11:
                    goto11();
                    break;
                case 12:
                    goto12();
                    break;
                case 13:
                    goto13();
                    break;
                case 14:
                    goto14();
                    break;
                case 15:
                    goto15();
                    break;
                case 16:
                    goto16();
                    break;
                case 17:
                    goto17();
                    break;
                case 18:
                    goto18();
                    break;
                case 19:
                    goto19();
                    break;
                case 20:
                    goto20();
                    break;
                case 21:
                    goto21();
                    break;
                case 22:
                    goto22();
                    break;
                case 23:
                    goto23();
                    break;
                case 24:
                    goto24();
                    break;
                case 25:
                    goto25();
                    break;
                case 26:
                    goto26();
                    break;
                case 27:
                    goto27();
                    break;
                case 28:
                    goto28();
                    break;
                case 29:
                    goto29();
                    break;
                case 30:
                    goto30();
                    break;
                case 31:
                    goto31();
                    break;
                case 32:
                    goto32();
                    break;
                case 33:
                    goto33();
                    break;
                case 34:
                    goto34();
                    break;
                case 35:
                    goto35();
                    break;
                case 36:
                    goto36();
                    break;
                case 37:
                    goto37();
                    break;
                case 38:
                    goto38();
                    break;
                case 39:
                    goto39();
                    break;
                case 40:
                    goto40();
                    break;
                case 41:
                    goto41();
                    break;
                case 42:
                    goto42();
                    break;
                case 43:
                    goto43();
                    break;
                case 44:
                    goto44();
                    break;
                case 45:
                    goto45();
                    break;
                case 46:
                    goto46();
                    break;
                case 47:
                    goto47();
                    break;
                case 48:
                    goto48();
                    break;
                case 49:
                    goto49();
                    break;
                case 50:
                    goto50();
                    break;
                case 51:
                    goto51();
                    break;
                case 52:
                    goto52();
                    break;
                case 53:
                    goto53();
                    break;
                case 54:
                    goto54();
                    break;
                case 55:
                    goto55();
                    break;
                case 56:
                    goto56();
                    break;
                case 57:
                    goto57();
                    break;
                case 58:
                    goto58();
                    break;
                case 59:
                    goto59();
                    break;
                case 60:
                    goto60();
                    break;
                case 61:
                    goto61();
                    break;
                case 62:
                    goto62();
                    break;
                case 63:
                    goto63();
                    break;
                case 64:
                    goto64();
                    break;
                case 65:
                    goto65();
                    break;
                case 66:
                    goto66();
                    break;
                case 67:
                    goto67();
                    break;
                case 68:
                    goto68();
                    break;
                case 69:
                    goto69();
                    break;
                case 70:
                    goto70();
                    break;
                case 71:
                    goto71();
                    break;
                case 72:
                    goto72();
                    break;
                case 73:
                    goto73();
                    break;
                case 74:
                    goto74();
                    break;
                case 75:
                    goto75();
                    break;
                case 76:
                    goto76();
                    break;
                case 77:
                    goto77();
                    break;
                case 78:
                    goto78();
                    break;
                case 79:
                    goto79();
                    break;
                case 80:
                    goto80();
                    break;
                case 81:
                    goto81();
                    break;
                case 82:
                    goto82();
                    break;
                case 83:
                    goto83();
                    break;
                case 84:
                    goto84();
                    break;
                case 85:
                    goto85();
                    break;
                case 86:
                    goto86();
                    break;
                case 87:
                    goto87();
                    break;
                case 88:
                    goto88();
                    break;
                case 89:
                    goto89();
                    break;
                case 90:
                    goto90();
                    break;
                case 91:
                    goto91();
                    break;
                case 92:
                    goto92();
                    break;
                case 93:
                    goto93();
                    break;
                case 94:
                    goto94();
                    break;
                case 95:
                    goto95();
                    break;
                case 96:
                    goto96();
                    break;
                case 97:
                    goto97();
                    break;
                case 98:
                    goto98();
                    break;
                case 99:
                    goto99();
                    break;
                case 100:
                    goto100();
                    break;
                case 101:
                    goto101();
                    break;
                case 102:
                    goto102();
                    break;
                case 103:
                    goto103();
                    break;
                case 104:
                    goto104();
                    break;
                case 105:
                    goto105();
                    break;
                case 106:
                    goto106();
                    break;
                case 107:
                    goto107();
                    break;
                case 108:
                    goto108();
                    break;
                case 109:
                    goto109();
                    break;
                case 110:
                    goto110();
                    break;
                case 111:
                    goto111();
                    break;
                case 112:
                    goto112();
                    break;
                case 113:
                    goto113();
                    break;
                case 114:
                    goto114();
                    break;
                case 115:
                    goto115();
                    break;
                case 116:
                    goto116();
                    break;
                case 117:
                    goto117();
                    break;
                case 118:
                    goto118();
                    break;
                case 119:
                    goto119();
                    break;
                case 120:
                    goto120();
                    break;
                case 121:
                    goto121();
                    break;
                case 122:
                    goto122();
                    break;
                case 123:
                    goto123();
                    break;
                case 124:
                    goto124();
                    break;
                case 125:
                    goto125();
                    break;
                case 126:
                    goto126();
                    break;
                case 127:
                    goto127();
                    break;
                case 128:
                    goto128();
                    break;
                case 129:
                    goto129();
                    break;
                case 130:
                    goto130();
                    break;
                case 131:
                    goto131();
                    break;
                case 132:
                    goto132();
                    break;
                case 133:
                    goto133();
                    break;
                case 134:
                    goto134();
                    break;
                case 135:
                    goto135();
                    break;
                case 136:
                    goto136();
                    break;
                case 137:
                    goto137();
                    break;
                case 138:
                    goto138();
                    break;
                case 139:
                    goto139();
                    break;
                case 140:
                    goto140();
                    break;
                case 141:
                    goto141();
                    break;
                case 142:
                    goto142();
                    break;
                case 143:
                    goto143();
                    break;
                case 144:
                    goto144();
                    break;
                case 145:
                    goto145();
                    break;
                case 146:
                    goto146();
                    break;
                case 147:
                    goto147();
                    break;
                case 148:
                    goto148();
                    break;
                case 149:
                    goto149();
                    break;
                case 150:
                    goto150();
                    break;
                case 151:
                    goto151();
                    break;
                case 152:
                    goto152();
                    break;
                case 153:
                    goto153();
                    break;
                case 154:
                    goto154();
                    break;
                case 155:
                    goto155();
                    break;
                case 156:
                    goto156();
                    break;
                case 157:
                    goto157();
                    break;
                case 158:
                    goto158();
                    break;
                case 159:
                    goto159();
                    break;
                case 160:
                    goto160();
                    break;
                case 161:
                    goto161();
                    break;
                case 162:
                    goto162();
                    break;
                case 163:
                    goto163();
                    break;
                case 164:
                    goto164();
                    break;
                case 165:
                    goto165();
                    break;
                case 166:
                    goto166();
                    break;
                case 167:
                    goto167();
                    break;
                case 168:
                    goto168();
                    break;
                case 169:
                    goto169();
                    break;
                case 170:
                    goto170();
                    break;
                case 171:
                    goto171();
                    break;
                case 172:
                    goto172();
                    break;
                case 173:
                    goto173();
                    break;
                case 174:
                    goto174();
                    break;
                case 175:
                    goto175();
                    break;
                case 176:
                    goto176();
                    break;
                case 177:
                    goto177();
                    break;
                case 178:
                    goto178();
                    break;
                case 179:
                    goto179();
                    break;
                case 180:
                    goto180();
                    break;
                case 181:
                    goto181();
                    break;
                case 182:
                    goto182();
                    break;
                case 183:
                    goto183();
                    break;
                case 184:
                    goto184();
                    break;
                case 185:
                    goto185();
                    break;
                case 186:
                    goto186();
                    break;
                case 187:
                    goto187();
                    break;
                case 188:
                    goto188();
                    break;
                case 189:
                    goto189();
                    break;
                case 190:
                    goto190();
                    break;
                case 191:
                    goto191();
                    break;
                case 192:
                    goto192();
                    break;
                case 193:
                    goto193();
                    break;
                case 194:
                    goto194();
                    break;
                case 195:
                    goto195();
                    break;
                case 196:
                    goto196();
                    break;
                case 197:
                    goto197();
                    break;
                case 198:
                    goto198();
                    break;
                case 199:
                    goto199();
                    break;
                case 200:
                    goto200();
                    break;
                case 201:
                    goto201();
                    break;
                case 202:
                    goto202();
                    break;
                case 203:
                    goto203();
                    break;
                case 204:
                    goto204();
                    break;
                case 205:
                    goto205();
                    break;
                case 206:
                    goto206();
                    break;
                case 207:
                    goto207();
                    break;
                case 208:
                    goto208();
                    break;
                case 209:
                    goto209();
                    break;
                case 210:
                    goto210();
                    break;
                case 211:
                    goto211();
                    break;
                case 212:
                    goto212();
                    break;
                case 213:
                    goto213();
                    break;
                case 214:
                    goto214();
                    break;
                case 215:
                    goto215();
                    break;
                case 216:
                    goto216();
                    break;
                case 217:
                    goto217();
                    break;
                case 218:
                    goto218();
                    break;
                case 219:
                    goto219();
                    break;
                case 220:
                    goto220();
                    break;
                case 221:
                    goto221();
                    break;
                case 222:
                    goto222();
                    break;
                case 223:
                    goto223();
                    break;
                case 224:
                    goto224();
                    break;
                case 225:
                    goto225();
                    break;
                case 226:
                    goto226();
                    break;
                case 227:
                    goto227();
                    break;
                case 228:
                    goto228();
                    break;
                case 229:
                    goto229();
                    break;
                case 230:
                    goto230();
                    break;
                case 231:
                    goto231();
                    break;
                case 232:
                    goto232();
                    break;
                case 233:
                    goto233();
                    break;
                case 234:
                    goto234();
                    break;
                case 235:
                    goto235();
                    break;
                case 236:
                    goto236();
                    break;
                case 237:
                    goto237();
                    break;
                case 238:
                    goto238();
                    break;
                case 239:
                    goto239();
                    break;
                case 240:
                    goto240();
                    break;
                case 241:
                    goto241();
                    break;
                case 242:
                    goto242();
                    break;
                case 243:
                    goto243();
                    break;
                case 244:
                    goto244();
                    break;
                case 245:
                    goto245();
                    break;
                case 246:
                    goto246();
                    break;
                case 247:
                    goto247();
                    break;
                case 248:
                    goto248();
                    break;
                case 249:
                    goto249();
                    break;
                case 250:
                    goto250();
                    break;
                case 251:
                    goto251();
                    break;
                case 252:
                    goto252();
                    break;
                case 253:
                    goto253();
                    break;
                case 254:
                    goto254();
                    break;
                case 255:
                    goto255();
                    break;
                case 256:
                    goto256();
                    break;
                case 257:
                    goto257();
                    break;
                case 258:
                    goto258();
                    break;
                case 259:
                    goto259();
                    break;
                case 260:
                    goto260();
                    break;
                case 261:
                    goto261();
                    break;
                case 262:
                    goto262();
                    break;
                case 263:
                    goto263();
                    break;
                case 264:
                    goto264();
                    break;
                case 265:
                    goto265();
                    break;
                case 266:
                    goto266();
                    break;
                case 267:
                    goto267();
                    break;
                case 268:
                    goto268();
                    break;
                case 269:
                    goto269();
                    break;
                case 270:
                    goto270();
                    break;
                case 271:
                    goto271();
                    break;
                case 272:
                    goto272();
                    break;
                case 273:
                    goto273();
                    break;
                case 274:
                    goto274();
                    break;
                case 275:
                    goto275();
                    break;
                case 276:
                    goto276();
                    break;
                case 277:
                    goto277();
                    break;
                case 278:
                    goto278();
                    break;
                case 279:
                    goto279();
                    break;
                case 280:
                    goto280();
                    break;
                case 281:
                    goto281();
                    break;
                case 282:
                    goto282();
                    break;
                case 283:
                    goto283();
                    break;
                case 284:
                    goto284();
                    break;
                case 285:
                    goto285();
                    break;
                case 286:
                    goto286();
                    break;
                case 287:
                    goto287();
                    break;
                case 288:
                    goto288();
                    break;
                case 289:
                    goto289();
                    break;
                case 290:
                    goto290();
                    break;
                case 291:
                    goto291();
                    break;
                case 292:
                    goto292();
                    break;
                case 293:
                    goto293();
                    break;
                case 294:
                    goto294();
                    break;
                case 295:
                    goto295();
                    break;
                case 296:
                    goto296();
                    break;
                case 297:
                    goto297();
                    break;
                case 298:
                    goto298();
                    break;
                case 299:
                    goto299();
                    break;
                case 300:
                    goto300();
                    break;
                case 301:
                    goto301();
                    break;
                case 302:
                    goto302();
                    break;
                case 303:
                    goto303();
                    break;
                case 304:
                    goto304();
                    break;
                case 305:
                    goto305();
                    break;
                case 306:
                    goto306();
                    break;
                case 307:
                    goto307();
                    break;
                case 308:
                    goto308();
                    break;
                case 309:
                    goto309();
                    break;
                case 310:
                    goto310();
                    break;
                case 311:
                    goto311();
                    break;
                case 312:
                    goto312();
                    break;
                case 313:
                    goto313();
                    break;
                case 314:
                    goto314();
                    break;
                case 315:
                    goto315();
                    break;
                case 316:
                    goto316();
                    break;
                case 317:
                    goto317();
                    break;
                case 318:
                    goto318();
                    break;
                case 319:
                    goto319();
                    break;
                case 320:
                    goto320();
                    break;
                case 321:
                    goto321();
                    break;
                case 322:
                    goto322();
                    break;
                case 323:
                    goto323();
                    break;
                case 324:
                    goto324();
                    break;
                case 325:
                    goto325();
                    break;
                case 326:
                    goto326();
                    break;
                case 327:
                    goto327();
                    break;
                case 328:
                    goto328();
                    break;
                case 329:
                    goto329();
                    break;
                case 330:
                    goto330();
                    break;
                case 331:
                    goto331();
                    break;
                case 332:
                    goto332();
                    break;
                case 333:
                    goto333();
                    break;
                case 334:
                    goto334();
                    break;
                case 335:
                    goto335();
                    break;
                case 336:
                    goto336();
                    break;
                case 337:
                    goto337();
                    break;
                case 338:
                    goto338();
                    break;
                case 339:
                    goto339();
                    break;
                case 340:
                    goto340();
                    break;
                case 341:
                    goto341();
                    break;
                case 342:
                    goto342();
                    break;
                case 343:
                    goto343();
                    break;
                case 344:
                    goto344();
                    break;
                case 345:
                    goto345();
                    break;
                case 346:
                    goto346();
                    break;
                case 347:
                    goto347();
                    break;
                case 348:
                    goto348();
                    break;
                case 349:
                    goto349();
                    break;
                case 350:
                    goto350();
                    break;
                case 351:
                    goto351();
                    break;
                case 352:
                    goto352();
                    break;
                case 353:
                    goto353();
                    break;
                case 354:
                    goto354();
                    break;
                case 355:
                    goto355();
                    break;
                case 356:
                    goto356();
                    break;
                case 357:
                    goto357();
                    break;
                case 358:
                    goto358();
                    break;
                case 359:
                    goto359();
                    break;
                case 360:
                    goto360();
                    break;
                case 361:
                    goto361();
                    break;
                case 362:
                    goto362();
                    break;
                case 363:
                    goto363();
                    break;
                case 364:
                    goto364();
                    break;
                case 365:
                    goto365();
                    break;
                case 366:
                    goto366();
                    break;
                case 367:
                    goto367();
                    break;
                case 368:
                    goto368();
                    break;
                case 369:
                    goto369();
                    break;
                case 370:
                    goto370();
                    break;
                case 371:
                    goto371();
                    break;
                case 372:
                    goto372();
                    break;
                case 373:
                    goto373();
                    break;
                case 374:
                    goto374();
                    break;
                case 375:
                    goto375();
                    break;
                case 376:
                    goto376();
                    break;
                case 377:
                    goto377();
                    break;
                case 378:
                    goto378();
                    break;
                case 379:
                    goto379();
                    break;
                case 380:
                    goto380();
                    break;
                case 381:
                    goto381();
                    break;
                case 382:
                    goto382();
                    break;
                case 383:
                    goto383();
                    break;
                case 384:
                    goto384();
                    break;
                case 385:
                    goto385();
                    break;
                case 386:
                    goto386();
                    break;
                case 387:
                    goto387();
                    break;
                case 388:
                    goto388();
                    break;
                case 389:
                    goto389();
                    break;
                case 390:
                    goto390();
                    break;
                case 391:
                    goto391();
                    break;
                case 392:
                    goto392();
                    break;
                case 393:
                    goto393();
                    break;
                case 394:
                    goto394();
                    break;
                case 395:
                    goto395();
                    break;
                case 396:
                    goto396();
                    break;
                case 397:
                    goto397();
                    break;
                case 398:
                    goto398();
                    break;
                case 399:
                    goto399();
                    break;
                case 400:
                    goto400();
                    break;
                case 401:
                    goto401();
                    break;
                default:
                    String msg = fmt("Unknown reduce state %d.", reduceState);
                    throw new RuntimeException(msg);
            }
        }
    }

    /**
     * Parser action code for parser state 0.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action0() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 11: {
                // Shift 7.
                token = doShift(token, 7);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 13: {
                // Shift 9.
                token = doShift(token, 9);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 24: {
                // Shift 18.
                token = doShift(token, 18);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 27: {
                // Shift 20.
                token = doShift(token, 20);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 136: {
                // Reduce Script : ;
                doReduce1(token, 5);
                Script o = hooks.parseScript1();

                reduce = true;
                reduceNonTerminal = 5;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 1.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action1() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 401.
                token = doShift(token, 401);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : BOOLKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType01((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 2.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action2() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 400.
                token = doShift(token, 400);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 3.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action3() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 399.
                token = doShift(token, 399);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 4.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action4() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 398.
                token = doShift(token, 398);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : DOUBLEKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType07((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 5.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action5() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 124: {
                // Shift 395.
                token = doShift(token, 395);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 6.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action6() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 378.
                token = doShift(token, 378);
                return;
            }

            case 128: {
                // Shift 379.
                token = doShift(token, 379);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 7.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action7() throws IOException {
        switch (token.id) {
            case 132: {
                // Shift 365.
                token = doShift(token, 365);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 8.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action8() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 9.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action9() throws IOException {
        switch (token.id) {
            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 132: {
                // Shift 335.
                token = doShift(token, 335);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 10.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action10() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 334.
                token = doShift(token, 334);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : INTKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType03((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 11.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action11() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 123: {
                // Shift 331.
                token = doShift(token, 331);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 12.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action12() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 330.
                token = doShift(token, 330);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : LONGKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType05((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 13.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action13() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 319.
                token = doShift(token, 319);
                return;
            }

            case 123: {
                // Shift 320.
                token = doShift(token, 320);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 14.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action14() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 318.
                token = doShift(token, 318);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : OBJECTKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType19((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 15.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action15() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 124: {
                // Shift 315.
                token = doShift(token, 315);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 16.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action16() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 123: {
                // Shift 312.
                token = doShift(token, 312);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 17.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action17() throws IOException {
        switch (token.id) {
            case 123: {
                // Shift 311.
                token = doShift(token, 311);
                return;
            }

            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : STRINGKW;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType09((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 18.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action18() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 276.
                token = doShift(token, 276);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 19.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action19() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 262.
                token = doShift(token, 262);
                return;
            }

            case 123: {
                // Shift 263.
                token = doShift(token, 263);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 20.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action20() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 254.
                token = doShift(token, 254);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 21.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action21() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 22.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action22() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInIoTool : ERRKW;
                doReduce1(token, 0);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInIoTool1((Token)o1);

                reduce = true;
                reduceNonTerminal = 0;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 23.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action23() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInIoTool : ERRLNKW;
                doReduce1(token, 0);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInIoTool2((Token)o1);

                reduce = true;
                reduceNonTerminal = 0;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 24.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action24() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInIoTool : OUTKW;
                doReduce1(token, 0);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInIoTool3((Token)o1);

                reduce = true;
                reduceNonTerminal = 0;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 25.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action25() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInIoTool : OUTLNKW;
                doReduce1(token, 0);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInIoTool4((Token)o1);

                reduce = true;
                reduceNonTerminal = 0;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 26.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action26() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInGenericTool : APPKW;
                doReduce1(token, 1);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInGenericTool1((Token)o1);

                reduce = true;
                reduceNonTerminal = 1;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 27.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action27() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInGenericTool : EXECKW;
                doReduce1(token, 1);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInGenericTool2((Token)o1);

                reduce = true;
                reduceNonTerminal = 1;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 28.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action28() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInGenericTool : TOOLDEFKW;
                doReduce1(token, 1);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInGenericTool3((Token)o1);

                reduce = true;
                reduceNonTerminal = 1;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 29.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action29() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : ABSPATHKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool01((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 30.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action30() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : BASENAMEKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool02((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 31.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action31() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : CHDIRKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool03((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 32.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action32() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : CHFILEEXTKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool04((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 33.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action33() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : CURDIRKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool05((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 34.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action34() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : DIRNAMEKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool06((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 35.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action35() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : FILEEXTKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool07((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 36.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action36() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : HASFILEEXTKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool08((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 37.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action37() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : PATHJOINKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool09((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 38.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action38() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInPathTool : SCRIPTPATHKW;
                doReduce1(token, 2);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInPathTool10((Token)o1);

                reduce = true;
                reduceNonTerminal = 2;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 39.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action39() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : CPDIRKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool01((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 40.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action40() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : CPFILEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool02((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 41.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action41() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : DIFFKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool03((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 42.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action42() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : EXISTSKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool04((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 43.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action43() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : FILENEWERKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool05((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 44.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action44() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : FILESIZEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool06((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 45.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action45() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : FINDKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool07((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 46.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action46() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : ISDIRKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool08((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 47.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action47() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : ISFILEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool09((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 48.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action48() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : MKDIRKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool10((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 49.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action49() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : MVDIRKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool11((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 50.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action50() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : MVFILEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool12((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 51.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action51() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : READLINESKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool13((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 52.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action52() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : RMDIRKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool14((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 53.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action53() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : RMFILEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool15((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 54.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action54() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInFileTool : WRITEFILEKW;
                doReduce1(token, 3);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInFileTool16((Token)o1);

                reduce = true;
                reduceNonTerminal = 3;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 55.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action55() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : ABSKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool01((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 56.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action56() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : CEILKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool02((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 57.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action57() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : CONTAINSKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool03((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 58.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action58() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : DELKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool04((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 59.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action59() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : DELIDXKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool05((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 60.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action60() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : EMPTYKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool06((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 61.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action61() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : ENDSWITHKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool07((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 62.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action62() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : ENTRIESKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool08((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 63.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action63() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : ENUMERATEKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool09((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 64.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action64() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : FLOORKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool10((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 65.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action65() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : FMTKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool11((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 66.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action66() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : INDEXOFKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool12((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 67.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action67() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : JOINKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool13((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 68.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action68() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : KEYSKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool14((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 69.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action69() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : LASTINDEXOFKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool15((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 70.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action70() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : LNKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool16((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 71.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action71() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : LOGKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool17((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 72.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action72() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : LOWERKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool18((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 73.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action73() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : LTRIMKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool19((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 74.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action74() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : MAXKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool20((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 75.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action75() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : MINKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool21((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 76.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action76() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : POWKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool22((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 77.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action77() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : RANGEKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool23((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 78.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action78() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : REPLACEKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool24((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 79.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action79() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : REVERSEKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool25((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 80.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action80() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : ROUNDKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool26((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 81.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action81() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : RTRIMKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool27((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 82.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action82() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : SIZEKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool28((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 83.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action83() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : SORTEDKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool29((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 84.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action84() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : SPLITKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool30((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 85.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action85() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : SQRTKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool31((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 86.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action86() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : STARTSWITHKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool32((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 87.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action87() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : STRKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool33((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 88.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action88() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : STRDUPKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool34((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 89.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action89() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : SUBSETKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool35((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 90.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action90() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : TRIMKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool36((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 91.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action91() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : UPPERKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool37((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 92.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action92() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInDataTool : VALUESKW;
                doReduce1(token, 4);
                Object o1 = doReduce2();

                Token o = hooks.parseBuiltInDataTool38((Token)o1);

                reduce = true;
                reduceNonTerminal = 4;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 93.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action93() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 235.
                token = doShift(token, 235);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 94.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action94() throws IOException {
        switch (token.id) {
            case 127: {
                // Shift 237.
                token = doShift(token, 237);
                return;
            }

            case 108:
            case 113: {
                // Reduce Addressable : IDENTIFIERTK;
                doReduce1(token, 25);
                Object o1 = doReduce2();

                Expression o = hooks.parseAddressable1((Token)o1);

                reduce = true;
                reduceNonTerminal = 25;
                reduceState = doReduce3(o);
                return;
            }

            case 121:
            case 128: {
                // Reduce Name : IDENTIFIERTK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName1((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 95.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action95() throws IOException {
        switch (token.id) {
            case 0:
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 111:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 121:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127:
            case 128: {
                // Reduce Name : RELATIVENAMETK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName2((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 96.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action96() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120: {
                // Reduce Addressables : Addressable;
                doReduce1(token, 24);
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseAddressables1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 24;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 97.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action97() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 230.
                token = doShift(token, 230);
                return;
            }

            case 113: {
                // Shift 231.
                token = doShift(token, 231);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 98.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action98() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInTool : BuiltInDataTool;
                doReduce1(token, 43);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseBuiltInTool5((Token)o1);

                reduce = true;
                reduceNonTerminal = 43;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 99.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action99() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInTool : BuiltInFileTool;
                doReduce1(token, 43);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseBuiltInTool4((Token)o1);

                reduce = true;
                reduceNonTerminal = 43;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 100.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action100() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInTool : BuiltInGenericTool;
                doReduce1(token, 43);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseBuiltInTool2((Token)o1);

                reduce = true;
                reduceNonTerminal = 43;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 101.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action101() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInTool : BuiltInIoTool;
                doReduce1(token, 43);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseBuiltInTool1((Token)o1);

                reduce = true;
                reduceNonTerminal = 43;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 102.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action102() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce BuiltInTool : BuiltInPathTool;
                doReduce1(token, 43);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseBuiltInTool3((Token)o1);

                reduce = true;
                reduceNonTerminal = 43;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 103.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action103() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce ToolRef : BuiltInTool;
                doReduce1(token, 42);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseToolRef1((ToolRef)o1);

                reduce = true;
                reduceNonTerminal = 42;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 104.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action104() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decls : Decl;
                doReduce1(token, 6);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecls1((List<Declaration>)o1);

                reduce = true;
                reduceNonTerminal = 6;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 105.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action105() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 11: {
                // Shift 7.
                token = doShift(token, 7);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 13: {
                // Shift 9.
                token = doShift(token, 9);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 24: {
                // Shift 18.
                token = doShift(token, 18);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 27: {
                // Shift 20.
                token = doShift(token, 20);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 136: {
                // Reduce Script : Decls;
                doReduce1(token, 5);
                Object o1 = doReduce2();

                Script o = hooks.parseScript2((List<Declaration>)o1);

                reduce = true;
                reduceNonTerminal = 5;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 106.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action106() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decl : Import;
                doReduce1(token, 7);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecl1((List<Declaration>)o1);

                reduce = true;
                reduceNonTerminal = 7;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 107.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action107() throws IOException {
        switch (token.id) {
            case 128: {
                // Reduce Type : Name;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType21((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            case 121: {
                // Reduce ToolRef : Name;
                doReduce1(token, 42);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseToolRef2((Token)o1);

                reduce = true;
                reduceNonTerminal = 42;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 108.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action108() throws IOException {
        switch (token.id) {
            case 136: {
                // Accept.
                Object rslt = doAccept(token);
                accept = true;
                acceptObject = (Script)rslt;
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 109.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action109() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decl : Statement;
                doReduce1(token, 7);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecl5((List<Statement>)o1);

                reduce = true;
                reduceNonTerminal = 7;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 110.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action110() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 228.
                token = doShift(token, 228);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 111.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action111() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 214.
                token = doShift(token, 214);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 112.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action112() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 113.
                token = doShift(token, 113);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 113.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action113() throws IOException {
        switch (token.id) {
            case 113: {
                // Shift 119.
                token = doShift(token, 119);
                return;
            }

            case 108:
            case 124: {
                // Reduce VarDecl : IDENTIFIERTK;
                doReduce1(token, 19);
                Object o1 = doReduce2();

                Statement o = hooks.parseVarDecl1((Token)o1);

                reduce = true;
                reduceNonTerminal = 19;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 114.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action114() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce VarDecls : VarDecl;
                doReduce1(token, 18);
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseVarDecls1((Statement)o1);

                reduce = true;
                reduceNonTerminal = 18;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 115.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action115() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 116.
                token = doShift(token, 116);
                return;
            }

            case 124: {
                // Shift 117.
                token = doShift(token, 117);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 116.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action116() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 113.
                token = doShift(token, 113);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 117.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action117() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : Type VarDecls SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement01((ToolDefType)o1, (List<Statement>)o2);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 118.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action118() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce VarDecls : VarDecls COMMATK VarDecl;
                doReduce1(token, 18);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseVarDecls2((List<Statement>)o1, (Statement)o3);

                reduce = true;
                reduceNonTerminal = 18;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 119.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action119() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 120.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action120() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : FALSEKW;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor02((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 121.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action121() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : NULLKW;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor05((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 122.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action122() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : TRUEKW;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor01((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 123.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action123() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 124.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action124() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 109: {
                // Shift 199.
                token = doShift(token, 199);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 125.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action125() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 126.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action126() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 127.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action127() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 128.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action128() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 129.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action129() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 126: {
                // Shift 180.
                token = doShift(token, 180);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 130.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action130() throws IOException {
        switch (token.id) {
            case 0:
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 111:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 121:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127:
            case 128: {
                // Reduce Name : IDENTIFIERTK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName1((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 131.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action131() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : NUMBERTK;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor03((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 132.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action132() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : DOUBLETK;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor04((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 133.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action133() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : STRINGTK;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor06((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 134.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action134() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : AddExpression;
                doReduce1(token, 34);
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 135.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action135() throws IOException {
        switch (token.id) {
            case 100: {
                // Shift 153.
                token = doShift(token, 153);
                return;
            }

            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 120:
            case 124:
            case 126: {
                // Reduce Expression : AndExpression;
                doReduce1(token, 32);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 32;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 136.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action136() throws IOException {
        switch (token.id) {
            case 112: {
                // Shift 155.
                token = doShift(token, 155);
                return;
            }

            case 114: {
                // Shift 156.
                token = doShift(token, 156);
                return;
            }

            case 115: {
                // Shift 157.
                token = doShift(token, 157);
                return;
            }

            case 116: {
                // Shift 158.
                token = doShift(token, 158);
                return;
            }

            case 117: {
                // Shift 159.
                token = doShift(token, 159);
                return;
            }

            case 119: {
                // Shift 160.
                token = doShift(token, 160);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 120:
            case 124:
            case 126: {
                // Reduce AndExpression : CompareExpression;
                doReduce1(token, 33);
                Object o1 = doReduce2();

                Expression o = hooks.parseAndExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 33;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 137.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action137() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 124: {
                // Reduce VarDecl : IDENTIFIERTK EQTK Expression;
                doReduce1(token, 19);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Statement o = hooks.parseVarDecl2((Token)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 19;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 138.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action138() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ProjExpression : ExpressionFactor;
                doReduce1(token, 38);
                Object o1 = doReduce2();

                Expression o = hooks.parseProjExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 38;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 139.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action139() throws IOException {
        switch (token.id) {
            case 101: {
                // Shift 165.
                token = doShift(token, 165);
                return;
            }

            case 102: {
                // Shift 166.
                token = doShift(token, 166);
                return;
            }

            case 105: {
                // Shift 167.
                token = doShift(token, 167);
                return;
            }

            case 125: {
                // Shift 168.
                token = doShift(token, 168);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 126: {
                // Reduce AddExpression : MulExpression;
                doReduce1(token, 35);
                Object o1 = doReduce2();

                Expression o = hooks.parseAddExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 35;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 140.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action140() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : Name;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor16((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            case 121: {
                // Reduce ToolRef : Name;
                doReduce1(token, 42);
                Object o1 = doReduce2();

                ToolRef o = hooks.parseToolRef2((Token)o1);

                reduce = true;
                reduceNonTerminal = 42;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 141.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action141() throws IOException {
        switch (token.id) {
            case 127: {
                // Shift 144.
                token = doShift(token, 144);
                return;
            }

            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce UnaryExpression : ProjExpression;
                doReduce1(token, 37);
                Object o1 = doReduce2();

                Expression o = hooks.parseUnaryExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 37;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 142.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action142() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : ToolInvokeExpression;
                doReduce1(token, 39);
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor15((ToolInvokeExpression)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 143.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action143() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce MulExpression : UnaryExpression;
                doReduce1(token, 36);
                Object o1 = doReduce2();

                Expression o = hooks.parseMulExpression1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 36;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 144.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action144() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 107: {
                // Reduce OptExpression : ;
                doReduce1(token, 31);
                Expression o = hooks.parseOptExpression1();

                reduce = true;
                reduceNonTerminal = 31;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 145.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action145() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 126: {
                // Shift 179.
                token = doShift(token, 179);
                return;
            }

            case 107: {
                // Reduce OptExpression : Expression;
                doReduce1(token, 31);
                Object o1 = doReduce2();

                Expression o = hooks.parseOptExpression2((Expression)o1);

                reduce = true;
                reduceNonTerminal = 31;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 146.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action146() throws IOException {
        switch (token.id) {
            case 107: {
                // Shift 147.
                token = doShift(token, 147);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 147.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action147() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 126: {
                // Reduce OptExpression : ;
                doReduce1(token, 31);
                Expression o = hooks.parseOptExpression1();

                reduce = true;
                reduceNonTerminal = 31;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 148.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action148() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 126: {
                // Reduce OptExpression : Expression;
                doReduce1(token, 31);
                Object o1 = doReduce2();

                Expression o = hooks.parseOptExpression2((Expression)o1);

                reduce = true;
                reduceNonTerminal = 31;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 149.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action149() throws IOException {
        switch (token.id) {
            case 126: {
                // Shift 150.
                token = doShift(token, 150);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 150.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action150() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ProjExpression : ProjExpression SQOPENTK OptExpression COLONTK OptExpression SQCLOSETK;
                doReduce1(token, 38);
                doReduce2();
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseProjExpression3((Expression)o1, (Token)o2, (Expression)o3, (Expression)o5);

                reduce = true;
                reduceNonTerminal = 38;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 151.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action151() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 152.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action152() throws IOException {
        switch (token.id) {
            case 100: {
                // Shift 153.
                token = doShift(token, 153);
                return;
            }

            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 120:
            case 124:
            case 126: {
                // Reduce Expression : Expression ORKW AndExpression;
                doReduce1(token, 32);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 32;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 153.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action153() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 154.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action154() throws IOException {
        switch (token.id) {
            case 112: {
                // Shift 155.
                token = doShift(token, 155);
                return;
            }

            case 114: {
                // Shift 156.
                token = doShift(token, 156);
                return;
            }

            case 115: {
                // Shift 157.
                token = doShift(token, 157);
                return;
            }

            case 116: {
                // Shift 158.
                token = doShift(token, 158);
                return;
            }

            case 117: {
                // Shift 159.
                token = doShift(token, 159);
                return;
            }

            case 119: {
                // Shift 160.
                token = doShift(token, 160);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 120:
            case 124:
            case 126: {
                // Reduce AndExpression : AndExpression ANDKW CompareExpression;
                doReduce1(token, 33);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseAndExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 33;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 155.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action155() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 156.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action156() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 157.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action157() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 158.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action158() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 159.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action159() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 160.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action160() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 161.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action161() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression NETK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression5((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 162.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action162() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 163.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action163() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 164.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action164() throws IOException {
        switch (token.id) {
            case 101: {
                // Shift 165.
                token = doShift(token, 165);
                return;
            }

            case 102: {
                // Shift 166.
                token = doShift(token, 166);
                return;
            }

            case 105: {
                // Shift 167.
                token = doShift(token, 167);
                return;
            }

            case 125: {
                // Shift 168.
                token = doShift(token, 168);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 126: {
                // Reduce AddExpression : AddExpression PLUSTK MulExpression;
                doReduce1(token, 35);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseAddExpression3((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 35;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 165.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action165() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 166.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action166() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 167.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action167() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 168.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action168() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 169.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action169() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce MulExpression : MulExpression SLASHTK UnaryExpression;
                doReduce1(token, 36);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseMulExpression3((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 36;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 170.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action170() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce MulExpression : MulExpression ASTERISKTK UnaryExpression;
                doReduce1(token, 36);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseMulExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 36;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 171.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action171() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce MulExpression : MulExpression MODKW UnaryExpression;
                doReduce1(token, 36);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseMulExpression5((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 36;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 172.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action172() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce MulExpression : MulExpression DIVKW UnaryExpression;
                doReduce1(token, 36);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseMulExpression4((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 36;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 173.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action173() throws IOException {
        switch (token.id) {
            case 101: {
                // Shift 165.
                token = doShift(token, 165);
                return;
            }

            case 102: {
                // Shift 166.
                token = doShift(token, 166);
                return;
            }

            case 105: {
                // Shift 167.
                token = doShift(token, 167);
                return;
            }

            case 125: {
                // Shift 168.
                token = doShift(token, 168);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 126: {
                // Reduce AddExpression : AddExpression MINUSTK MulExpression;
                doReduce1(token, 35);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseAddExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 35;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 174.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action174() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression LTTK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 175.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action175() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression LETK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression3((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 176.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action176() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression GTTK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression7((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 177.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action177() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression GETK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression6((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 178.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action178() throws IOException {
        switch (token.id) {
            case 118: {
                // Shift 162.
                token = doShift(token, 162);
                return;
            }

            case 122: {
                // Shift 163.
                token = doShift(token, 163);
                return;
            }

            case 100:
            case 104:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 119:
            case 120:
            case 124:
            case 126: {
                // Reduce CompareExpression : CompareExpression EQEQTK AddExpression;
                doReduce1(token, 34);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseCompareExpression4((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 34;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 179.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action179() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ProjExpression : ProjExpression SQOPENTK Expression SQCLOSETK;
                doReduce1(token, 38);
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseProjExpression2((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 38;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 180.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action180() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : SQOPENTK SQCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor08((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 181.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action181() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120:
            case 124:
            case 126: {
                // Reduce Expressions : Expression;
                doReduce1(token, 30);
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseExpressions1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 30;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 182.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action182() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 183.
                token = doShift(token, 183);
                return;
            }

            case 126: {
                // Reduce OptComma : ;
                doReduce1(token, 47);
                Token o = hooks.parseOptComma1();

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 183.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action183() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 109:
            case 120:
            case 126: {
                // Reduce OptComma : COMMATK;
                doReduce1(token, 47);
                Object o1 = doReduce2();

                Token o = hooks.parseOptComma2((Token)o1);

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 184.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action184() throws IOException {
        switch (token.id) {
            case 126: {
                // Shift 185.
                token = doShift(token, 185);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 185.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action185() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : SQOPENTK Expressions OptComma SQCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor09((Token)o1, (List<Expression>)o2, (Token)o3);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 186.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action186() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 109:
            case 120:
            case 124:
            case 126: {
                // Reduce Expressions : Expressions COMMATK Expression;
                doReduce1(token, 30);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseExpressions2((List<Expression>)o1, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 30;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 187.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action187() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce UnaryExpression : PLUSTK UnaryExpression;
                doReduce1(token, 37);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseUnaryExpression3((Token)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 37;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 188.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action188() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108: {
                // Shift 189.
                token = doShift(token, 189);
                return;
            }

            case 120: {
                // Shift 190.
                token = doShift(token, 190);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 189.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action189() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 190.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action190() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : PAROPENTK Expression PARCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                Expression o = hooks.parseExpressionFactor14((Expression)o2);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 191.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action191() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 183.
                token = doShift(token, 183);
                return;
            }

            case 120: {
                // Reduce OptComma : ;
                doReduce1(token, 47);
                Token o = hooks.parseOptComma1();

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 192.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action192() throws IOException {
        switch (token.id) {
            case 120: {
                // Shift 193.
                token = doShift(token, 193);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 193.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action193() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : PAROPENTK Expression COMMATK Expressions OptComma PARCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o5 = doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor13((Token)o1, (Expression)o2, (List<Expression>)o4, (Token)o5);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 194.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action194() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce UnaryExpression : MINUSTK UnaryExpression;
                doReduce1(token, 37);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseUnaryExpression2((Token)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 37;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 195.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action195() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : Name;
                doReduce1(token, 29);
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType21((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 196.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action196() throws IOException {
        switch (token.id) {
            case 115: {
                // Shift 197.
                token = doShift(token, 197);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 197.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action197() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 198.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action198() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : LTTK Type GTTK ExpressionFactor;
                doReduce1(token, 39);
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor07((Token)o1, (ToolDefType)o2, (Expression)o4);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 199.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action199() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : CUROPENTK CURCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor10((Token)o1);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 200.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action200() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 107: {
                // Shift 211.
                token = doShift(token, 211);
                return;
            }

            case 108:
            case 109: {
                // Reduce Expressions : Expression;
                doReduce1(token, 30);
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseExpressions1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 30;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 201.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action201() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 183.
                token = doShift(token, 183);
                return;
            }

            case 109: {
                // Reduce OptComma : ;
                doReduce1(token, 47);
                Token o = hooks.parseOptComma1();

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 202.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action202() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 203.
                token = doShift(token, 203);
                return;
            }

            case 109: {
                // Reduce OptComma : ;
                doReduce1(token, 47);
                Token o = hooks.parseOptComma1();

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 203.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action203() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 109: {
                // Reduce OptComma : COMMATK;
                doReduce1(token, 47);
                Object o1 = doReduce2();

                Token o = hooks.parseOptComma2((Token)o1);

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 204.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action204() throws IOException {
        switch (token.id) {
            case 109: {
                // Shift 205.
                token = doShift(token, 205);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 205.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action205() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : CUROPENTK MapEntries OptComma CURCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor12((Token)o1, (List<MapEntry>)o2, (Token)o3);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 206.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action206() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 107: {
                // Shift 207.
                token = doShift(token, 207);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 207.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action207() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 208.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action208() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 109: {
                // Reduce MapEntries : MapEntries COMMATK Expression COLONTK Expression;
                doReduce1(token, 40);
                Object o5 = doReduce2();
                Object o4 = doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<MapEntry> o = hooks.parseMapEntries2((List<MapEntry>)o1, (Expression)o3, (Token)o4, (Expression)o5);

                reduce = true;
                reduceNonTerminal = 40;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 209.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action209() throws IOException {
        switch (token.id) {
            case 109: {
                // Shift 210.
                token = doShift(token, 210);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 210.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action210() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ExpressionFactor : CUROPENTK Expressions OptComma CURCLOSETK;
                doReduce1(token, 39);
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseExpressionFactor11((Token)o1, (List<Expression>)o2, (Token)o3);

                reduce = true;
                reduceNonTerminal = 39;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 211.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action211() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 212.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action212() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 109: {
                // Reduce MapEntries : Expression COLONTK Expression;
                doReduce1(token, 40);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<MapEntry> o = hooks.parseMapEntries1((Expression)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 40;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 213.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action213() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126: {
                // Reduce UnaryExpression : NOTKW UnaryExpression;
                doReduce1(token, 37);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseUnaryExpression4((Token)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 37;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 214.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action214() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 120: {
                // Shift 215.
                token = doShift(token, 215);
                return;
            }

            case 128: {
                // Shift 216.
                token = doShift(token, 216);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 215.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action215() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ToolInvokeExpression : ToolRef PAROPENTK PARCLOSETK;
                doReduce1(token, 41);
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                ToolInvokeExpression o = hooks.parseToolInvokeExpression2((ToolRef)o1, (Token)o2);

                reduce = true;
                reduceNonTerminal = 41;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 216.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action216() throws IOException {
        switch (token.id) {
            case 113: {
                // Shift 226.
                token = doShift(token, 226);
                return;
            }

            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 108:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 121:
            case 122:
            case 125:
            case 127: {
                // Reduce Name : IDENTIFIERTK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName1((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 217.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action217() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolArgs : Expression;
                doReduce1(token, 44);
                Object o1 = doReduce2();

                List<ToolArgument> o = hooks.parseToolArgs1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 44;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 218.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action218() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 219.
                token = doShift(token, 219);
                return;
            }

            case 120: {
                // Reduce OptComma : ;
                doReduce1(token, 47);
                Token o = hooks.parseOptComma1();

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 219.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action219() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            case 128: {
                // Shift 222.
                token = doShift(token, 222);
                return;
            }

            case 120: {
                // Reduce OptComma : COMMATK;
                doReduce1(token, 47);
                Object o1 = doReduce2();

                Token o = hooks.parseOptComma2((Token)o1);

                reduce = true;
                reduceNonTerminal = 47;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 220.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action220() throws IOException {
        switch (token.id) {
            case 120: {
                // Shift 221.
                token = doShift(token, 221);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 221.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action221() throws IOException {
        switch (token.id) {
            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 106:
            case 107:
            case 108:
            case 109:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 122:
            case 124:
            case 125:
            case 126:
            case 127: {
                // Reduce ToolInvokeExpression : ToolRef PAROPENTK ToolArgs OptComma PARCLOSETK;
                doReduce1(token, 41);
                doReduce2();
                Object o4 = doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                ToolInvokeExpression o = hooks.parseToolInvokeExpression1((ToolRef)o1, (Token)o2, (List<ToolArgument>)o3, (Token)o4);

                reduce = true;
                reduceNonTerminal = 41;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 222.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action222() throws IOException {
        switch (token.id) {
            case 113: {
                // Shift 224.
                token = doShift(token, 224);
                return;
            }

            case 100:
            case 101:
            case 102:
            case 104:
            case 105:
            case 108:
            case 112:
            case 114:
            case 115:
            case 116:
            case 117:
            case 118:
            case 119:
            case 120:
            case 121:
            case 122:
            case 125:
            case 127: {
                // Reduce Name : IDENTIFIERTK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName1((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 223.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action223() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolArgs : ToolArgs COMMATK Expression;
                doReduce1(token, 44);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolArgument> o = hooks.parseToolArgs3((List<ToolArgument>)o1, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 44;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 224.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action224() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 225.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action225() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolArgs : ToolArgs COMMATK IDENTIFIERTK EQTK Expression;
                doReduce1(token, 44);
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolArgument> o = hooks.parseToolArgs4((List<ToolArgument>)o1, (Token)o3, (Expression)o5);

                reduce = true;
                reduceNonTerminal = 44;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 226.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action226() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 227.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action227() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolArgs : IDENTIFIERTK EQTK Expression;
                doReduce1(token, 44);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolArgument> o = hooks.parseToolArgs2((Token)o1, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 44;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 228.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action228() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : ToolInvokeExpression SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement13((ToolInvokeExpression)o1);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 229.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action229() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decls : Decls Decl;
                doReduce1(token, 6);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecls2((List<Declaration>)o1, (List<Declaration>)o2);

                reduce = true;
                reduceNonTerminal = 6;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 230.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action230() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 235.
                token = doShift(token, 235);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 231.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action231() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 232.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action232() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 233.
                token = doShift(token, 233);
                return;
            }

            case 124: {
                // Shift 234.
                token = doShift(token, 234);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 233.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action233() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 234.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action234() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : Addressables EQTK Expressions SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement10((List<Expression>)o1, (Token)o2, (List<Expression>)o3);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 235.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action235() throws IOException {
        switch (token.id) {
            case 127: {
                // Shift 237.
                token = doShift(token, 237);
                return;
            }

            case 108:
            case 113:
            case 120: {
                // Reduce Addressable : IDENTIFIERTK;
                doReduce1(token, 25);
                Object o1 = doReduce2();

                Expression o = hooks.parseAddressable1((Token)o1);

                reduce = true;
                reduceNonTerminal = 25;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 236.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action236() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120: {
                // Reduce Addressables : Addressables COMMATK Addressable;
                doReduce1(token, 24);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseAddressables2((List<Expression>)o1, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 24;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 237.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action237() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 238.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action238() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120:
            case 127: {
                // Reduce Projections : Projection;
                doReduce1(token, 26);
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseProjections1((Expression)o1);

                reduce = true;
                reduceNonTerminal = 26;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 239.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action239() throws IOException {
        switch (token.id) {
            case 127: {
                // Shift 237.
                token = doShift(token, 237);
                return;
            }

            case 108:
            case 113:
            case 120: {
                // Reduce Addressable : IDENTIFIERTK Projections;
                doReduce1(token, 25);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseAddressable2((Token)o1, (List<Expression>)o2);

                reduce = true;
                reduceNonTerminal = 25;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 240.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action240() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120:
            case 127: {
                // Reduce Projections : Projections Projection;
                doReduce1(token, 26);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Expression> o = hooks.parseProjections2((List<Expression>)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 26;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 241.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action241() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 126: {
                // Shift 242.
                token = doShift(token, 242);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 242.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action242() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120:
            case 127: {
                // Reduce Projection : SQOPENTK Expression SQCLOSETK;
                doReduce1(token, 27);
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseProjection1((Token)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 27;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 243.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action243() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 244.
                token = doShift(token, 244);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 244.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action244() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 235.
                token = doShift(token, 235);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 245.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action245() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 230.
                token = doShift(token, 230);
                return;
            }

            case 120: {
                // Shift 246.
                token = doShift(token, 246);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 246.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action246() throws IOException {
        switch (token.id) {
            case 108:
            case 113:
            case 120: {
                // Reduce Addressable : PAROPENTK Addressable COMMATK Addressables PARCLOSETK;
                doReduce1(token, 25);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                Expression o = hooks.parseAddressable3((Token)o1, (Expression)o2, (List<Expression>)o4);

                reduce = true;
                reduceNonTerminal = 25;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 247.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action247() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 106: {
                // Shift 248.
                token = doShift(token, 248);
                return;
            }

            case 107: {
                // Shift 249.
                token = doShift(token, 249);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 248.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action248() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 249.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action249() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 250.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action250() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 7: {
                // Shift 251.
                token = doShift(token, 251);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 251.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action251() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : WHILEKW Expression COLONTK OptStatements ENDKW;
                doReduce1(token, 17);
                Object o5 = doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement02((Token)o1, (Expression)o2, (List<Statement>)o4, (Token)o5);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 252.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action252() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : OptStatements Statement;
                doReduce1(token, 16);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseOptStatements2((List<Statement>)o1, (List<Statement>)o2);

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 253.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action253() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : WHILEKW Expression COLONCOLONTK Statement;
                doReduce1(token, 17);
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement03((Token)o1, (Expression)o2, (List<Statement>)o4);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 254.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action254() throws IOException {
        switch (token.id) {
            case 113: {
                // Shift 260.
                token = doShift(token, 260);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 255.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action255() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce TypeDecls : TypeDecl;
                doReduce1(token, 10);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseTypeDecls1((TypeDecl)o1);

                reduce = true;
                reduceNonTerminal = 10;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 256.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action256() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 257.
                token = doShift(token, 257);
                return;
            }

            case 124: {
                // Shift 258.
                token = doShift(token, 258);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 257.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action257() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 254.
                token = doShift(token, 254);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 258.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action258() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decl : TYPEKW TypeDecls SEMICOLTK;
                doReduce1(token, 7);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseDecl2((List<Declaration>)o2);

                reduce = true;
                reduceNonTerminal = 7;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 259.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action259() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce TypeDecls : TypeDecls COMMATK TypeDecl;
                doReduce1(token, 10);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseTypeDecls2((List<Declaration>)o1, (TypeDecl)o3);

                reduce = true;
                reduceNonTerminal = 10;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 260.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action260() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 261.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action261() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce TypeDecl : IDENTIFIERTK EQTK Type;
                doReduce1(token, 11);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                TypeDecl o = hooks.parseTypeDecl1((Token)o1, (ToolDefType)o3);

                reduce = true;
                reduceNonTerminal = 11;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 262.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action262() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 263.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action263() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 264.
                token = doShift(token, 264);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 264.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action264() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 265.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action265() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 266.
                token = doShift(token, 266);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 266.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action266() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 267.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action267() throws IOException {
        switch (token.id) {
            case 108:
            case 120:
            case 128: {
                // Reduce Types : Type;
                doReduce1(token, 28);
                Object o1 = doReduce2();

                List<ToolDefType> o = hooks.parseTypes1((ToolDefType)o1);

                reduce = true;
                reduceNonTerminal = 28;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 268.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action268() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 269.
                token = doShift(token, 269);
                return;
            }

            case 120: {
                // Shift 270.
                token = doShift(token, 270);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 269.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action269() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 270.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action270() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : TUPLEKW QUESTIONTK PAROPENTK Type COMMATK Types PARCLOSETK;
                doReduce1(token, 29);
                doReduce2();
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType18((Token)o1, (ToolDefType)o4, (List<ToolDefType>)o6);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 271.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action271() throws IOException {
        switch (token.id) {
            case 108:
            case 120:
            case 128: {
                // Reduce Types : Types COMMATK Type;
                doReduce1(token, 28);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolDefType> o = hooks.parseTypes2((List<ToolDefType>)o1, (ToolDefType)o3);

                reduce = true;
                reduceNonTerminal = 28;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 272.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action272() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 273.
                token = doShift(token, 273);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 273.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action273() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 274.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action274() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 269.
                token = doShift(token, 269);
                return;
            }

            case 120: {
                // Shift 275.
                token = doShift(token, 275);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 275.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action275() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : TUPLEKW PAROPENTK Type COMMATK Types PARCLOSETK;
                doReduce1(token, 29);
                doReduce2();
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType17((Token)o1, (ToolDefType)o3, (List<ToolDefType>)o5);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 276.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action276() throws IOException {
        switch (token.id) {
            case 117: {
                // Shift 279.
                token = doShift(token, 279);
                return;
            }

            case 121: {
                // Reduce OptTypeParams : ;
                doReduce1(token, 12);
                List<TypeParam> o = hooks.parseOptTypeParams1();

                reduce = true;
                reduceNonTerminal = 12;
                reduceState = doReduce3(o);
                return;
            }

            case 108:
            case 128: {
                // Reduce Name : IDENTIFIERTK;
                doReduce1(token, 46);
                Object o1 = doReduce2();

                Token o = hooks.parseName1((Token)o1);

                reduce = true;
                reduceNonTerminal = 46;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 277.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action277() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 269.
                token = doShift(token, 269);
                return;
            }

            case 128: {
                // Shift 278.
                token = doShift(token, 278);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 278.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action278() throws IOException {
        switch (token.id) {
            case 117: {
                // Shift 279.
                token = doShift(token, 279);
                return;
            }

            case 121: {
                // Reduce OptTypeParams : ;
                doReduce1(token, 12);
                List<TypeParam> o = hooks.parseOptTypeParams1();

                reduce = true;
                reduceNonTerminal = 12;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 279.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action279() throws IOException {
        switch (token.id) {
            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 280.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action280() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 281.
                token = doShift(token, 281);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 281.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action281() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 120: {
                // Shift 286.
                token = doShift(token, 286);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 282.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action282() throws IOException {
        switch (token.id) {
            case 107: {
                // Shift 283.
                token = doShift(token, 283);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 283.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action283() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 284.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action284() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 7: {
                // Shift 285.
                token = doShift(token, 285);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 285.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action285() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decl : TOOLKW Types IDENTIFIERTK OptTypeParams ToolParameters COLONTK OptStatements ENDKW;
                doReduce1(token, 7);
                Object o8 = doReduce2();
                Object o7 = doReduce2();
                doReduce2();
                Object o5 = doReduce2();
                Object o4 = doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecl4((Token)o1, (List<ToolDefType>)o2, (Token)o3, (List<TypeParam>)o4, (List<ToolParameter>)o5, (List<Statement>)o7, (Token)o8);

                reduce = true;
                reduceNonTerminal = 7;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 286.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action286() throws IOException {
        switch (token.id) {
            case 107: {
                // Reduce ToolParameters : PAROPENTK PARCLOSETK;
                doReduce1(token, 13);
                doReduce2();
                doReduce2();

                List<ToolParameter> o = hooks.parseToolParameters1();

                reduce = true;
                reduceNonTerminal = 13;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 287.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action287() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 295.
                token = doShift(token, 295);
                return;
            }

            case 120: {
                // Shift 296.
                token = doShift(token, 296);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 288.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action288() throws IOException {
        switch (token.id) {
            case 111: {
                // Shift 289.
                token = doShift(token, 289);
                return;
            }

            case 128: {
                // Shift 290.
                token = doShift(token, 290);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 289.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action289() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 290.
                token = doShift(token, 290);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 290.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action290() throws IOException {
        switch (token.id) {
            case 113: {
                // Shift 292.
                token = doShift(token, 292);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolParam : IDENTIFIERTK;
                doReduce1(token, 15);
                Object o1 = doReduce2();

                ToolParameter o = hooks.parseToolParam1((Token)o1);

                reduce = true;
                reduceNonTerminal = 15;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 291.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action291() throws IOException {
        switch (token.id) {
            case 108:
            case 120: {
                // Reduce ToolParams : Type ToolParam;
                doReduce1(token, 14);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<ToolParameter> o = hooks.parseToolParams1((ToolDefType)o1, (ToolParameter)o2);

                reduce = true;
                reduceNonTerminal = 14;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 292.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action292() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 293.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action293() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 108:
            case 120: {
                // Reduce ToolParam : IDENTIFIERTK EQTK Expression;
                doReduce1(token, 15);
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                ToolParameter o = hooks.parseToolParam2((Token)o1, (Token)o2, (Expression)o3);

                reduce = true;
                reduceNonTerminal = 15;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 294.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action294() throws IOException {
        switch (token.id) {
            case 108:
            case 120: {
                // Reduce ToolParams : Type DOTSTK ToolParam;
                doReduce1(token, 14);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolParameter> o = hooks.parseToolParams2((ToolDefType)o1, (ToolParameter)o3);

                reduce = true;
                reduceNonTerminal = 14;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 295.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action295() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 296.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action296() throws IOException {
        switch (token.id) {
            case 107: {
                // Reduce ToolParameters : PAROPENTK ToolParams PARCLOSETK;
                doReduce1(token, 13);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<ToolParameter> o = hooks.parseToolParameters2((List<ToolParameter>)o2);

                reduce = true;
                reduceNonTerminal = 13;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 297.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action297() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 290.
                token = doShift(token, 290);
                return;
            }

            case 111: {
                // Shift 298.
                token = doShift(token, 298);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 298.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action298() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 290.
                token = doShift(token, 290);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 299.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action299() throws IOException {
        switch (token.id) {
            case 108:
            case 120: {
                // Reduce ToolParams : ToolParams COMMATK Type ToolParam;
                doReduce1(token, 14);
                Object o4 = doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolParameter> o = hooks.parseToolParams3((List<ToolParameter>)o1, (ToolDefType)o3, (ToolParameter)o4);

                reduce = true;
                reduceNonTerminal = 14;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 300.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action300() throws IOException {
        switch (token.id) {
            case 108:
            case 120: {
                // Reduce ToolParams : ToolParams COMMATK Type DOTSTK ToolParam;
                doReduce1(token, 14);
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<ToolParameter> o = hooks.parseToolParams4((List<ToolParameter>)o1, (ToolDefType)o3, (ToolParameter)o5);

                reduce = true;
                reduceNonTerminal = 14;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 301.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action301() throws IOException {
        switch (token.id) {
            case 108:
            case 115: {
                // Reduce Names : Name;
                doReduce1(token, 45);
                Object o1 = doReduce2();

                List<Token> o = hooks.parseNames1((Token)o1);

                reduce = true;
                reduceNonTerminal = 45;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 302.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action302() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 303.
                token = doShift(token, 303);
                return;
            }

            case 115: {
                // Shift 304.
                token = doShift(token, 304);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 303.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action303() throws IOException {
        switch (token.id) {
            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 304.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action304() throws IOException {
        switch (token.id) {
            case 121: {
                // Reduce OptTypeParams : LTTK Names GTTK;
                doReduce1(token, 12);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<TypeParam> o = hooks.parseOptTypeParams2((List<Token>)o2);

                reduce = true;
                reduceNonTerminal = 12;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 305.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action305() throws IOException {
        switch (token.id) {
            case 108:
            case 115: {
                // Reduce Names : Names COMMATK Name;
                doReduce1(token, 45);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Token> o = hooks.parseNames2((List<Token>)o1, (Token)o3);

                reduce = true;
                reduceNonTerminal = 45;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 306.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action306() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 281.
                token = doShift(token, 281);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 307.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action307() throws IOException {
        switch (token.id) {
            case 107: {
                // Shift 308.
                token = doShift(token, 308);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 308.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action308() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 309.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action309() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 7: {
                // Shift 310.
                token = doShift(token, 310);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 310.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action310() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Decl : TOOLKW IDENTIFIERTK OptTypeParams ToolParameters COLONTK OptStatements ENDKW;
                doReduce1(token, 7);
                Object o7 = doReduce2();
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseDecl3((Token)o1, (Token)o2, (List<TypeParam>)o3, (List<ToolParameter>)o4, (List<Statement>)o6, (Token)o7);

                reduce = true;
                reduceNonTerminal = 7;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 311.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action311() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : STRINGKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType10((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 312.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action312() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 313.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action313() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : SETKW Type;
                doReduce1(token, 29);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType13((Token)o1, (ToolDefType)o2);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 314.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action314() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : SETKW QUESTIONTK Type;
                doReduce1(token, 29);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType14((Token)o1, (ToolDefType)o3);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 315.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action315() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : RETURNKW SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement11((Token)o1);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 316.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action316() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 233.
                token = doShift(token, 233);
                return;
            }

            case 124: {
                // Shift 317.
                token = doShift(token, 317);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 317.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action317() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : RETURNKW Expressions SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement12((Token)o1, (List<Expression>)o2);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 318.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action318() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : OBJECTKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType20((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 319.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action319() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 320.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action320() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 321.
                token = doShift(token, 321);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 321.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action321() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 322.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action322() throws IOException {
        switch (token.id) {
            case 107: {
                // Shift 323.
                token = doShift(token, 323);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 323.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action323() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 324.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action324() throws IOException {
        switch (token.id) {
            case 120: {
                // Shift 325.
                token = doShift(token, 325);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 325.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action325() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : MAPKW QUESTIONTK PAROPENTK Type COLONTK Type PARCLOSETK;
                doReduce1(token, 29);
                doReduce2();
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType16((Token)o1, (ToolDefType)o4, (ToolDefType)o6);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 326.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action326() throws IOException {
        switch (token.id) {
            case 107: {
                // Shift 327.
                token = doShift(token, 327);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 327.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action327() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 328.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action328() throws IOException {
        switch (token.id) {
            case 120: {
                // Shift 329.
                token = doShift(token, 329);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 329.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action329() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : MAPKW PAROPENTK Type COLONTK Type PARCLOSETK;
                doReduce1(token, 29);
                doReduce2();
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType15((Token)o1, (ToolDefType)o3, (ToolDefType)o5);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 330.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action330() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : LONGKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType06((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 331.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action331() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 332.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action332() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : LISTKW Type;
                doReduce1(token, 29);
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType11((Token)o1, (ToolDefType)o2);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 333.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action333() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : LISTKW QUESTIONTK Type;
                doReduce1(token, 29);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType12((Token)o1, (ToolDefType)o3);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 334.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action334() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : INTKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType04((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 335.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action335() throws IOException {
        switch (token.id) {
            case 0: {
                // Shift 347.
                token = doShift(token, 347);
                return;
            }

            case 124: {
                // Shift 348.
                token = doShift(token, 348);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 336.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action336() throws IOException {
        switch (token.id) {
            case 0: {
                // Shift 337.
                token = doShift(token, 337);
                return;
            }

            case 107: {
                // Shift 338.
                token = doShift(token, 338);
                return;
            }

            case 124: {
                // Shift 339.
                token = doShift(token, 339);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 337.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action337() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 345.
                token = doShift(token, 345);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 338.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action338() throws IOException {
        switch (token.id) {
            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 339.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action339() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW Name SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport3((Token)o2);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 340.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action340() throws IOException {
        switch (token.id) {
            case 0: {
                // Shift 341.
                token = doShift(token, 341);
                return;
            }

            case 124: {
                // Shift 342.
                token = doShift(token, 342);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 341.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action341() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 343.
                token = doShift(token, 343);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 342.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action342() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW Name COLONTK Name SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport5((Token)o2, (Token)o4);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 343.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action343() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 344.
                token = doShift(token, 344);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 344.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action344() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW Name COLONTK Name ASKW IDENTIFIERTK SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport6((Token)o2, (Token)o4, (Token)o6);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 345.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action345() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 346.
                token = doShift(token, 346);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 346.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action346() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW Name ASKW IDENTIFIERTK SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport4((Token)o2, (Token)o4);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 347.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action347() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 349.
                token = doShift(token, 349);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 348.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action348() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW STRINGTK SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport1((Token)o2);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 349.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action349() throws IOException {
        switch (token.id) {
            case 124: {
                // Shift 350.
                token = doShift(token, 350);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 350.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action350() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : IMPORTKW STRINGTK ASKW IDENTIFIERTK SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport2((Token)o2, (Token)o4);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 351.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action351() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 106: {
                // Shift 352.
                token = doShift(token, 352);
                return;
            }

            case 107: {
                // Shift 353.
                token = doShift(token, 353);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 352.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action352() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 353.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action353() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 354.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action354() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 5:
            case 6:
            case 7: {
                // Reduce OptElifStatements : ;
                doReduce1(token, 20);
                List<ElifStatement> o = hooks.parseOptElifStatements1();

                reduce = true;
                reduceNonTerminal = 20;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 355.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action355() throws IOException {
        switch (token.id) {
            case 5: {
                // Shift 356.
                token = doShift(token, 356);
                return;
            }

            case 6: {
                // Shift 357.
                token = doShift(token, 357);
                return;
            }

            case 7: {
                // Reduce OptElseStatement : ;
                doReduce1(token, 21);
                List<Statement> o = hooks.parseOptElseStatement1();

                reduce = true;
                reduceNonTerminal = 21;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 356.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action356() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 357.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action357() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 358.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action358() throws IOException {
        switch (token.id) {
            case 7: {
                // Shift 359.
                token = doShift(token, 359);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 359.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action359() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : IFKW Expression COLONTK OptStatements OptElifStatements OptElseStatement ENDKW;
                doReduce1(token, 17);
                Object o7 = doReduce2();
                Object o6 = doReduce2();
                Object o5 = doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement06((Token)o1, (Expression)o2, (List<Statement>)o4, (List<ElifStatement>)o5, (List<Statement>)o6, (Token)o7);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 360.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action360() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 7: {
                // Reduce OptElseStatement : ELSEKW OptStatements;
                doReduce1(token, 21);
                Object o2 = doReduce2();
                doReduce2();

                List<Statement> o = hooks.parseOptElseStatement2((List<Statement>)o2);

                reduce = true;
                reduceNonTerminal = 21;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 361.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action361() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 107: {
                // Shift 362.
                token = doShift(token, 362);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 362.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action362() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 363.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action363() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 5:
            case 6:
            case 7: {
                // Reduce OptElifStatements : OptElifStatements ELIFKW Expression COLONTK OptStatements;
                doReduce1(token, 20);
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<ElifStatement> o = hooks.parseOptElifStatements2((List<ElifStatement>)o1, (Token)o2, (Expression)o3, (List<Statement>)o5);

                reduce = true;
                reduceNonTerminal = 20;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 364.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action364() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : IFKW Expression COLONCOLONTK Statement;
                doReduce1(token, 17);
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement07((Token)o1, (Expression)o2, (List<Statement>)o4);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 365.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action365() throws IOException {
        switch (token.id) {
            case 13: {
                // Shift 366.
                token = doShift(token, 366);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 366.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action366() throws IOException {
        switch (token.id) {
            case 105: {
                // Shift 367.
                token = doShift(token, 367);
                return;
            }

            case 128: {
                // Shift 368.
                token = doShift(token, 368);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 367.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action367() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce ImportParts : ASTERISKTK;
                doReduce1(token, 9);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts1((Token)o1);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 368.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action368() throws IOException {
        switch (token.id) {
            case 0: {
                // Shift 376.
                token = doShift(token, 376);
                return;
            }

            case 108:
            case 124: {
                // Reduce ImportParts : IDENTIFIERTK;
                doReduce1(token, 9);
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts2((Token)o1);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 369.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action369() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 370.
                token = doShift(token, 370);
                return;
            }

            case 124: {
                // Shift 371.
                token = doShift(token, 371);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 370.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action370() throws IOException {
        switch (token.id) {
            case 105: {
                // Shift 372.
                token = doShift(token, 372);
                return;
            }

            case 128: {
                // Shift 373.
                token = doShift(token, 373);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 371.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action371() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Import : FROMKW STRINGTK IMPORTKW ImportParts SEMICOLTK;
                doReduce1(token, 8);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                doReduce2();

                List<Declaration> o = hooks.parseImport7((Token)o2, (List<Declaration>)o4);

                reduce = true;
                reduceNonTerminal = 8;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 372.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action372() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce ImportParts : ImportParts COMMATK ASTERISKTK;
                doReduce1(token, 9);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts4((List<Declaration>)o1, (Token)o3);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 373.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action373() throws IOException {
        switch (token.id) {
            case 0: {
                // Shift 374.
                token = doShift(token, 374);
                return;
            }

            case 108:
            case 124: {
                // Reduce ImportParts : ImportParts COMMATK IDENTIFIERTK;
                doReduce1(token, 9);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts5((List<Declaration>)o1, (Token)o3);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 374.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action374() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 375.
                token = doShift(token, 375);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 375.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action375() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce ImportParts : ImportParts COMMATK IDENTIFIERTK ASKW IDENTIFIERTK;
                doReduce1(token, 9);
                Object o5 = doReduce2();
                doReduce2();
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts6((List<Declaration>)o1, (Token)o3, (Token)o5);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 376.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action376() throws IOException {
        switch (token.id) {
            case 128: {
                // Shift 377.
                token = doShift(token, 377);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 377.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action377() throws IOException {
        switch (token.id) {
            case 108:
            case 124: {
                // Reduce ImportParts : IDENTIFIERTK ASKW IDENTIFIERTK;
                doReduce1(token, 9);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<Declaration> o = hooks.parseImportParts3((Token)o1, (Token)o3);

                reduce = true;
                reduceNonTerminal = 9;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 378.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action378() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 378.
                token = doShift(token, 378);
                return;
            }

            case 128: {
                // Shift 379.
                token = doShift(token, 379);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 379.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action379() throws IOException {
        switch (token.id) {
            case 14:
            case 108:
            case 120: {
                // Reduce AddressableDecl : IDENTIFIERTK;
                doReduce1(token, 23);
                Object o1 = doReduce2();

                AddressableDecl o = hooks.parseAddressableDecl1((Token)o1);

                reduce = true;
                reduceNonTerminal = 23;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 380.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action380() throws IOException {
        switch (token.id) {
            case 14:
            case 108:
            case 120: {
                // Reduce AddressableDecls : AddressableDecl;
                doReduce1(token, 22);
                Object o1 = doReduce2();

                List<AddressableDecl> o = hooks.parseAddressableDecls1((AddressableDecl)o1);

                reduce = true;
                reduceNonTerminal = 22;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 381.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action381() throws IOException {
        switch (token.id) {
            case 14: {
                // Shift 382.
                token = doShift(token, 382);
                return;
            }

            case 108: {
                // Shift 383.
                token = doShift(token, 383);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 382.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action382() throws IOException {
        switch (token.id) {
            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 9: {
                // Shift 120.
                token = doShift(token, 120);
                return;
            }

            case 19: {
                // Shift 121.
                token = doShift(token, 121);
                return;
            }

            case 25: {
                // Shift 122.
                token = doShift(token, 122);
                return;
            }

            case 103: {
                // Shift 123.
                token = doShift(token, 123);
                return;
            }

            case 110: {
                // Shift 124.
                token = doShift(token, 124);
                return;
            }

            case 117: {
                // Shift 125.
                token = doShift(token, 125);
                return;
            }

            case 118: {
                // Shift 126.
                token = doShift(token, 126);
                return;
            }

            case 121: {
                // Shift 127.
                token = doShift(token, 127);
                return;
            }

            case 122: {
                // Shift 128.
                token = doShift(token, 128);
                return;
            }

            case 127: {
                // Shift 129.
                token = doShift(token, 129);
                return;
            }

            case 128: {
                // Shift 130.
                token = doShift(token, 130);
                return;
            }

            case 130: {
                // Shift 131.
                token = doShift(token, 131);
                return;
            }

            case 131: {
                // Shift 132.
                token = doShift(token, 132);
                return;
            }

            case 132: {
                // Shift 133.
                token = doShift(token, 133);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 383.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action383() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 378.
                token = doShift(token, 378);
                return;
            }

            case 128: {
                // Shift 379.
                token = doShift(token, 379);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 384.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action384() throws IOException {
        switch (token.id) {
            case 14:
            case 108:
            case 120: {
                // Reduce AddressableDecls : AddressableDecls COMMATK AddressableDecl;
                doReduce1(token, 22);
                Object o3 = doReduce2();
                doReduce2();
                Object o1 = doReduce2();

                List<AddressableDecl> o = hooks.parseAddressableDecls2((List<AddressableDecl>)o1, (AddressableDecl)o3);

                reduce = true;
                reduceNonTerminal = 22;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 385.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action385() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 106: {
                // Shift 386.
                token = doShift(token, 386);
                return;
            }

            case 107: {
                // Shift 387.
                token = doShift(token, 387);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 386.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action386() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 387.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action387() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 7:
            case 8:
            case 10:
            case 12:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 26:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129: {
                // Reduce OptStatements : ;
                doReduce1(token, 16);
                List<Statement> o = hooks.parseOptStatements1();

                reduce = true;
                reduceNonTerminal = 16;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 388.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action388() throws IOException {
        switch (token.id) {
            case 1: {
                // Shift 1.
                token = doShift(token, 1);
                return;
            }

            case 2: {
                // Shift 2.
                token = doShift(token, 2);
                return;
            }

            case 3: {
                // Shift 3.
                token = doShift(token, 3);
                return;
            }

            case 4: {
                // Shift 4.
                token = doShift(token, 4);
                return;
            }

            case 8: {
                // Shift 5.
                token = doShift(token, 5);
                return;
            }

            case 10: {
                // Shift 6.
                token = doShift(token, 6);
                return;
            }

            case 12: {
                // Shift 8.
                token = doShift(token, 8);
                return;
            }

            case 15: {
                // Shift 10.
                token = doShift(token, 10);
                return;
            }

            case 16: {
                // Shift 11.
                token = doShift(token, 11);
                return;
            }

            case 17: {
                // Shift 12.
                token = doShift(token, 12);
                return;
            }

            case 18: {
                // Shift 13.
                token = doShift(token, 13);
                return;
            }

            case 20: {
                // Shift 14.
                token = doShift(token, 14);
                return;
            }

            case 21: {
                // Shift 15.
                token = doShift(token, 15);
                return;
            }

            case 22: {
                // Shift 16.
                token = doShift(token, 16);
                return;
            }

            case 23: {
                // Shift 17.
                token = doShift(token, 17);
                return;
            }

            case 26: {
                // Shift 19.
                token = doShift(token, 19);
                return;
            }

            case 28: {
                // Shift 21.
                token = doShift(token, 21);
                return;
            }

            case 29: {
                // Shift 22.
                token = doShift(token, 22);
                return;
            }

            case 30: {
                // Shift 23.
                token = doShift(token, 23);
                return;
            }

            case 31: {
                // Shift 24.
                token = doShift(token, 24);
                return;
            }

            case 32: {
                // Shift 25.
                token = doShift(token, 25);
                return;
            }

            case 33: {
                // Shift 26.
                token = doShift(token, 26);
                return;
            }

            case 34: {
                // Shift 27.
                token = doShift(token, 27);
                return;
            }

            case 35: {
                // Shift 28.
                token = doShift(token, 28);
                return;
            }

            case 36: {
                // Shift 29.
                token = doShift(token, 29);
                return;
            }

            case 37: {
                // Shift 30.
                token = doShift(token, 30);
                return;
            }

            case 38: {
                // Shift 31.
                token = doShift(token, 31);
                return;
            }

            case 39: {
                // Shift 32.
                token = doShift(token, 32);
                return;
            }

            case 40: {
                // Shift 33.
                token = doShift(token, 33);
                return;
            }

            case 41: {
                // Shift 34.
                token = doShift(token, 34);
                return;
            }

            case 42: {
                // Shift 35.
                token = doShift(token, 35);
                return;
            }

            case 43: {
                // Shift 36.
                token = doShift(token, 36);
                return;
            }

            case 44: {
                // Shift 37.
                token = doShift(token, 37);
                return;
            }

            case 45: {
                // Shift 38.
                token = doShift(token, 38);
                return;
            }

            case 46: {
                // Shift 39.
                token = doShift(token, 39);
                return;
            }

            case 47: {
                // Shift 40.
                token = doShift(token, 40);
                return;
            }

            case 48: {
                // Shift 41.
                token = doShift(token, 41);
                return;
            }

            case 49: {
                // Shift 42.
                token = doShift(token, 42);
                return;
            }

            case 50: {
                // Shift 43.
                token = doShift(token, 43);
                return;
            }

            case 51: {
                // Shift 44.
                token = doShift(token, 44);
                return;
            }

            case 52: {
                // Shift 45.
                token = doShift(token, 45);
                return;
            }

            case 53: {
                // Shift 46.
                token = doShift(token, 46);
                return;
            }

            case 54: {
                // Shift 47.
                token = doShift(token, 47);
                return;
            }

            case 55: {
                // Shift 48.
                token = doShift(token, 48);
                return;
            }

            case 56: {
                // Shift 49.
                token = doShift(token, 49);
                return;
            }

            case 57: {
                // Shift 50.
                token = doShift(token, 50);
                return;
            }

            case 58: {
                // Shift 51.
                token = doShift(token, 51);
                return;
            }

            case 59: {
                // Shift 52.
                token = doShift(token, 52);
                return;
            }

            case 60: {
                // Shift 53.
                token = doShift(token, 53);
                return;
            }

            case 61: {
                // Shift 54.
                token = doShift(token, 54);
                return;
            }

            case 62: {
                // Shift 55.
                token = doShift(token, 55);
                return;
            }

            case 63: {
                // Shift 56.
                token = doShift(token, 56);
                return;
            }

            case 64: {
                // Shift 57.
                token = doShift(token, 57);
                return;
            }

            case 65: {
                // Shift 58.
                token = doShift(token, 58);
                return;
            }

            case 66: {
                // Shift 59.
                token = doShift(token, 59);
                return;
            }

            case 67: {
                // Shift 60.
                token = doShift(token, 60);
                return;
            }

            case 68: {
                // Shift 61.
                token = doShift(token, 61);
                return;
            }

            case 69: {
                // Shift 62.
                token = doShift(token, 62);
                return;
            }

            case 70: {
                // Shift 63.
                token = doShift(token, 63);
                return;
            }

            case 71: {
                // Shift 64.
                token = doShift(token, 64);
                return;
            }

            case 72: {
                // Shift 65.
                token = doShift(token, 65);
                return;
            }

            case 73: {
                // Shift 66.
                token = doShift(token, 66);
                return;
            }

            case 74: {
                // Shift 67.
                token = doShift(token, 67);
                return;
            }

            case 75: {
                // Shift 68.
                token = doShift(token, 68);
                return;
            }

            case 76: {
                // Shift 69.
                token = doShift(token, 69);
                return;
            }

            case 77: {
                // Shift 70.
                token = doShift(token, 70);
                return;
            }

            case 78: {
                // Shift 71.
                token = doShift(token, 71);
                return;
            }

            case 79: {
                // Shift 72.
                token = doShift(token, 72);
                return;
            }

            case 80: {
                // Shift 73.
                token = doShift(token, 73);
                return;
            }

            case 81: {
                // Shift 74.
                token = doShift(token, 74);
                return;
            }

            case 82: {
                // Shift 75.
                token = doShift(token, 75);
                return;
            }

            case 83: {
                // Shift 76.
                token = doShift(token, 76);
                return;
            }

            case 84: {
                // Shift 77.
                token = doShift(token, 77);
                return;
            }

            case 85: {
                // Shift 78.
                token = doShift(token, 78);
                return;
            }

            case 86: {
                // Shift 79.
                token = doShift(token, 79);
                return;
            }

            case 87: {
                // Shift 80.
                token = doShift(token, 80);
                return;
            }

            case 88: {
                // Shift 81.
                token = doShift(token, 81);
                return;
            }

            case 89: {
                // Shift 82.
                token = doShift(token, 82);
                return;
            }

            case 90: {
                // Shift 83.
                token = doShift(token, 83);
                return;
            }

            case 91: {
                // Shift 84.
                token = doShift(token, 84);
                return;
            }

            case 92: {
                // Shift 85.
                token = doShift(token, 85);
                return;
            }

            case 93: {
                // Shift 86.
                token = doShift(token, 86);
                return;
            }

            case 94: {
                // Shift 87.
                token = doShift(token, 87);
                return;
            }

            case 95: {
                // Shift 88.
                token = doShift(token, 88);
                return;
            }

            case 96: {
                // Shift 89.
                token = doShift(token, 89);
                return;
            }

            case 97: {
                // Shift 90.
                token = doShift(token, 90);
                return;
            }

            case 98: {
                // Shift 91.
                token = doShift(token, 91);
                return;
            }

            case 99: {
                // Shift 92.
                token = doShift(token, 92);
                return;
            }

            case 121: {
                // Shift 93.
                token = doShift(token, 93);
                return;
            }

            case 128: {
                // Shift 94.
                token = doShift(token, 94);
                return;
            }

            case 129: {
                // Shift 95.
                token = doShift(token, 95);
                return;
            }

            case 7: {
                // Shift 389.
                token = doShift(token, 389);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 389.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action389() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : FORKW AddressableDecls INKW Expression COLONTK OptStatements ENDKW;
                doReduce1(token, 17);
                Object o7 = doReduce2();
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement04((Token)o1, (List<AddressableDecl>)o2, (Expression)o4, (List<Statement>)o6, (Token)o7);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 390.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action390() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : FORKW AddressableDecls INKW Expression COLONCOLONTK Statement;
                doReduce1(token, 17);
                Object o6 = doReduce2();
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement05((Token)o1, (List<AddressableDecl>)o2, (Expression)o4, (List<Statement>)o6);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 391.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action391() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 392.
                token = doShift(token, 392);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 392.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action392() throws IOException {
        switch (token.id) {
            case 121: {
                // Shift 378.
                token = doShift(token, 378);
                return;
            }

            case 128: {
                // Shift 379.
                token = doShift(token, 379);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 393.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action393() throws IOException {
        switch (token.id) {
            case 108: {
                // Shift 383.
                token = doShift(token, 383);
                return;
            }

            case 120: {
                // Shift 394.
                token = doShift(token, 394);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 394.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action394() throws IOException {
        switch (token.id) {
            case 14:
            case 108:
            case 120: {
                // Reduce AddressableDecl : PAROPENTK AddressableDecl COMMATK AddressableDecls PARCLOSETK;
                doReduce1(token, 23);
                doReduce2();
                Object o4 = doReduce2();
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                AddressableDecl o = hooks.parseAddressableDecl2((Token)o1, (AddressableDecl)o2, (List<AddressableDecl>)o4);

                reduce = true;
                reduceNonTerminal = 23;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 395.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action395() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : EXITKW SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement14((Token)o1);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 396.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action396() throws IOException {
        switch (token.id) {
            case 104: {
                // Shift 151.
                token = doShift(token, 151);
                return;
            }

            case 124: {
                // Shift 397.
                token = doShift(token, 397);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 397.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action397() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : EXITKW Expression SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o2 = doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement15((Token)o1, (Expression)o2);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 398.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action398() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : DOUBLEKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType08((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 399.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action399() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : CONTINUEKW SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement09((Token)o1);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 400.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action400() throws IOException {
        switch (token.id) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 10:
            case 11:
            case 12:
            case 13:
            case 15:
            case 16:
            case 17:
            case 18:
            case 20:
            case 21:
            case 22:
            case 23:
            case 24:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
            case 63:
            case 64:
            case 65:
            case 66:
            case 67:
            case 68:
            case 69:
            case 70:
            case 71:
            case 72:
            case 73:
            case 74:
            case 75:
            case 76:
            case 77:
            case 78:
            case 79:
            case 80:
            case 81:
            case 82:
            case 83:
            case 84:
            case 85:
            case 86:
            case 87:
            case 88:
            case 89:
            case 90:
            case 91:
            case 92:
            case 93:
            case 94:
            case 95:
            case 96:
            case 97:
            case 98:
            case 99:
            case 121:
            case 128:
            case 129:
            case 136: {
                // Reduce Statement : BREAKKW SEMICOLTK;
                doReduce1(token, 17);
                doReduce2();
                Object o1 = doReduce2();

                List<Statement> o = hooks.parseStatement08((Token)o1);

                reduce = true;
                reduceNonTerminal = 17;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /**
     * Parser action code for parser state 401.
     *
     * @throws IOException If reading the input failed due to an I/O error.
     */
    private final void action401() throws IOException {
        switch (token.id) {
            case 107:
            case 108:
            case 111:
            case 115:
            case 120:
            case 124:
            case 128: {
                // Reduce Type : BOOLKW QUESTIONTK;
                doReduce1(token, 29);
                doReduce2();
                Object o1 = doReduce2();

                ToolDefType o = hooks.parseType02((Token)o1);

                reduce = true;
                reduceNonTerminal = 29;
                reduceState = doReduce3(o);
                return;
            }

            default:
                parsingFailed(token);
        }
    }

    /** Parser goto code for parser state 0. */
    private final void goto0() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 5:
                // Script
                doGoto(108);
                return;

            case 6:
                // Decls
                doGoto(105);
                return;

            case 7:
                // Decl
                doGoto(104);
                return;

            case 8:
                // Import
                doGoto(106);
                return;

            case 17:
                // Statement
                doGoto(109);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 1. */
    private final void goto1() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 2. */
    private final void goto2() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 3. */
    private final void goto3() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 4. */
    private final void goto4() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 5. */
    private final void goto5() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(396);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 6. */
    private final void goto6() {
        switch (reduceNonTerminal) {
            case 22:
                // AddressableDecls
                doGoto(381);
                return;

            case 23:
                // AddressableDecl
                doGoto(380);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 7. */
    private final void goto7() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 8. */
    private final void goto8() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(351);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 9. */
    private final void goto9() {
        switch (reduceNonTerminal) {
            case 46:
                // Name
                doGoto(336);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 10. */
    private final void goto10() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 11. */
    private final void goto11() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(332);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 12. */
    private final void goto12() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 13. */
    private final void goto13() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 14. */
    private final void goto14() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 15. */
    private final void goto15() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 30:
                // Expressions
                doGoto(316);
                return;

            case 32:
                // Expression
                doGoto(181);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 16. */
    private final void goto16() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(313);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 17. */
    private final void goto17() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 18. */
    private final void goto18() {
        switch (reduceNonTerminal) {
            case 28:
                // Types
                doGoto(277);
                return;

            case 29:
                // Type
                doGoto(267);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 19. */
    private final void goto19() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 20. */
    private final void goto20() {
        switch (reduceNonTerminal) {
            case 10:
                // TypeDecls
                doGoto(256);
                return;

            case 11:
                // TypeDecl
                doGoto(255);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 21. */
    private final void goto21() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(247);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 22. */
    private final void goto22() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 23. */
    private final void goto23() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 24. */
    private final void goto24() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 25. */
    private final void goto25() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 26. */
    private final void goto26() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 27. */
    private final void goto27() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 28. */
    private final void goto28() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 29. */
    private final void goto29() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 30. */
    private final void goto30() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 31. */
    private final void goto31() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 32. */
    private final void goto32() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 33. */
    private final void goto33() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 34. */
    private final void goto34() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 35. */
    private final void goto35() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 36. */
    private final void goto36() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 37. */
    private final void goto37() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 38. */
    private final void goto38() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 39. */
    private final void goto39() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 40. */
    private final void goto40() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 41. */
    private final void goto41() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 42. */
    private final void goto42() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 43. */
    private final void goto43() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 44. */
    private final void goto44() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 45. */
    private final void goto45() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 46. */
    private final void goto46() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 47. */
    private final void goto47() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 48. */
    private final void goto48() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 49. */
    private final void goto49() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 50. */
    private final void goto50() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 51. */
    private final void goto51() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 52. */
    private final void goto52() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 53. */
    private final void goto53() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 54. */
    private final void goto54() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 55. */
    private final void goto55() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 56. */
    private final void goto56() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 57. */
    private final void goto57() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 58. */
    private final void goto58() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 59. */
    private final void goto59() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 60. */
    private final void goto60() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 61. */
    private final void goto61() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 62. */
    private final void goto62() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 63. */
    private final void goto63() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 64. */
    private final void goto64() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 65. */
    private final void goto65() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 66. */
    private final void goto66() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 67. */
    private final void goto67() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 68. */
    private final void goto68() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 69. */
    private final void goto69() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 70. */
    private final void goto70() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 71. */
    private final void goto71() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 72. */
    private final void goto72() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 73. */
    private final void goto73() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 74. */
    private final void goto74() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 75. */
    private final void goto75() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 76. */
    private final void goto76() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 77. */
    private final void goto77() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 78. */
    private final void goto78() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 79. */
    private final void goto79() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 80. */
    private final void goto80() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 81. */
    private final void goto81() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 82. */
    private final void goto82() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 83. */
    private final void goto83() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 84. */
    private final void goto84() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 85. */
    private final void goto85() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 86. */
    private final void goto86() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 87. */
    private final void goto87() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 88. */
    private final void goto88() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 89. */
    private final void goto89() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 90. */
    private final void goto90() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 91. */
    private final void goto91() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 92. */
    private final void goto92() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 93. */
    private final void goto93() {
        switch (reduceNonTerminal) {
            case 25:
                // Addressable
                doGoto(243);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 94. */
    private final void goto94() {
        switch (reduceNonTerminal) {
            case 26:
                // Projections
                doGoto(239);
                return;

            case 27:
                // Projection
                doGoto(238);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 95. */
    private final void goto95() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 96. */
    private final void goto96() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 97. */
    private final void goto97() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 98. */
    private final void goto98() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 99. */
    private final void goto99() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 100. */
    private final void goto100() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 101. */
    private final void goto101() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 102. */
    private final void goto102() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 103. */
    private final void goto103() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 104. */
    private final void goto104() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 105. */
    private final void goto105() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 7:
                // Decl
                doGoto(229);
                return;

            case 8:
                // Import
                doGoto(106);
                return;

            case 17:
                // Statement
                doGoto(109);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 106. */
    private final void goto106() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 107. */
    private final void goto107() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 108. */
    private final void goto108() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 109. */
    private final void goto109() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 110. */
    private final void goto110() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 111. */
    private final void goto111() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 112. */
    private final void goto112() {
        switch (reduceNonTerminal) {
            case 18:
                // VarDecls
                doGoto(115);
                return;

            case 19:
                // VarDecl
                doGoto(114);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 113. */
    private final void goto113() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 114. */
    private final void goto114() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 115. */
    private final void goto115() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 116. */
    private final void goto116() {
        switch (reduceNonTerminal) {
            case 19:
                // VarDecl
                doGoto(118);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 117. */
    private final void goto117() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 118. */
    private final void goto118() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 119. */
    private final void goto119() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(137);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 120. */
    private final void goto120() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 121. */
    private final void goto121() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 122. */
    private final void goto122() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 123. */
    private final void goto123() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(213);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 124. */
    private final void goto124() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 30:
                // Expressions
                doGoto(201);
                return;

            case 32:
                // Expression
                doGoto(200);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 40:
                // MapEntries
                doGoto(202);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 125. */
    private final void goto125() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(196);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 126. */
    private final void goto126() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(194);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 127. */
    private final void goto127() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(188);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 128. */
    private final void goto128() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(187);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 129. */
    private final void goto129() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 30:
                // Expressions
                doGoto(182);
                return;

            case 32:
                // Expression
                doGoto(181);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 130. */
    private final void goto130() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 131. */
    private final void goto131() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 132. */
    private final void goto132() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 133. */
    private final void goto133() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 134. */
    private final void goto134() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 135. */
    private final void goto135() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 136. */
    private final void goto136() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 137. */
    private final void goto137() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 138. */
    private final void goto138() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 139. */
    private final void goto139() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 140. */
    private final void goto140() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 141. */
    private final void goto141() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 142. */
    private final void goto142() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 143. */
    private final void goto143() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 144. */
    private final void goto144() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 31:
                // OptExpression
                doGoto(146);
                return;

            case 32:
                // Expression
                doGoto(145);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 145. */
    private final void goto145() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 146. */
    private final void goto146() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 147. */
    private final void goto147() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 31:
                // OptExpression
                doGoto(149);
                return;

            case 32:
                // Expression
                doGoto(148);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 148. */
    private final void goto148() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 149. */
    private final void goto149() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 150. */
    private final void goto150() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 151. */
    private final void goto151() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 33:
                // AndExpression
                doGoto(152);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 152. */
    private final void goto152() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 153. */
    private final void goto153() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 34:
                // CompareExpression
                doGoto(154);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 154. */
    private final void goto154() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 155. */
    private final void goto155() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(178);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 156. */
    private final void goto156() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(177);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 157. */
    private final void goto157() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(176);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 158. */
    private final void goto158() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(175);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 159. */
    private final void goto159() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(174);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 160. */
    private final void goto160() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 35:
                // AddExpression
                doGoto(161);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 161. */
    private final void goto161() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 162. */
    private final void goto162() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 36:
                // MulExpression
                doGoto(173);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 163. */
    private final void goto163() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 36:
                // MulExpression
                doGoto(164);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 164. */
    private final void goto164() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 165. */
    private final void goto165() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(172);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 166. */
    private final void goto166() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(171);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 167. */
    private final void goto167() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(170);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 168. */
    private final void goto168() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 37:
                // UnaryExpression
                doGoto(169);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 169. */
    private final void goto169() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 170. */
    private final void goto170() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 171. */
    private final void goto171() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 172. */
    private final void goto172() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 173. */
    private final void goto173() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 174. */
    private final void goto174() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 175. */
    private final void goto175() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 176. */
    private final void goto176() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 177. */
    private final void goto177() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 178. */
    private final void goto178() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 179. */
    private final void goto179() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 180. */
    private final void goto180() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 181. */
    private final void goto181() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 182. */
    private final void goto182() {
        switch (reduceNonTerminal) {
            case 47:
                // OptComma
                doGoto(184);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 183. */
    private final void goto183() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(186);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 184. */
    private final void goto184() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 185. */
    private final void goto185() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 186. */
    private final void goto186() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 187. */
    private final void goto187() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 188. */
    private final void goto188() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 189. */
    private final void goto189() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 30:
                // Expressions
                doGoto(191);
                return;

            case 32:
                // Expression
                doGoto(181);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 190. */
    private final void goto190() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 191. */
    private final void goto191() {
        switch (reduceNonTerminal) {
            case 47:
                // OptComma
                doGoto(192);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 192. */
    private final void goto192() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 193. */
    private final void goto193() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 194. */
    private final void goto194() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 195. */
    private final void goto195() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 196. */
    private final void goto196() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 197. */
    private final void goto197() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 39:
                // ExpressionFactor
                doGoto(198);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 198. */
    private final void goto198() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 199. */
    private final void goto199() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 200. */
    private final void goto200() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 201. */
    private final void goto201() {
        switch (reduceNonTerminal) {
            case 47:
                // OptComma
                doGoto(209);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 202. */
    private final void goto202() {
        switch (reduceNonTerminal) {
            case 47:
                // OptComma
                doGoto(204);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 203. */
    private final void goto203() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(206);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 204. */
    private final void goto204() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 205. */
    private final void goto205() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 206. */
    private final void goto206() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 207. */
    private final void goto207() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(208);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 208. */
    private final void goto208() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 209. */
    private final void goto209() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 210. */
    private final void goto210() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 211. */
    private final void goto211() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(212);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 212. */
    private final void goto212() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 213. */
    private final void goto213() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 214. */
    private final void goto214() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(217);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 44:
                // ToolArgs
                doGoto(218);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 215. */
    private final void goto215() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 216. */
    private final void goto216() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 217. */
    private final void goto217() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 218. */
    private final void goto218() {
        switch (reduceNonTerminal) {
            case 47:
                // OptComma
                doGoto(220);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 219. */
    private final void goto219() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(223);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 220. */
    private final void goto220() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 221. */
    private final void goto221() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 222. */
    private final void goto222() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 223. */
    private final void goto223() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 224. */
    private final void goto224() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(225);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 225. */
    private final void goto225() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 226. */
    private final void goto226() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(227);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 227. */
    private final void goto227() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 228. */
    private final void goto228() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 229. */
    private final void goto229() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 230. */
    private final void goto230() {
        switch (reduceNonTerminal) {
            case 25:
                // Addressable
                doGoto(236);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 231. */
    private final void goto231() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 30:
                // Expressions
                doGoto(232);
                return;

            case 32:
                // Expression
                doGoto(181);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 232. */
    private final void goto232() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 233. */
    private final void goto233() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(186);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 234. */
    private final void goto234() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 235. */
    private final void goto235() {
        switch (reduceNonTerminal) {
            case 26:
                // Projections
                doGoto(239);
                return;

            case 27:
                // Projection
                doGoto(238);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 236. */
    private final void goto236() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 237. */
    private final void goto237() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(241);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 238. */
    private final void goto238() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 239. */
    private final void goto239() {
        switch (reduceNonTerminal) {
            case 27:
                // Projection
                doGoto(240);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 240. */
    private final void goto240() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 241. */
    private final void goto241() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 242. */
    private final void goto242() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 243. */
    private final void goto243() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 244. */
    private final void goto244() {
        switch (reduceNonTerminal) {
            case 24:
                // Addressables
                doGoto(245);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 245. */
    private final void goto245() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 246. */
    private final void goto246() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 247. */
    private final void goto247() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 248. */
    private final void goto248() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(253);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 249. */
    private final void goto249() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(250);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 250. */
    private final void goto250() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 251. */
    private final void goto251() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 252. */
    private final void goto252() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 253. */
    private final void goto253() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 254. */
    private final void goto254() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 255. */
    private final void goto255() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 256. */
    private final void goto256() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 257. */
    private final void goto257() {
        switch (reduceNonTerminal) {
            case 11:
                // TypeDecl
                doGoto(259);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 258. */
    private final void goto258() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 259. */
    private final void goto259() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 260. */
    private final void goto260() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(261);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 261. */
    private final void goto261() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 262. */
    private final void goto262() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(272);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 263. */
    private final void goto263() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 264. */
    private final void goto264() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(265);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 265. */
    private final void goto265() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 266. */
    private final void goto266() {
        switch (reduceNonTerminal) {
            case 28:
                // Types
                doGoto(268);
                return;

            case 29:
                // Type
                doGoto(267);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 267. */
    private final void goto267() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 268. */
    private final void goto268() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 269. */
    private final void goto269() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(271);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 270. */
    private final void goto270() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 271. */
    private final void goto271() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 272. */
    private final void goto272() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 273. */
    private final void goto273() {
        switch (reduceNonTerminal) {
            case 28:
                // Types
                doGoto(274);
                return;

            case 29:
                // Type
                doGoto(267);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 274. */
    private final void goto274() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 275. */
    private final void goto275() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 276. */
    private final void goto276() {
        switch (reduceNonTerminal) {
            case 12:
                // OptTypeParams
                doGoto(306);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 277. */
    private final void goto277() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 278. */
    private final void goto278() {
        switch (reduceNonTerminal) {
            case 12:
                // OptTypeParams
                doGoto(280);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 279. */
    private final void goto279() {
        switch (reduceNonTerminal) {
            case 45:
                // Names
                doGoto(302);
                return;

            case 46:
                // Name
                doGoto(301);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 280. */
    private final void goto280() {
        switch (reduceNonTerminal) {
            case 13:
                // ToolParameters
                doGoto(282);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 281. */
    private final void goto281() {
        switch (reduceNonTerminal) {
            case 14:
                // ToolParams
                doGoto(287);
                return;

            case 29:
                // Type
                doGoto(288);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 282. */
    private final void goto282() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 283. */
    private final void goto283() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(284);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 284. */
    private final void goto284() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 285. */
    private final void goto285() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 286. */
    private final void goto286() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 287. */
    private final void goto287() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 288. */
    private final void goto288() {
        switch (reduceNonTerminal) {
            case 15:
                // ToolParam
                doGoto(291);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 289. */
    private final void goto289() {
        switch (reduceNonTerminal) {
            case 15:
                // ToolParam
                doGoto(294);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 290. */
    private final void goto290() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 291. */
    private final void goto291() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 292. */
    private final void goto292() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(293);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 293. */
    private final void goto293() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 294. */
    private final void goto294() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 295. */
    private final void goto295() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(297);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 296. */
    private final void goto296() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 297. */
    private final void goto297() {
        switch (reduceNonTerminal) {
            case 15:
                // ToolParam
                doGoto(299);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 298. */
    private final void goto298() {
        switch (reduceNonTerminal) {
            case 15:
                // ToolParam
                doGoto(300);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 299. */
    private final void goto299() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 300. */
    private final void goto300() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 301. */
    private final void goto301() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 302. */
    private final void goto302() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 303. */
    private final void goto303() {
        switch (reduceNonTerminal) {
            case 46:
                // Name
                doGoto(305);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 304. */
    private final void goto304() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 305. */
    private final void goto305() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 306. */
    private final void goto306() {
        switch (reduceNonTerminal) {
            case 13:
                // ToolParameters
                doGoto(307);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 307. */
    private final void goto307() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 308. */
    private final void goto308() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(309);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 309. */
    private final void goto309() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 310. */
    private final void goto310() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 311. */
    private final void goto311() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 312. */
    private final void goto312() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(314);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 313. */
    private final void goto313() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 314. */
    private final void goto314() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 315. */
    private final void goto315() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 316. */
    private final void goto316() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 317. */
    private final void goto317() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 318. */
    private final void goto318() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 319. */
    private final void goto319() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(326);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 320. */
    private final void goto320() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 321. */
    private final void goto321() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(322);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 322. */
    private final void goto322() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 323. */
    private final void goto323() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(324);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 324. */
    private final void goto324() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 325. */
    private final void goto325() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 326. */
    private final void goto326() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 327. */
    private final void goto327() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(328);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 328. */
    private final void goto328() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 329. */
    private final void goto329() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 330. */
    private final void goto330() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 331. */
    private final void goto331() {
        switch (reduceNonTerminal) {
            case 29:
                // Type
                doGoto(333);
                return;

            case 46:
                // Name
                doGoto(195);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 332. */
    private final void goto332() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 333. */
    private final void goto333() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 334. */
    private final void goto334() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 335. */
    private final void goto335() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 336. */
    private final void goto336() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 337. */
    private final void goto337() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 338. */
    private final void goto338() {
        switch (reduceNonTerminal) {
            case 46:
                // Name
                doGoto(340);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 339. */
    private final void goto339() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 340. */
    private final void goto340() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 341. */
    private final void goto341() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 342. */
    private final void goto342() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 343. */
    private final void goto343() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 344. */
    private final void goto344() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 345. */
    private final void goto345() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 346. */
    private final void goto346() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 347. */
    private final void goto347() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 348. */
    private final void goto348() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 349. */
    private final void goto349() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 350. */
    private final void goto350() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 351. */
    private final void goto351() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 352. */
    private final void goto352() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(364);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 353. */
    private final void goto353() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(354);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 354. */
    private final void goto354() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 20:
                // OptElifStatements
                doGoto(355);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 355. */
    private final void goto355() {
        switch (reduceNonTerminal) {
            case 21:
                // OptElseStatement
                doGoto(358);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 356. */
    private final void goto356() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(361);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 357. */
    private final void goto357() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(360);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 358. */
    private final void goto358() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 359. */
    private final void goto359() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 360. */
    private final void goto360() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 361. */
    private final void goto361() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 362. */
    private final void goto362() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(363);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 363. */
    private final void goto363() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 364. */
    private final void goto364() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 365. */
    private final void goto365() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 366. */
    private final void goto366() {
        switch (reduceNonTerminal) {
            case 9:
                // ImportParts
                doGoto(369);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 367. */
    private final void goto367() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 368. */
    private final void goto368() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 369. */
    private final void goto369() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 370. */
    private final void goto370() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 371. */
    private final void goto371() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 372. */
    private final void goto372() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 373. */
    private final void goto373() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 374. */
    private final void goto374() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 375. */
    private final void goto375() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 376. */
    private final void goto376() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 377. */
    private final void goto377() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 378. */
    private final void goto378() {
        switch (reduceNonTerminal) {
            case 23:
                // AddressableDecl
                doGoto(391);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 379. */
    private final void goto379() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 380. */
    private final void goto380() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 381. */
    private final void goto381() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 382. */
    private final void goto382() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 32:
                // Expression
                doGoto(385);
                return;

            case 33:
                // AndExpression
                doGoto(135);
                return;

            case 34:
                // CompareExpression
                doGoto(136);
                return;

            case 35:
                // AddExpression
                doGoto(134);
                return;

            case 36:
                // MulExpression
                doGoto(139);
                return;

            case 37:
                // UnaryExpression
                doGoto(143);
                return;

            case 38:
                // ProjExpression
                doGoto(141);
                return;

            case 39:
                // ExpressionFactor
                doGoto(138);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(142);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(140);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 383. */
    private final void goto383() {
        switch (reduceNonTerminal) {
            case 23:
                // AddressableDecl
                doGoto(384);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 384. */
    private final void goto384() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 385. */
    private final void goto385() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 386. */
    private final void goto386() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(390);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 387. */
    private final void goto387() {
        switch (reduceNonTerminal) {
            case 16:
                // OptStatements
                doGoto(388);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 388. */
    private final void goto388() {
        switch (reduceNonTerminal) {
            case 0:
                // BuiltInIoTool
                doGoto(101);
                return;

            case 1:
                // BuiltInGenericTool
                doGoto(100);
                return;

            case 2:
                // BuiltInPathTool
                doGoto(102);
                return;

            case 3:
                // BuiltInFileTool
                doGoto(99);
                return;

            case 4:
                // BuiltInDataTool
                doGoto(98);
                return;

            case 17:
                // Statement
                doGoto(252);
                return;

            case 24:
                // Addressables
                doGoto(97);
                return;

            case 25:
                // Addressable
                doGoto(96);
                return;

            case 29:
                // Type
                doGoto(112);
                return;

            case 41:
                // ToolInvokeExpression
                doGoto(110);
                return;

            case 42:
                // ToolRef
                doGoto(111);
                return;

            case 43:
                // BuiltInTool
                doGoto(103);
                return;

            case 46:
                // Name
                doGoto(107);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 389. */
    private final void goto389() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 390. */
    private final void goto390() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 391. */
    private final void goto391() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 392. */
    private final void goto392() {
        switch (reduceNonTerminal) {
            case 22:
                // AddressableDecls
                doGoto(393);
                return;

            case 23:
                // AddressableDecl
                doGoto(380);
                return;

            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 393. */
    private final void goto393() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 394. */
    private final void goto394() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 395. */
    private final void goto395() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 396. */
    private final void goto396() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 397. */
    private final void goto397() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 398. */
    private final void goto398() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 399. */
    private final void goto399() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 400. */
    private final void goto400() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    /** Parser goto code for parser state 401. */
    private final void goto401() {
        switch (reduceNonTerminal) {
            default:
                String msg = fmt("Unknown non-terminal %d (%s) for reduce " +
                                 "state %d.", reduceNonTerminal,
                                 NON_TERMINAL_NAMES[reduceNonTerminal],
                                 reduceState);
                throw new RuntimeException(msg);
        }
    }

    @Override
    protected final String getNonTerminalName(int nonTerminalId) {
        return NON_TERMINAL_NAMES[nonTerminalId];
    }

    /** See {@code Parser.firstTerminals}. */
    private static final class FirstTerminals {
        /** See {@code Parser.firstTerminals}. */
        private static final int[][] FIRST_TERMINALS = new int[][] {
            {1, 2, 3, 4, 8, 10, 11, 12, 13, 15, 16, 17, 18, 20, 21, 22, 23, 24, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129, 136}, // state 0
            {123}, // state 1
            {124}, // state 2
            {124}, // state 3
            {123}, // state 4
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 124, 127, 128, 129, 130, 131, 132}, // state 5
            {121, 128}, // state 6
            {132}, // state 7
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 8
            {128, 129, 132}, // state 9
            {123}, // state 10
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 123, 128, 129}, // state 11
            {123}, // state 12
            {121, 123}, // state 13
            {123}, // state 14
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 124, 127, 128, 129, 130, 131, 132}, // state 15
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 123, 128, 129}, // state 16
            {123}, // state 17
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 18
            {121, 123}, // state 19
            {128}, // state 20
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 21
            {}, // state 22
            {}, // state 23
            {}, // state 24
            {}, // state 25
            {}, // state 26
            {}, // state 27
            {}, // state 28
            {}, // state 29
            {}, // state 30
            {}, // state 31
            {}, // state 32
            {}, // state 33
            {}, // state 34
            {}, // state 35
            {}, // state 36
            {}, // state 37
            {}, // state 38
            {}, // state 39
            {}, // state 40
            {}, // state 41
            {}, // state 42
            {}, // state 43
            {}, // state 44
            {}, // state 45
            {}, // state 46
            {}, // state 47
            {}, // state 48
            {}, // state 49
            {}, // state 50
            {}, // state 51
            {}, // state 52
            {}, // state 53
            {}, // state 54
            {}, // state 55
            {}, // state 56
            {}, // state 57
            {}, // state 58
            {}, // state 59
            {}, // state 60
            {}, // state 61
            {}, // state 62
            {}, // state 63
            {}, // state 64
            {}, // state 65
            {}, // state 66
            {}, // state 67
            {}, // state 68
            {}, // state 69
            {}, // state 70
            {}, // state 71
            {}, // state 72
            {}, // state 73
            {}, // state 74
            {}, // state 75
            {}, // state 76
            {}, // state 77
            {}, // state 78
            {}, // state 79
            {}, // state 80
            {}, // state 81
            {}, // state 82
            {}, // state 83
            {}, // state 84
            {}, // state 85
            {}, // state 86
            {}, // state 87
            {}, // state 88
            {}, // state 89
            {}, // state 90
            {}, // state 91
            {}, // state 92
            {121, 128}, // state 93
            {127}, // state 94
            {}, // state 95
            {}, // state 96
            {108, 113}, // state 97
            {}, // state 98
            {}, // state 99
            {}, // state 100
            {}, // state 101
            {}, // state 102
            {}, // state 103
            {}, // state 104
            {1, 2, 3, 4, 8, 10, 11, 12, 13, 15, 16, 17, 18, 20, 21, 22, 23, 24, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 105
            {}, // state 106
            {}, // state 107
            {136}, // state 108
            {}, // state 109
            {124}, // state 110
            {121}, // state 111
            {128}, // state 112
            {113}, // state 113
            {}, // state 114
            {108, 124}, // state 115
            {128}, // state 116
            {}, // state 117
            {}, // state 118
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 119
            {}, // state 120
            {}, // state 121
            {}, // state 122
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 123
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 109, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 124
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 125
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 126
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 127
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 128
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 126, 127, 128, 129, 130, 131, 132}, // state 129
            {}, // state 130
            {}, // state 131
            {}, // state 132
            {}, // state 133
            {118, 122}, // state 134
            {100}, // state 135
            {112, 114, 115, 116, 117, 119}, // state 136
            {104}, // state 137
            {}, // state 138
            {101, 102, 105, 125}, // state 139
            {}, // state 140
            {127}, // state 141
            {}, // state 142
            {}, // state 143
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 107, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 144
            {104, 126}, // state 145
            {107}, // state 146
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 126, 127, 128, 129, 130, 131, 132}, // state 147
            {104}, // state 148
            {126}, // state 149
            {}, // state 150
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 151
            {100}, // state 152
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 153
            {112, 114, 115, 116, 117, 119}, // state 154
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 155
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 156
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 157
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 158
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 159
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 160
            {118, 122}, // state 161
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 162
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 163
            {101, 102, 105, 125}, // state 164
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 165
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 166
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 167
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 168
            {}, // state 169
            {}, // state 170
            {}, // state 171
            {}, // state 172
            {101, 102, 105, 125}, // state 173
            {118, 122}, // state 174
            {118, 122}, // state 175
            {118, 122}, // state 176
            {118, 122}, // state 177
            {118, 122}, // state 178
            {}, // state 179
            {}, // state 180
            {104}, // state 181
            {108, 126}, // state 182
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 183
            {126}, // state 184
            {}, // state 185
            {104}, // state 186
            {}, // state 187
            {104, 108, 120}, // state 188
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 189
            {}, // state 190
            {108, 120}, // state 191
            {120}, // state 192
            {}, // state 193
            {}, // state 194
            {}, // state 195
            {115}, // state 196
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 110, 117, 121, 127, 128, 129, 130, 131, 132}, // state 197
            {}, // state 198
            {}, // state 199
            {104, 107}, // state 200
            {108, 109}, // state 201
            {108, 109}, // state 202
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 203
            {109}, // state 204
            {}, // state 205
            {104, 107}, // state 206
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 207
            {104}, // state 208
            {109}, // state 209
            {}, // state 210
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 211
            {104}, // state 212
            {}, // state 213
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 120, 121, 122, 127, 128, 129, 130, 131, 132}, // state 214
            {}, // state 215
            {113}, // state 216
            {104}, // state 217
            {108, 120}, // state 218
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 219
            {120}, // state 220
            {}, // state 221
            {113}, // state 222
            {104}, // state 223
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 224
            {104}, // state 225
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 226
            {104}, // state 227
            {}, // state 228
            {}, // state 229
            {121, 128}, // state 230
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 231
            {108, 124}, // state 232
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 233
            {}, // state 234
            {127}, // state 235
            {}, // state 236
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 237
            {}, // state 238
            {127}, // state 239
            {}, // state 240
            {104, 126}, // state 241
            {}, // state 242
            {108}, // state 243
            {121, 128}, // state 244
            {108, 120}, // state 245
            {}, // state 246
            {104, 106, 107}, // state 247
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 248
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 249
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 250
            {}, // state 251
            {}, // state 252
            {}, // state 253
            {113}, // state 254
            {}, // state 255
            {108, 124}, // state 256
            {128}, // state 257
            {}, // state 258
            {}, // state 259
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 260
            {}, // state 261
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 262
            {121}, // state 263
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 264
            {108}, // state 265
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 266
            {}, // state 267
            {108, 120}, // state 268
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 269
            {}, // state 270
            {}, // state 271
            {108}, // state 272
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 273
            {108, 120}, // state 274
            {}, // state 275
            {117, 121}, // state 276
            {108, 128}, // state 277
            {117, 121}, // state 278
            {128, 129}, // state 279
            {121}, // state 280
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 120, 128, 129}, // state 281
            {107}, // state 282
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 283
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 284
            {}, // state 285
            {}, // state 286
            {108, 120}, // state 287
            {111, 128}, // state 288
            {128}, // state 289
            {113}, // state 290
            {}, // state 291
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 292
            {104}, // state 293
            {}, // state 294
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 295
            {}, // state 296
            {111, 128}, // state 297
            {128}, // state 298
            {}, // state 299
            {}, // state 300
            {}, // state 301
            {108, 115}, // state 302
            {128, 129}, // state 303
            {}, // state 304
            {}, // state 305
            {121}, // state 306
            {107}, // state 307
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 308
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 309
            {}, // state 310
            {}, // state 311
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 312
            {}, // state 313
            {}, // state 314
            {}, // state 315
            {108, 124}, // state 316
            {}, // state 317
            {}, // state 318
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 319
            {121}, // state 320
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 321
            {107}, // state 322
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 323
            {120}, // state 324
            {}, // state 325
            {107}, // state 326
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 327
            {120}, // state 328
            {}, // state 329
            {}, // state 330
            {1, 4, 15, 16, 17, 18, 20, 22, 23, 26, 128, 129}, // state 331
            {}, // state 332
            {}, // state 333
            {}, // state 334
            {0, 124}, // state 335
            {0, 107, 124}, // state 336
            {128}, // state 337
            {128, 129}, // state 338
            {}, // state 339
            {0, 124}, // state 340
            {128}, // state 341
            {}, // state 342
            {124}, // state 343
            {}, // state 344
            {124}, // state 345
            {}, // state 346
            {128}, // state 347
            {}, // state 348
            {124}, // state 349
            {}, // state 350
            {104, 106, 107}, // state 351
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 352
            {1, 2, 3, 4, 5, 6, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 353
            {1, 2, 3, 4, 5, 6, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 354
            {5, 6, 7}, // state 355
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 356
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 357
            {7}, // state 358
            {}, // state 359
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 360
            {104, 107}, // state 361
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 362
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 363
            {}, // state 364
            {13}, // state 365
            {105, 128}, // state 366
            {}, // state 367
            {0}, // state 368
            {108, 124}, // state 369
            {105, 128}, // state 370
            {}, // state 371
            {}, // state 372
            {0}, // state 373
            {128}, // state 374
            {}, // state 375
            {128}, // state 376
            {}, // state 377
            {121, 128}, // state 378
            {}, // state 379
            {}, // state 380
            {14, 108}, // state 381
            {9, 19, 25, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 103, 110, 117, 118, 121, 122, 127, 128, 129, 130, 131, 132}, // state 382
            {121, 128}, // state 383
            {}, // state 384
            {104, 106, 107}, // state 385
            {1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 386
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 387
            {1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129}, // state 388
            {}, // state 389
            {}, // state 390
            {108}, // state 391
            {121, 128}, // state 392
            {108, 120}, // state 393
            {}, // state 394
            {}, // state 395
            {104, 124}, // state 396
            {}, // state 397
            {}, // state 398
            {}, // state 399
            {}, // state 400
            {}, // state 401
        };
    }

    /** See {@code Parser.firstTerminalsReduced}. */
    private static final class FirstTerminalsReduced {
        /** See {@code Parser.firstTerminalsReduced}. */
        private static final int[][][] FIRST_TERMINALS_REDUCED = new int[][][] {
            { // state 0
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
                {5, 136},
                {6, 1, 2, 3, 4, 8, 10, 11, 12, 13, 15, 16, 17, 18, 20, 21, 22, 23, 24, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            {}, // state 1
            {}, // state 2
            {}, // state 3
            {}, // state 4
            { // state 5
                {32, 104, 124},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 6
                {22, 14, 108},
            },
            {}, // state 7
            { // state 8
                {32, 104, 106, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 9
                {46, 0, 107, 124},
            },
            {}, // state 10
            {}, // state 11
            {}, // state 12
            {}, // state 13
            {}, // state 14
            { // state 15
                {30, 108, 124},
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 16
            {}, // state 17
            { // state 18
                {28, 108, 128},
            },
            {}, // state 19
            { // state 20
                {10, 108, 124},
            },
            { // state 21
                {32, 104, 106, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 22
            {}, // state 23
            {}, // state 24
            {}, // state 25
            {}, // state 26
            {}, // state 27
            {}, // state 28
            {}, // state 29
            {}, // state 30
            {}, // state 31
            {}, // state 32
            {}, // state 33
            {}, // state 34
            {}, // state 35
            {}, // state 36
            {}, // state 37
            {}, // state 38
            {}, // state 39
            {}, // state 40
            {}, // state 41
            {}, // state 42
            {}, // state 43
            {}, // state 44
            {}, // state 45
            {}, // state 46
            {}, // state 47
            {}, // state 48
            {}, // state 49
            {}, // state 50
            {}, // state 51
            {}, // state 52
            {}, // state 53
            {}, // state 54
            {}, // state 55
            {}, // state 56
            {}, // state 57
            {}, // state 58
            {}, // state 59
            {}, // state 60
            {}, // state 61
            {}, // state 62
            {}, // state 63
            {}, // state 64
            {}, // state 65
            {}, // state 66
            {}, // state 67
            {}, // state 68
            {}, // state 69
            {}, // state 70
            {}, // state 71
            {}, // state 72
            {}, // state 73
            {}, // state 74
            {}, // state 75
            {}, // state 76
            {}, // state 77
            {}, // state 78
            {}, // state 79
            {}, // state 80
            {}, // state 81
            {}, // state 82
            {}, // state 83
            {}, // state 84
            {}, // state 85
            {}, // state 86
            {}, // state 87
            {}, // state 88
            {}, // state 89
            {}, // state 90
            {}, // state 91
            {}, // state 92
            { // state 93
                {25, 108},
            },
            { // state 94
                {26, 127},
            },
            {}, // state 95
            {}, // state 96
            {}, // state 97
            {}, // state 98
            {}, // state 99
            {}, // state 100
            {}, // state 101
            {}, // state 102
            {}, // state 103
            {}, // state 104
            { // state 105
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 106
            {}, // state 107
            {}, // state 108
            {}, // state 109
            {}, // state 110
            {}, // state 111
            { // state 112
                {18, 108, 124},
            },
            {}, // state 113
            {}, // state 114
            {}, // state 115
            {}, // state 116
            {}, // state 117
            {}, // state 118
            { // state 119
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 120
            {}, // state 121
            {}, // state 122
            { // state 123
                {38, 127},
                {42, 121},
            },
            { // state 124
                {30, 108, 109},
                {32, 104, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {40, 108, 109},
                {42, 121},
            },
            { // state 125
                {29, 115},
            },
            { // state 126
                {38, 127},
                {42, 121},
            },
            { // state 127
                {32, 104, 108, 120},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 128
                {38, 127},
                {42, 121},
            },
            { // state 129
                {30, 108, 126},
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 130
            {}, // state 131
            {}, // state 132
            {}, // state 133
            {}, // state 134
            {}, // state 135
            {}, // state 136
            {}, // state 137
            {}, // state 138
            {}, // state 139
            {}, // state 140
            {}, // state 141
            {}, // state 142
            {}, // state 143
            { // state 144
                {31, 107},
                {32, 104, 126},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 145
            {}, // state 146
            { // state 147
                {31, 126},
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 148
            {}, // state 149
            {}, // state 150
            { // state 151
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 152
            { // state 153
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 154
            { // state 155
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 156
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 157
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 158
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 159
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 160
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 161
            { // state 162
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 163
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 164
            { // state 165
                {38, 127},
                {42, 121},
            },
            { // state 166
                {38, 127},
                {42, 121},
            },
            { // state 167
                {38, 127},
                {42, 121},
            },
            { // state 168
                {38, 127},
                {42, 121},
            },
            {}, // state 169
            {}, // state 170
            {}, // state 171
            {}, // state 172
            {}, // state 173
            {}, // state 174
            {}, // state 175
            {}, // state 176
            {}, // state 177
            {}, // state 178
            {}, // state 179
            {}, // state 180
            {}, // state 181
            { // state 182
                {47, 126},
            },
            { // state 183
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 184
            {}, // state 185
            {}, // state 186
            {}, // state 187
            {}, // state 188
            { // state 189
                {30, 108, 120},
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 190
            { // state 191
                {47, 120},
            },
            {}, // state 192
            {}, // state 193
            {}, // state 194
            {}, // state 195
            {}, // state 196
            { // state 197
                {42, 121},
            },
            {}, // state 198
            {}, // state 199
            {}, // state 200
            { // state 201
                {47, 109},
            },
            { // state 202
                {47, 109},
            },
            { // state 203
                {32, 104, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 204
            {}, // state 205
            {}, // state 206
            { // state 207
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 208
            {}, // state 209
            {}, // state 210
            { // state 211
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 212
            {}, // state 213
            { // state 214
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
                {44, 108, 120},
            },
            {}, // state 215
            {}, // state 216
            {}, // state 217
            { // state 218
                {47, 120},
            },
            { // state 219
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 220
            {}, // state 221
            {}, // state 222
            {}, // state 223
            { // state 224
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 225
            { // state 226
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 227
            {}, // state 228
            {}, // state 229
            {}, // state 230
            { // state 231
                {30, 108, 124},
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 232
            { // state 233
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 234
            { // state 235
                {26, 127},
            },
            {}, // state 236
            { // state 237
                {32, 104, 126},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 238
            {}, // state 239
            {}, // state 240
            {}, // state 241
            {}, // state 242
            {}, // state 243
            { // state 244
                {24, 108, 120},
            },
            {}, // state 245
            {}, // state 246
            {}, // state 247
            { // state 248
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            { // state 249
                {16, 1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 250
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 251
            {}, // state 252
            {}, // state 253
            {}, // state 254
            {}, // state 255
            {}, // state 256
            {}, // state 257
            {}, // state 258
            {}, // state 259
            {}, // state 260
            {}, // state 261
            { // state 262
                {29, 108},
            },
            {}, // state 263
            { // state 264
                {29, 108},
            },
            {}, // state 265
            { // state 266
                {28, 108, 120},
            },
            {}, // state 267
            {}, // state 268
            {}, // state 269
            {}, // state 270
            {}, // state 271
            {}, // state 272
            { // state 273
                {28, 108, 120},
            },
            {}, // state 274
            {}, // state 275
            { // state 276
                {12, 121},
            },
            {}, // state 277
            { // state 278
                {12, 121},
            },
            { // state 279
                {45, 108, 115},
            },
            { // state 280
                {13, 107},
            },
            { // state 281
                {14, 108, 120},
                {29, 111, 128},
            },
            {}, // state 282
            { // state 283
                {16, 1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 284
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 285
            {}, // state 286
            {}, // state 287
            {}, // state 288
            {}, // state 289
            {}, // state 290
            {}, // state 291
            { // state 292
                {32, 104},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 293
            {}, // state 294
            { // state 295
                {29, 111, 128},
            },
            {}, // state 296
            {}, // state 297
            {}, // state 298
            {}, // state 299
            {}, // state 300
            {}, // state 301
            {}, // state 302
            {}, // state 303
            {}, // state 304
            {}, // state 305
            { // state 306
                {13, 107},
            },
            {}, // state 307
            { // state 308
                {16, 1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 309
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 310
            {}, // state 311
            {}, // state 312
            {}, // state 313
            {}, // state 314
            {}, // state 315
            {}, // state 316
            {}, // state 317
            {}, // state 318
            { // state 319
                {29, 107},
            },
            {}, // state 320
            { // state 321
                {29, 107},
            },
            {}, // state 322
            { // state 323
                {29, 120},
            },
            {}, // state 324
            {}, // state 325
            {}, // state 326
            { // state 327
                {29, 120},
            },
            {}, // state 328
            {}, // state 329
            {}, // state 330
            {}, // state 331
            {}, // state 332
            {}, // state 333
            {}, // state 334
            {}, // state 335
            {}, // state 336
            {}, // state 337
            { // state 338
                {46, 0, 124},
            },
            {}, // state 339
            {}, // state 340
            {}, // state 341
            {}, // state 342
            {}, // state 343
            {}, // state 344
            {}, // state 345
            {}, // state 346
            {}, // state 347
            {}, // state 348
            {}, // state 349
            {}, // state 350
            {}, // state 351
            { // state 352
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            { // state 353
                {16, 1, 2, 3, 4, 5, 6, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 354
                {20, 5, 6, 7},
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            { // state 355
                {21, 7},
            },
            { // state 356
                {32, 104, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            { // state 357
                {16, 1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            {}, // state 358
            {}, // state 359
            { // state 360
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 361
            { // state 362
                {16, 1, 2, 3, 4, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 363
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 364
            {}, // state 365
            { // state 366
                {9, 108, 124},
            },
            {}, // state 367
            {}, // state 368
            {}, // state 369
            {}, // state 370
            {}, // state 371
            {}, // state 372
            {}, // state 373
            {}, // state 374
            {}, // state 375
            {}, // state 376
            {}, // state 377
            { // state 378
                {23, 108},
            },
            {}, // state 379
            {}, // state 380
            {}, // state 381
            { // state 382
                {32, 104, 106, 107},
                {33, 100},
                {34, 112, 114, 115, 116, 117, 119},
                {35, 118, 122},
                {36, 101, 102, 105, 125},
                {38, 127},
                {42, 121},
            },
            {}, // state 383
            {}, // state 384
            {}, // state 385
            { // state 386
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            { // state 387
                {16, 1, 2, 3, 4, 7, 8, 10, 12, 15, 16, 17, 18, 20, 21, 22, 23, 26, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 121, 128, 129},
            },
            { // state 388
                {24, 108, 113},
                {29, 128},
                {41, 124},
                {42, 121},
            },
            {}, // state 389
            {}, // state 390
            {}, // state 391
            { // state 392
                {22, 108, 120},
            },
            {}, // state 393
            {}, // state 394
            {}, // state 395
            {}, // state 396
            {}, // state 397
            {}, // state 398
            {}, // state 399
            {}, // state 400
            {}, // state 401
        };
    }

    /** See {@code Parser.reducibleNonTerminals}. */
    private static final class ReducibleNonTerminals {
        /** See {@code Parser.reducibleNonTerminals}. */
        private static final int[][][] REDUCIBLE_NON_TERMINALS = new int[][][] {
            { // state 0
                {5, 0},
            },
            { // state 1
                {29, 1},
            },
            {}, // state 2
            {}, // state 3
            { // state 4
                {29, 1},
            },
            {}, // state 5
            {}, // state 6
            {}, // state 7
            {}, // state 8
            {}, // state 9
            { // state 10
                {29, 1},
            },
            {}, // state 11
            { // state 12
                {29, 1},
            },
            {}, // state 13
            { // state 14
                {29, 1},
            },
            {}, // state 15
            {}, // state 16
            { // state 17
                {29, 1},
            },
            {}, // state 18
            {}, // state 19
            {}, // state 20
            {}, // state 21
            { // state 22
                {0, 1},
            },
            { // state 23
                {0, 1},
            },
            { // state 24
                {0, 1},
            },
            { // state 25
                {0, 1},
            },
            { // state 26
                {1, 1},
            },
            { // state 27
                {1, 1},
            },
            { // state 28
                {1, 1},
            },
            { // state 29
                {2, 1},
            },
            { // state 30
                {2, 1},
            },
            { // state 31
                {2, 1},
            },
            { // state 32
                {2, 1},
            },
            { // state 33
                {2, 1},
            },
            { // state 34
                {2, 1},
            },
            { // state 35
                {2, 1},
            },
            { // state 36
                {2, 1},
            },
            { // state 37
                {2, 1},
            },
            { // state 38
                {2, 1},
            },
            { // state 39
                {3, 1},
            },
            { // state 40
                {3, 1},
            },
            { // state 41
                {3, 1},
            },
            { // state 42
                {3, 1},
            },
            { // state 43
                {3, 1},
            },
            { // state 44
                {3, 1},
            },
            { // state 45
                {3, 1},
            },
            { // state 46
                {3, 1},
            },
            { // state 47
                {3, 1},
            },
            { // state 48
                {3, 1},
            },
            { // state 49
                {3, 1},
            },
            { // state 50
                {3, 1},
            },
            { // state 51
                {3, 1},
            },
            { // state 52
                {3, 1},
            },
            { // state 53
                {3, 1},
            },
            { // state 54
                {3, 1},
            },
            { // state 55
                {4, 1},
            },
            { // state 56
                {4, 1},
            },
            { // state 57
                {4, 1},
            },
            { // state 58
                {4, 1},
            },
            { // state 59
                {4, 1},
            },
            { // state 60
                {4, 1},
            },
            { // state 61
                {4, 1},
            },
            { // state 62
                {4, 1},
            },
            { // state 63
                {4, 1},
            },
            { // state 64
                {4, 1},
            },
            { // state 65
                {4, 1},
            },
            { // state 66
                {4, 1},
            },
            { // state 67
                {4, 1},
            },
            { // state 68
                {4, 1},
            },
            { // state 69
                {4, 1},
            },
            { // state 70
                {4, 1},
            },
            { // state 71
                {4, 1},
            },
            { // state 72
                {4, 1},
            },
            { // state 73
                {4, 1},
            },
            { // state 74
                {4, 1},
            },
            { // state 75
                {4, 1},
            },
            { // state 76
                {4, 1},
            },
            { // state 77
                {4, 1},
            },
            { // state 78
                {4, 1},
            },
            { // state 79
                {4, 1},
            },
            { // state 80
                {4, 1},
            },
            { // state 81
                {4, 1},
            },
            { // state 82
                {4, 1},
            },
            { // state 83
                {4, 1},
            },
            { // state 84
                {4, 1},
            },
            { // state 85
                {4, 1},
            },
            { // state 86
                {4, 1},
            },
            { // state 87
                {4, 1},
            },
            { // state 88
                {4, 1},
            },
            { // state 89
                {4, 1},
            },
            { // state 90
                {4, 1},
            },
            { // state 91
                {4, 1},
            },
            { // state 92
                {4, 1},
            },
            {}, // state 93
            { // state 94
                {25, 1},
                {46, 1},
            },
            { // state 95
                {46, 1},
            },
            { // state 96
                {24, 1},
            },
            {}, // state 97
            { // state 98
                {43, 1},
            },
            { // state 99
                {43, 1},
            },
            { // state 100
                {43, 1},
            },
            { // state 101
                {43, 1},
            },
            { // state 102
                {43, 1},
            },
            { // state 103
                {42, 1},
            },
            { // state 104
                {6, 1},
            },
            { // state 105
                {5, 1},
            },
            { // state 106
                {7, 1},
            },
            { // state 107
                {29, 1},
                {42, 1},
            },
            {}, // state 108
            { // state 109
                {7, 1},
            },
            {}, // state 110
            {}, // state 111
            {}, // state 112
            { // state 113
                {19, 1},
            },
            { // state 114
                {18, 1},
            },
            {}, // state 115
            {}, // state 116
            { // state 117
                {17, 3},
            },
            { // state 118
                {18, 3},
            },
            {}, // state 119
            { // state 120
                {39, 1},
            },
            { // state 121
                {39, 1},
            },
            { // state 122
                {39, 1},
            },
            {}, // state 123
            {}, // state 124
            {}, // state 125
            {}, // state 126
            {}, // state 127
            {}, // state 128
            {}, // state 129
            { // state 130
                {46, 1},
            },
            { // state 131
                {39, 1},
            },
            { // state 132
                {39, 1},
            },
            { // state 133
                {39, 1},
            },
            { // state 134
                {34, 1},
            },
            { // state 135
                {32, 1},
            },
            { // state 136
                {33, 1},
            },
            { // state 137
                {19, 3},
            },
            { // state 138
                {38, 1},
            },
            { // state 139
                {35, 1},
            },
            { // state 140
                {39, 1},
                {42, 1},
            },
            { // state 141
                {37, 1},
            },
            { // state 142
                {39, 1},
            },
            { // state 143
                {36, 1},
            },
            { // state 144
                {31, 0},
            },
            { // state 145
                {31, 1},
            },
            {}, // state 146
            { // state 147
                {31, 0},
            },
            { // state 148
                {31, 1},
            },
            {}, // state 149
            { // state 150
                {38, 6},
            },
            {}, // state 151
            { // state 152
                {32, 3},
            },
            {}, // state 153
            { // state 154
                {33, 3},
            },
            {}, // state 155
            {}, // state 156
            {}, // state 157
            {}, // state 158
            {}, // state 159
            {}, // state 160
            { // state 161
                {34, 3},
            },
            {}, // state 162
            {}, // state 163
            { // state 164
                {35, 3},
            },
            {}, // state 165
            {}, // state 166
            {}, // state 167
            {}, // state 168
            { // state 169
                {36, 3},
            },
            { // state 170
                {36, 3},
            },
            { // state 171
                {36, 3},
            },
            { // state 172
                {36, 3},
            },
            { // state 173
                {35, 3},
            },
            { // state 174
                {34, 3},
            },
            { // state 175
                {34, 3},
            },
            { // state 176
                {34, 3},
            },
            { // state 177
                {34, 3},
            },
            { // state 178
                {34, 3},
            },
            { // state 179
                {38, 4},
            },
            { // state 180
                {39, 2},
            },
            { // state 181
                {30, 1},
            },
            { // state 182
                {47, 0},
            },
            { // state 183
                {47, 1},
            },
            {}, // state 184
            { // state 185
                {39, 4},
            },
            { // state 186
                {30, 3},
            },
            { // state 187
                {37, 2},
            },
            {}, // state 188
            {}, // state 189
            { // state 190
                {39, 3},
            },
            { // state 191
                {47, 0},
            },
            {}, // state 192
            { // state 193
                {39, 6},
            },
            { // state 194
                {37, 2},
            },
            { // state 195
                {29, 1},
            },
            {}, // state 196
            {}, // state 197
            { // state 198
                {39, 4},
            },
            { // state 199
                {39, 2},
            },
            { // state 200
                {30, 1},
            },
            { // state 201
                {47, 0},
            },
            { // state 202
                {47, 0},
            },
            { // state 203
                {47, 1},
            },
            {}, // state 204
            { // state 205
                {39, 4},
            },
            {}, // state 206
            {}, // state 207
            { // state 208
                {40, 5},
            },
            {}, // state 209
            { // state 210
                {39, 4},
            },
            {}, // state 211
            { // state 212
                {40, 3},
            },
            { // state 213
                {37, 2},
            },
            {}, // state 214
            { // state 215
                {41, 3},
            },
            { // state 216
                {46, 1},
            },
            { // state 217
                {44, 1},
            },
            { // state 218
                {47, 0},
            },
            { // state 219
                {47, 1},
            },
            {}, // state 220
            { // state 221
                {41, 5},
            },
            { // state 222
                {46, 1},
            },
            { // state 223
                {44, 3},
            },
            {}, // state 224
            { // state 225
                {44, 5},
            },
            {}, // state 226
            { // state 227
                {44, 3},
            },
            { // state 228
                {17, 2},
            },
            { // state 229
                {6, 2},
            },
            {}, // state 230
            {}, // state 231
            {}, // state 232
            {}, // state 233
            { // state 234
                {17, 4},
            },
            { // state 235
                {25, 1},
            },
            { // state 236
                {24, 3},
            },
            {}, // state 237
            { // state 238
                {26, 1},
            },
            { // state 239
                {25, 2},
            },
            { // state 240
                {26, 2},
            },
            {}, // state 241
            { // state 242
                {27, 3},
            },
            {}, // state 243
            {}, // state 244
            {}, // state 245
            { // state 246
                {25, 5},
            },
            {}, // state 247
            {}, // state 248
            { // state 249
                {16, 0},
            },
            {}, // state 250
            { // state 251
                {17, 5},
            },
            { // state 252
                {16, 2},
            },
            { // state 253
                {17, 4},
            },
            {}, // state 254
            { // state 255
                {10, 1},
            },
            {}, // state 256
            {}, // state 257
            { // state 258
                {7, 3},
            },
            { // state 259
                {10, 3},
            },
            {}, // state 260
            { // state 261
                {11, 3},
            },
            {}, // state 262
            {}, // state 263
            {}, // state 264
            {}, // state 265
            {}, // state 266
            { // state 267
                {28, 1},
            },
            {}, // state 268
            {}, // state 269
            { // state 270
                {29, 7},
            },
            { // state 271
                {28, 3},
            },
            {}, // state 272
            {}, // state 273
            {}, // state 274
            { // state 275
                {29, 6},
            },
            { // state 276
                {12, 0},
                {46, 1},
            },
            {}, // state 277
            { // state 278
                {12, 0},
            },
            {}, // state 279
            {}, // state 280
            {}, // state 281
            {}, // state 282
            { // state 283
                {16, 0},
            },
            {}, // state 284
            { // state 285
                {7, 8},
            },
            { // state 286
                {13, 2},
            },
            {}, // state 287
            {}, // state 288
            {}, // state 289
            { // state 290
                {15, 1},
            },
            { // state 291
                {14, 2},
            },
            {}, // state 292
            { // state 293
                {15, 3},
            },
            { // state 294
                {14, 3},
            },
            {}, // state 295
            { // state 296
                {13, 3},
            },
            {}, // state 297
            {}, // state 298
            { // state 299
                {14, 4},
            },
            { // state 300
                {14, 5},
            },
            { // state 301
                {45, 1},
            },
            {}, // state 302
            {}, // state 303
            { // state 304
                {12, 3},
            },
            { // state 305
                {45, 3},
            },
            {}, // state 306
            {}, // state 307
            { // state 308
                {16, 0},
            },
            {}, // state 309
            { // state 310
                {7, 7},
            },
            { // state 311
                {29, 2},
            },
            {}, // state 312
            { // state 313
                {29, 2},
            },
            { // state 314
                {29, 3},
            },
            { // state 315
                {17, 2},
            },
            {}, // state 316
            { // state 317
                {17, 3},
            },
            { // state 318
                {29, 2},
            },
            {}, // state 319
            {}, // state 320
            {}, // state 321
            {}, // state 322
            {}, // state 323
            {}, // state 324
            { // state 325
                {29, 7},
            },
            {}, // state 326
            {}, // state 327
            {}, // state 328
            { // state 329
                {29, 6},
            },
            { // state 330
                {29, 2},
            },
            {}, // state 331
            { // state 332
                {29, 2},
            },
            { // state 333
                {29, 3},
            },
            { // state 334
                {29, 2},
            },
            {}, // state 335
            {}, // state 336
            {}, // state 337
            {}, // state 338
            { // state 339
                {8, 3},
            },
            {}, // state 340
            {}, // state 341
            { // state 342
                {8, 5},
            },
            {}, // state 343
            { // state 344
                {8, 7},
            },
            {}, // state 345
            { // state 346
                {8, 5},
            },
            {}, // state 347
            { // state 348
                {8, 3},
            },
            {}, // state 349
            { // state 350
                {8, 5},
            },
            {}, // state 351
            {}, // state 352
            { // state 353
                {16, 0},
            },
            { // state 354
                {20, 0},
            },
            { // state 355
                {21, 0},
            },
            {}, // state 356
            { // state 357
                {16, 0},
                {21, 1},
            },
            {}, // state 358
            { // state 359
                {17, 7},
            },
            { // state 360
                {21, 2},
            },
            {}, // state 361
            { // state 362
                {16, 0},
                {20, 4},
            },
            { // state 363
                {20, 5},
            },
            { // state 364
                {17, 4},
            },
            {}, // state 365
            {}, // state 366
            { // state 367
                {9, 1},
            },
            { // state 368
                {9, 1},
            },
            {}, // state 369
            {}, // state 370
            { // state 371
                {8, 5},
            },
            { // state 372
                {9, 3},
            },
            { // state 373
                {9, 3},
            },
            {}, // state 374
            { // state 375
                {9, 5},
            },
            {}, // state 376
            { // state 377
                {9, 3},
            },
            {}, // state 378
            { // state 379
                {23, 1},
            },
            { // state 380
                {22, 1},
            },
            {}, // state 381
            {}, // state 382
            {}, // state 383
            { // state 384
                {22, 3},
            },
            {}, // state 385
            {}, // state 386
            { // state 387
                {16, 0},
            },
            {}, // state 388
            { // state 389
                {17, 7},
            },
            { // state 390
                {17, 6},
            },
            {}, // state 391
            {}, // state 392
            {}, // state 393
            { // state 394
                {23, 5},
            },
            { // state 395
                {17, 2},
            },
            {}, // state 396
            { // state 397
                {17, 3},
            },
            { // state 398
                {29, 2},
            },
            { // state 399
                {17, 2},
            },
            { // state 400
                {17, 2},
            },
            { // state 401
                {29, 2},
            },
        };
    }

    /** See {@code Parser.reducibleNonTerminalsReduced}. */
    private static final class ReducibleNonTerminalsReduced {
        /** See {@code Parser.reducibleNonTerminalsReduced}. */
        private static final int[][][] REDUCIBLE_NON_TERMINALS_REDUCED = new int[][][] {
            { // state 0
                {0, 43, 0},
                {1, 43, 0},
                {17, 7, 0},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
                {6, 5, 0},
                {7, 6, 0},
                {8, 7, 0},
            },
            {}, // state 1
            {}, // state 2
            {}, // state 3
            {}, // state 4
            { // state 5
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 6
                {23, 22, 0},
            },
            {}, // state 7
            { // state 8
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 9
            {}, // state 10
            { // state 11
                {29, 29, 1},
                {46, 29, 0},
            },
            {}, // state 12
            {}, // state 13
            {}, // state 14
            { // state 15
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 16
                {29, 29, 1},
                {46, 29, 0},
            },
            {}, // state 17
            { // state 18
                {29, 28, 0},
                {46, 29, 0},
            },
            {}, // state 19
            { // state 20
                {11, 10, 0},
            },
            { // state 21
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 22
            {}, // state 23
            {}, // state 24
            {}, // state 25
            {}, // state 26
            {}, // state 27
            {}, // state 28
            {}, // state 29
            {}, // state 30
            {}, // state 31
            {}, // state 32
            {}, // state 33
            {}, // state 34
            {}, // state 35
            {}, // state 36
            {}, // state 37
            {}, // state 38
            {}, // state 39
            {}, // state 40
            {}, // state 41
            {}, // state 42
            {}, // state 43
            {}, // state 44
            {}, // state 45
            {}, // state 46
            {}, // state 47
            {}, // state 48
            {}, // state 49
            {}, // state 50
            {}, // state 51
            {}, // state 52
            {}, // state 53
            {}, // state 54
            {}, // state 55
            {}, // state 56
            {}, // state 57
            {}, // state 58
            {}, // state 59
            {}, // state 60
            {}, // state 61
            {}, // state 62
            {}, // state 63
            {}, // state 64
            {}, // state 65
            {}, // state 66
            {}, // state 67
            {}, // state 68
            {}, // state 69
            {}, // state 70
            {}, // state 71
            {}, // state 72
            {}, // state 73
            {}, // state 74
            {}, // state 75
            {}, // state 76
            {}, // state 77
            {}, // state 78
            {}, // state 79
            {}, // state 80
            {}, // state 81
            {}, // state 82
            {}, // state 83
            {}, // state 84
            {}, // state 85
            {}, // state 86
            {}, // state 87
            {}, // state 88
            {}, // state 89
            {}, // state 90
            {}, // state 91
            {}, // state 92
            {}, // state 93
            { // state 94
                {26, 25, 1},
                {27, 26, 0},
            },
            {}, // state 95
            {}, // state 96
            {}, // state 97
            {}, // state 98
            {}, // state 99
            {}, // state 100
            {}, // state 101
            {}, // state 102
            {}, // state 103
            {}, // state 104
            { // state 105
                {0, 43, 0},
                {1, 43, 0},
                {17, 7, 0},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
                {7, 6, 1},
                {8, 7, 0},
            },
            {}, // state 106
            {}, // state 107
            {}, // state 108
            {}, // state 109
            {}, // state 110
            {}, // state 111
            { // state 112
                {19, 18, 0},
            },
            {}, // state 113
            {}, // state 114
            {}, // state 115
            { // state 116
                {19, 18, 2},
            },
            {}, // state 117
            {}, // state 118
            { // state 119
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 19, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 120
            {}, // state 121
            {}, // state 122
            { // state 123
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 37, 1},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 124
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 125
                {46, 29, 0},
            },
            { // state 126
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 37, 1},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 127
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 128
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 37, 1},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 129
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 130
            {}, // state 131
            {}, // state 132
            {}, // state 133
            {}, // state 134
            {}, // state 135
            {}, // state 136
            {}, // state 137
            {}, // state 138
            {}, // state 139
            {}, // state 140
            {}, // state 141
            {}, // state 142
            {}, // state 143
            { // state 144
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 31, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 145
            {}, // state 146
            { // state 147
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 31, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 148
            {}, // state 149
            {}, // state 150
            { // state 151
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 2},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 152
            { // state 153
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {34, 33, 2},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 154
            { // state 155
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 156
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 157
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 158
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 159
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 160
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {35, 34, 2},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 161
            { // state 162
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {36, 35, 2},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 163
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {36, 35, 2},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 164
            { // state 165
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 36, 2},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 166
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 36, 2},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 167
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 36, 2},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 168
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {37, 36, 2},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 169
            {}, // state 170
            {}, // state 171
            {}, // state 172
            {}, // state 173
            {}, // state 174
            {}, // state 175
            {}, // state 176
            {}, // state 177
            {}, // state 178
            {}, // state 179
            {}, // state 180
            {}, // state 181
            {}, // state 182
            { // state 183
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 184
            {}, // state 185
            {}, // state 186
            {}, // state 187
            {}, // state 188
            { // state 189
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 190
            {}, // state 191
            {}, // state 192
            {}, // state 193
            {}, // state 194
            {}, // state 195
            {}, // state 196
            { // state 197
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {39, 39, 3},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 198
            {}, // state 199
            {}, // state 200
            {}, // state 201
            {}, // state 202
            { // state 203
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 204
            {}, // state 205
            {}, // state 206
            { // state 207
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 40, 4},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 208
            {}, // state 209
            {}, // state 210
            { // state 211
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 40, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 212
            {}, // state 213
            { // state 214
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 44, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 215
            {}, // state 216
            {}, // state 217
            {}, // state 218
            { // state 219
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 44, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 220
            {}, // state 221
            {}, // state 222
            {}, // state 223
            { // state 224
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 44, 4},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 225
            { // state 226
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 44, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 227
            {}, // state 228
            {}, // state 229
            { // state 230
                {25, 24, 2},
            },
            { // state 231
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 232
            { // state 233
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 30, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 234
            { // state 235
                {26, 25, 1},
                {27, 26, 0},
            },
            {}, // state 236
            { // state 237
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 238
            { // state 239
                {27, 26, 1},
            },
            {}, // state 240
            {}, // state 241
            {}, // state 242
            {}, // state 243
            { // state 244
                {25, 24, 0},
            },
            {}, // state 245
            {}, // state 246
            {}, // state 247
            { // state 248
                {0, 43, 0},
                {1, 43, 0},
                {17, 17, 3},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 249
            { // state 250
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 251
            {}, // state 252
            {}, // state 253
            {}, // state 254
            {}, // state 255
            {}, // state 256
            { // state 257
                {11, 10, 2},
            },
            {}, // state 258
            {}, // state 259
            { // state 260
                {29, 11, 2},
                {46, 29, 0},
            },
            {}, // state 261
            { // state 262
                {46, 29, 0},
            },
            {}, // state 263
            { // state 264
                {46, 29, 0},
            },
            {}, // state 265
            { // state 266
                {29, 28, 0},
                {46, 29, 0},
            },
            {}, // state 267
            {}, // state 268
            { // state 269
                {29, 28, 2},
                {46, 29, 0},
            },
            {}, // state 270
            {}, // state 271
            {}, // state 272
            { // state 273
                {29, 28, 0},
                {46, 29, 0},
            },
            {}, // state 274
            {}, // state 275
            {}, // state 276
            {}, // state 277
            {}, // state 278
            { // state 279
                {46, 45, 0},
            },
            {}, // state 280
            { // state 281
                {46, 29, 0},
            },
            {}, // state 282
            {}, // state 283
            { // state 284
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 285
            {}, // state 286
            {}, // state 287
            { // state 288
                {15, 14, 1},
            },
            { // state 289
                {15, 14, 2},
            },
            {}, // state 290
            {}, // state 291
            { // state 292
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {32, 15, 2},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            {}, // state 293
            {}, // state 294
            { // state 295
                {46, 29, 0},
            },
            {}, // state 296
            { // state 297
                {15, 14, 3},
            },
            { // state 298
                {15, 14, 4},
            },
            {}, // state 299
            {}, // state 300
            {}, // state 301
            {}, // state 302
            { // state 303
                {46, 45, 2},
            },
            {}, // state 304
            {}, // state 305
            {}, // state 306
            {}, // state 307
            {}, // state 308
            { // state 309
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 310
            {}, // state 311
            { // state 312
                {29, 29, 2},
                {46, 29, 0},
            },
            {}, // state 313
            {}, // state 314
            {}, // state 315
            {}, // state 316
            {}, // state 317
            {}, // state 318
            { // state 319
                {46, 29, 0},
            },
            {}, // state 320
            { // state 321
                {46, 29, 0},
            },
            {}, // state 322
            { // state 323
                {46, 29, 0},
            },
            {}, // state 324
            {}, // state 325
            {}, // state 326
            { // state 327
                {46, 29, 0},
            },
            {}, // state 328
            {}, // state 329
            {}, // state 330
            { // state 331
                {29, 29, 2},
                {46, 29, 0},
            },
            {}, // state 332
            {}, // state 333
            {}, // state 334
            {}, // state 335
            {}, // state 336
            {}, // state 337
            {}, // state 338
            {}, // state 339
            {}, // state 340
            {}, // state 341
            {}, // state 342
            {}, // state 343
            {}, // state 344
            {}, // state 345
            {}, // state 346
            {}, // state 347
            {}, // state 348
            {}, // state 349
            {}, // state 350
            {}, // state 351
            { // state 352
                {0, 43, 0},
                {1, 43, 0},
                {17, 17, 3},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 353
            { // state 354
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 355
            { // state 356
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 357
                {16, 21, 1},
            },
            {}, // state 358
            {}, // state 359
            { // state 360
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 361
            { // state 362
                {16, 20, 4},
            },
            { // state 363
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 364
            {}, // state 365
            {}, // state 366
            {}, // state 367
            {}, // state 368
            {}, // state 369
            {}, // state 370
            {}, // state 371
            {}, // state 372
            {}, // state 373
            {}, // state 374
            {}, // state 375
            {}, // state 376
            {}, // state 377
            {}, // state 378
            {}, // state 379
            {}, // state 380
            {}, // state 381
            { // state 382
                {0, 43, 0},
                {1, 43, 0},
                {2, 43, 0},
                {3, 43, 0},
                {33, 32, 0},
                {34, 33, 0},
                {35, 34, 0},
                {36, 35, 0},
                {37, 36, 0},
                {38, 37, 0},
                {39, 38, 0},
                {4, 43, 0},
                {41, 39, 0},
                {43, 42, 0},
                {46, 39, 0},
                {46, 42, 0},
            },
            { // state 383
                {23, 22, 2},
            },
            {}, // state 384
            {}, // state 385
            { // state 386
                {0, 43, 0},
                {1, 43, 0},
                {17, 17, 5},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 387
            { // state 388
                {0, 43, 0},
                {1, 43, 0},
                {17, 16, 1},
                {2, 43, 0},
                {25, 24, 0},
                {3, 43, 0},
                {4, 43, 0},
                {43, 42, 0},
                {46, 29, 0},
                {46, 42, 0},
            },
            {}, // state 389
            {}, // state 390
            {}, // state 391
            { // state 392
                {23, 22, 0},
            },
            {}, // state 393
            {}, // state 394
            {}, // state 395
            {}, // state 396
            {}, // state 397
            {}, // state 398
            {}, // state 399
            {}, // state 400
            {}, // state 401
        };
    }

    /** Parser call back hooks for {@link ToolDefParser}. */
    public interface Hooks extends ParserHooksBase {
        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInIoTool : @ERRKW;}</p>
         *
         * @param t1 {@code ERRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInIoTool1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInIoTool : @ERRLNKW;}</p>
         *
         * @param t1 {@code ERRLNKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInIoTool2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInIoTool : @OUTKW;}</p>
         *
         * @param t1 {@code OUTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInIoTool3(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInIoTool : @OUTLNKW;}</p>
         *
         * @param t1 {@code OUTLNKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInIoTool4(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInGenericTool : @APPKW;}</p>
         *
         * @param t1 {@code APPKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInGenericTool1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInGenericTool : @EXECKW;}</p>
         *
         * @param t1 {@code EXECKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInGenericTool2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInGenericTool : @TOOLDEFKW;}</p>
         *
         * @param t1 {@code TOOLDEFKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInGenericTool3(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @ABSPATHKW;}</p>
         *
         * @param t1 {@code ABSPATHKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool01(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @BASENAMEKW;}</p>
         *
         * @param t1 {@code BASENAMEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool02(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @CHDIRKW;}</p>
         *
         * @param t1 {@code CHDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool03(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @CHFILEEXTKW;}</p>
         *
         * @param t1 {@code CHFILEEXTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool04(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @CURDIRKW;}</p>
         *
         * @param t1 {@code CURDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool05(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @DIRNAMEKW;}</p>
         *
         * @param t1 {@code DIRNAMEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool06(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @FILEEXTKW;}</p>
         *
         * @param t1 {@code FILEEXTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool07(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @HASFILEEXTKW;}</p>
         *
         * @param t1 {@code HASFILEEXTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @PATHJOINKW;}</p>
         *
         * @param t1 {@code PATHJOINKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool09(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInPathTool : @SCRIPTPATHKW;}</p>
         *
         * @param t1 {@code SCRIPTPATHKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInPathTool10(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @CPDIRKW;}</p>
         *
         * @param t1 {@code CPDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool01(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @CPFILEKW;}</p>
         *
         * @param t1 {@code CPFILEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool02(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @DIFFKW;}</p>
         *
         * @param t1 {@code DIFFKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool03(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @EXISTSKW;}</p>
         *
         * @param t1 {@code EXISTSKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool04(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @FILENEWERKW;}</p>
         *
         * @param t1 {@code FILENEWERKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool05(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @FILESIZEKW;}</p>
         *
         * @param t1 {@code FILESIZEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool06(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @FINDKW;}</p>
         *
         * @param t1 {@code FINDKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool07(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @ISDIRKW;}</p>
         *
         * @param t1 {@code ISDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @ISFILEKW;}</p>
         *
         * @param t1 {@code ISFILEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool09(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @MKDIRKW;}</p>
         *
         * @param t1 {@code MKDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool10(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @MVDIRKW;}</p>
         *
         * @param t1 {@code MVDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool11(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @MVFILEKW;}</p>
         *
         * @param t1 {@code MVFILEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool12(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @READLINESKW;}</p>
         *
         * @param t1 {@code READLINESKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool13(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @RMDIRKW;}</p>
         *
         * @param t1 {@code RMDIRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool14(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @RMFILEKW;}</p>
         *
         * @param t1 {@code RMFILEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool15(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInFileTool : @WRITEFILEKW;}</p>
         *
         * @param t1 {@code WRITEFILEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInFileTool16(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @ABSKW;}</p>
         *
         * @param t1 {@code ABSKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool01(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @CEILKW;}</p>
         *
         * @param t1 {@code CEILKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool02(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @CONTAINSKW;}</p>
         *
         * @param t1 {@code CONTAINSKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool03(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @DELKW;}</p>
         *
         * @param t1 {@code DELKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool04(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @DELIDXKW;}</p>
         *
         * @param t1 {@code DELIDXKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool05(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @EMPTYKW;}</p>
         *
         * @param t1 {@code EMPTYKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool06(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @ENDSWITHKW;}</p>
         *
         * @param t1 {@code ENDSWITHKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool07(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @ENTRIESKW;}</p>
         *
         * @param t1 {@code ENTRIESKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @ENUMERATEKW;}</p>
         *
         * @param t1 {@code ENUMERATEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool09(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @FLOORKW;}</p>
         *
         * @param t1 {@code FLOORKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool10(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @FMTKW;}</p>
         *
         * @param t1 {@code FMTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool11(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @INDEXOFKW;}</p>
         *
         * @param t1 {@code INDEXOFKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool12(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @JOINKW;}</p>
         *
         * @param t1 {@code JOINKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool13(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @KEYSKW;}</p>
         *
         * @param t1 {@code KEYSKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool14(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @LASTINDEXOFKW;}</p>
         *
         * @param t1 {@code LASTINDEXOFKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool15(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @LNKW;}</p>
         *
         * @param t1 {@code LNKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool16(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @LOGKW;}</p>
         *
         * @param t1 {@code LOGKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool17(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @LOWERKW;}</p>
         *
         * @param t1 {@code LOWERKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool18(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @LTRIMKW;}</p>
         *
         * @param t1 {@code LTRIMKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool19(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @MAXKW;}</p>
         *
         * @param t1 {@code MAXKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool20(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @MINKW;}</p>
         *
         * @param t1 {@code MINKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool21(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @POWKW;}</p>
         *
         * @param t1 {@code POWKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool22(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @RANGEKW;}</p>
         *
         * @param t1 {@code RANGEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool23(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @REPLACEKW;}</p>
         *
         * @param t1 {@code REPLACEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool24(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @REVERSEKW;}</p>
         *
         * @param t1 {@code REVERSEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool25(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @ROUNDKW;}</p>
         *
         * @param t1 {@code ROUNDKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool26(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @RTRIMKW;}</p>
         *
         * @param t1 {@code RTRIMKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool27(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @SIZEKW;}</p>
         *
         * @param t1 {@code SIZEKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool28(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @SORTEDKW;}</p>
         *
         * @param t1 {@code SORTEDKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool29(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @SPLITKW;}</p>
         *
         * @param t1 {@code SPLITKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool30(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @SQRTKW;}</p>
         *
         * @param t1 {@code SQRTKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool31(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @STARTSWITHKW;}</p>
         *
         * @param t1 {@code STARTSWITHKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool32(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @STRKW;}</p>
         *
         * @param t1 {@code STRKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool33(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @STRDUPKW;}</p>
         *
         * @param t1 {@code STRDUPKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool34(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @SUBSETKW;}</p>
         *
         * @param t1 {@code SUBSETKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool35(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @TRIMKW;}</p>
         *
         * @param t1 {@code TRIMKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool36(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @UPPERKW;}</p>
         *
         * @param t1 {@code UPPERKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool37(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInDataTool : @VALUESKW;}</p>
         *
         * @param t1 {@code VALUESKW}.
         * @return The parser call back hook result.
         */
        public Token parseBuiltInDataTool38(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Script : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public Script parseScript1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Script : Decls;}</p>
         *
         * @param l1 {@code Decls}.
         * @return The parser call back hook result.
         */
        public Script parseScript2(List<Declaration> l1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decls : Decl;}</p>
         *
         * @param l1 {@code Decl}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecls1(List<Declaration> l1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decls : Decls Decl;}</p>
         *
         * @param l1 {@code Decls}.
         * @param l2 {@code Decl}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecls2(List<Declaration> l1, List<Declaration> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decl : Import;}</p>
         *
         * @param l1 {@code Import}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecl1(List<Declaration> l1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decl : TYPEKW TypeDecls SEMICOLTK;}</p>
         *
         * @param l2 {@code TypeDecls}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecl2(List<Declaration> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decl : @TOOLKW @IDENTIFIERTK OptTypeParams ToolParameters COLONTK OptStatements @ENDKW;}</p>
         *
         * @param t1 {@code TOOLKW}.
         * @param t2 {@code IDENTIFIERTK}.
         * @param l3 {@code OptTypeParams}.
         * @param l4 {@code ToolParameters}.
         * @param l6 {@code OptStatements}.
         * @param t7 {@code ENDKW}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecl3(Token t1, Token t2, List<TypeParam> l3, List<ToolParameter> l4, List<Statement> l6, Token t7);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decl : @TOOLKW Types @IDENTIFIERTK OptTypeParams ToolParameters COLONTK OptStatements @ENDKW;}</p>
         *
         * @param t1 {@code TOOLKW}.
         * @param l2 {@code Types}.
         * @param t3 {@code IDENTIFIERTK}.
         * @param l4 {@code OptTypeParams}.
         * @param l5 {@code ToolParameters}.
         * @param l7 {@code OptStatements}.
         * @param t8 {@code ENDKW}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecl4(Token t1, List<ToolDefType> l2, Token t3, List<TypeParam> l4, List<ToolParameter> l5, List<Statement> l7, Token t8);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Decl : Statement;}</p>
         *
         * @param l1 {@code Statement}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseDecl5(List<Statement> l1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW @STRINGTK SEMICOLTK;}</p>
         *
         * @param t2 {@code STRINGTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport1(Token t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW @STRINGTK ASKW @IDENTIFIERTK SEMICOLTK;}</p>
         *
         * @param t2 {@code STRINGTK}.
         * @param t4 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport2(Token t2, Token t4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW Name SEMICOLTK;}</p>
         *
         * @param t2 {@code Name}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport3(Token t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW Name ASKW @IDENTIFIERTK SEMICOLTK;}</p>
         *
         * @param t2 {@code Name}.
         * @param t4 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport4(Token t2, Token t4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW Name COLONTK Name SEMICOLTK;}</p>
         *
         * @param t2 {@code Name}.
         * @param t4 {@code Name}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport5(Token t2, Token t4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : IMPORTKW Name COLONTK Name ASKW @IDENTIFIERTK SEMICOLTK;}</p>
         *
         * @param t2 {@code Name}.
         * @param t4 {@code Name}.
         * @param t6 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport6(Token t2, Token t4, Token t6);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Import : FROMKW @STRINGTK IMPORTKW ImportParts SEMICOLTK;}</p>
         *
         * @param t2 {@code STRINGTK}.
         * @param l4 {@code ImportParts}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImport7(Token t2, List<Declaration> l4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : @ASTERISKTK;}</p>
         *
         * @param t1 {@code ASTERISKTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : @IDENTIFIERTK ASKW @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param t3 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts3(Token t1, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : ImportParts COMMATK @ASTERISKTK;}</p>
         *
         * @param l1 {@code ImportParts}.
         * @param t3 {@code ASTERISKTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts4(List<Declaration> l1, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : ImportParts COMMATK @IDENTIFIERTK;}</p>
         *
         * @param l1 {@code ImportParts}.
         * @param t3 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts5(List<Declaration> l1, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ImportParts : ImportParts COMMATK @IDENTIFIERTK ASKW @IDENTIFIERTK;}</p>
         *
         * @param l1 {@code ImportParts}.
         * @param t3 {@code IDENTIFIERTK}.
         * @param t5 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseImportParts6(List<Declaration> l1, Token t3, Token t5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code TypeDecls : TypeDecl;}</p>
         *
         * @param t1 {@code TypeDecl}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseTypeDecls1(TypeDecl t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code TypeDecls : TypeDecls COMMATK TypeDecl;}</p>
         *
         * @param l1 {@code TypeDecls}.
         * @param t3 {@code TypeDecl}.
         * @return The parser call back hook result.
         */
        public List<Declaration> parseTypeDecls2(List<Declaration> l1, TypeDecl t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code TypeDecl : @IDENTIFIERTK EQTK Type;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param t3 {@code Type}.
         * @return The parser call back hook result.
         */
        public TypeDecl parseTypeDecl1(Token t1, ToolDefType t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptTypeParams : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public List<TypeParam> parseOptTypeParams1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptTypeParams : LTTK Names GTTK;}</p>
         *
         * @param l2 {@code Names}.
         * @return The parser call back hook result.
         */
        public List<TypeParam> parseOptTypeParams2(List<Token> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParameters : PAROPENTK PARCLOSETK;}</p>
         *
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParameters1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParameters : PAROPENTK ToolParams PARCLOSETK;}</p>
         *
         * @param l2 {@code ToolParams}.
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParameters2(List<ToolParameter> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParams : Type ToolParam;}</p>
         *
         * @param t1 {@code Type}.
         * @param t2 {@code ToolParam}.
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParams1(ToolDefType t1, ToolParameter t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParams : Type DOTSTK ToolParam;}</p>
         *
         * @param t1 {@code Type}.
         * @param t3 {@code ToolParam}.
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParams2(ToolDefType t1, ToolParameter t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParams : ToolParams COMMATK Type ToolParam;}</p>
         *
         * @param l1 {@code ToolParams}.
         * @param t3 {@code Type}.
         * @param t4 {@code ToolParam}.
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParams3(List<ToolParameter> l1, ToolDefType t3, ToolParameter t4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParams : ToolParams COMMATK Type DOTSTK ToolParam;}</p>
         *
         * @param l1 {@code ToolParams}.
         * @param t3 {@code Type}.
         * @param t5 {@code ToolParam}.
         * @return The parser call back hook result.
         */
        public List<ToolParameter> parseToolParams4(List<ToolParameter> l1, ToolDefType t3, ToolParameter t5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParam : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public ToolParameter parseToolParam1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolParam : @IDENTIFIERTK @EQTK Expression;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param t2 {@code EQTK}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public ToolParameter parseToolParam2(Token t1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptStatements : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public List<Statement> parseOptStatements1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptStatements : OptStatements Statement;}</p>
         *
         * @param l1 {@code OptStatements}.
         * @param l2 {@code Statement}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseOptStatements2(List<Statement> l1, List<Statement> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : Type VarDecls SEMICOLTK;}</p>
         *
         * @param t1 {@code Type}.
         * @param l2 {@code VarDecls}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement01(ToolDefType t1, List<Statement> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @WHILEKW Expression COLONTK OptStatements @ENDKW;}</p>
         *
         * @param t1 {@code WHILEKW}.
         * @param e2 {@code Expression}.
         * @param l4 {@code OptStatements}.
         * @param t5 {@code ENDKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement02(Token t1, Expression e2, List<Statement> l4, Token t5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @WHILEKW Expression COLONCOLONTK Statement;}</p>
         *
         * @param t1 {@code WHILEKW}.
         * @param e2 {@code Expression}.
         * @param l4 {@code Statement}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement03(Token t1, Expression e2, List<Statement> l4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @FORKW AddressableDecls INKW Expression COLONTK OptStatements @ENDKW;}</p>
         *
         * @param t1 {@code FORKW}.
         * @param l2 {@code AddressableDecls}.
         * @param e4 {@code Expression}.
         * @param l6 {@code OptStatements}.
         * @param t7 {@code ENDKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement04(Token t1, List<AddressableDecl> l2, Expression e4, List<Statement> l6, Token t7);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @FORKW AddressableDecls INKW Expression COLONCOLONTK Statement;}</p>
         *
         * @param t1 {@code FORKW}.
         * @param l2 {@code AddressableDecls}.
         * @param e4 {@code Expression}.
         * @param l6 {@code Statement}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement05(Token t1, List<AddressableDecl> l2, Expression e4, List<Statement> l6);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @IFKW Expression COLONTK OptStatements OptElifStatements OptElseStatement @ENDKW;}</p>
         *
         * @param t1 {@code IFKW}.
         * @param e2 {@code Expression}.
         * @param l4 {@code OptStatements}.
         * @param l5 {@code OptElifStatements}.
         * @param l6 {@code OptElseStatement}.
         * @param t7 {@code ENDKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement06(Token t1, Expression e2, List<Statement> l4, List<ElifStatement> l5, List<Statement> l6, Token t7);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @IFKW Expression COLONCOLONTK Statement;}</p>
         *
         * @param t1 {@code IFKW}.
         * @param e2 {@code Expression}.
         * @param l4 {@code Statement}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement07(Token t1, Expression e2, List<Statement> l4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @BREAKKW SEMICOLTK;}</p>
         *
         * @param t1 {@code BREAKKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @CONTINUEKW SEMICOLTK;}</p>
         *
         * @param t1 {@code CONTINUEKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement09(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : Addressables @EQTK Expressions SEMICOLTK;}</p>
         *
         * @param l1 {@code Addressables}.
         * @param t2 {@code EQTK}.
         * @param l3 {@code Expressions}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement10(List<Expression> l1, Token t2, List<Expression> l3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @RETURNKW SEMICOLTK;}</p>
         *
         * @param t1 {@code RETURNKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement11(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @RETURNKW Expressions SEMICOLTK;}</p>
         *
         * @param t1 {@code RETURNKW}.
         * @param l2 {@code Expressions}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement12(Token t1, List<Expression> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : ToolInvokeExpression SEMICOLTK;}</p>
         *
         * @param t1 {@code ToolInvokeExpression}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement13(ToolInvokeExpression t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @EXITKW SEMICOLTK;}</p>
         *
         * @param t1 {@code EXITKW}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement14(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Statement : @EXITKW Expression SEMICOLTK;}</p>
         *
         * @param t1 {@code EXITKW}.
         * @param e2 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseStatement15(Token t1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code VarDecls : VarDecl;}</p>
         *
         * @param s1 {@code VarDecl}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseVarDecls1(Statement s1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code VarDecls : VarDecls COMMATK VarDecl;}</p>
         *
         * @param l1 {@code VarDecls}.
         * @param s3 {@code VarDecl}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseVarDecls2(List<Statement> l1, Statement s3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code VarDecl : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public Statement parseVarDecl1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code VarDecl : @IDENTIFIERTK @EQTK Expression;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param t2 {@code EQTK}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public Statement parseVarDecl2(Token t1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptElifStatements : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public List<ElifStatement> parseOptElifStatements1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptElifStatements : OptElifStatements @ELIFKW Expression COLONTK OptStatements;}</p>
         *
         * @param l1 {@code OptElifStatements}.
         * @param t2 {@code ELIFKW}.
         * @param e3 {@code Expression}.
         * @param l5 {@code OptStatements}.
         * @return The parser call back hook result.
         */
        public List<ElifStatement> parseOptElifStatements2(List<ElifStatement> l1, Token t2, Expression e3, List<Statement> l5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptElseStatement : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public List<Statement> parseOptElseStatement1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptElseStatement : ELSEKW OptStatements;}</p>
         *
         * @param l2 {@code OptStatements}.
         * @return The parser call back hook result.
         */
        public List<Statement> parseOptElseStatement2(List<Statement> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddressableDecls : AddressableDecl;}</p>
         *
         * @param a1 {@code AddressableDecl}.
         * @return The parser call back hook result.
         */
        public List<AddressableDecl> parseAddressableDecls1(AddressableDecl a1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddressableDecls : AddressableDecls COMMATK AddressableDecl;}</p>
         *
         * @param l1 {@code AddressableDecls}.
         * @param a3 {@code AddressableDecl}.
         * @return The parser call back hook result.
         */
        public List<AddressableDecl> parseAddressableDecls2(List<AddressableDecl> l1, AddressableDecl a3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddressableDecl : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public AddressableDecl parseAddressableDecl1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddressableDecl : @PAROPENTK AddressableDecl COMMATK AddressableDecls PARCLOSETK;}</p>
         *
         * @param t1 {@code PAROPENTK}.
         * @param a2 {@code AddressableDecl}.
         * @param l4 {@code AddressableDecls}.
         * @return The parser call back hook result.
         */
        public AddressableDecl parseAddressableDecl2(Token t1, AddressableDecl a2, List<AddressableDecl> l4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Addressables : Addressable;}</p>
         *
         * @param e1 {@code Addressable}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseAddressables1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Addressables : Addressables COMMATK Addressable;}</p>
         *
         * @param l1 {@code Addressables}.
         * @param e3 {@code Addressable}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseAddressables2(List<Expression> l1, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Addressable : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public Expression parseAddressable1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Addressable : @IDENTIFIERTK Projections;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param l2 {@code Projections}.
         * @return The parser call back hook result.
         */
        public Expression parseAddressable2(Token t1, List<Expression> l2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Addressable : @PAROPENTK Addressable COMMATK Addressables PARCLOSETK;}</p>
         *
         * @param t1 {@code PAROPENTK}.
         * @param e2 {@code Addressable}.
         * @param l4 {@code Addressables}.
         * @return The parser call back hook result.
         */
        public Expression parseAddressable3(Token t1, Expression e2, List<Expression> l4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Projections : Projection;}</p>
         *
         * @param e1 {@code Projection}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseProjections1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Projections : Projections Projection;}</p>
         *
         * @param l1 {@code Projections}.
         * @param e2 {@code Projection}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseProjections2(List<Expression> l1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Projection : @SQOPENTK Expression SQCLOSETK;}</p>
         *
         * @param t1 {@code SQOPENTK}.
         * @param e2 {@code Expression}.
         * @return The parser call back hook result.
         */
        public Expression parseProjection1(Token t1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Types : Type;}</p>
         *
         * @param t1 {@code Type}.
         * @return The parser call back hook result.
         */
        public List<ToolDefType> parseTypes1(ToolDefType t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Types : Types COMMATK Type;}</p>
         *
         * @param l1 {@code Types}.
         * @param t3 {@code Type}.
         * @return The parser call back hook result.
         */
        public List<ToolDefType> parseTypes2(List<ToolDefType> l1, ToolDefType t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @BOOLKW;}</p>
         *
         * @param t1 {@code BOOLKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType01(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @BOOLKW QUESTIONTK;}</p>
         *
         * @param t1 {@code BOOLKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType02(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @INTKW;}</p>
         *
         * @param t1 {@code INTKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType03(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @INTKW QUESTIONTK;}</p>
         *
         * @param t1 {@code INTKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType04(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @LONGKW;}</p>
         *
         * @param t1 {@code LONGKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType05(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @LONGKW QUESTIONTK;}</p>
         *
         * @param t1 {@code LONGKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType06(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @DOUBLEKW;}</p>
         *
         * @param t1 {@code DOUBLEKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType07(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @DOUBLEKW QUESTIONTK;}</p>
         *
         * @param t1 {@code DOUBLEKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @STRINGKW;}</p>
         *
         * @param t1 {@code STRINGKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType09(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @STRINGKW QUESTIONTK;}</p>
         *
         * @param t1 {@code STRINGKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType10(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @LISTKW Type;}</p>
         *
         * @param t1 {@code LISTKW}.
         * @param t2 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType11(Token t1, ToolDefType t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @LISTKW QUESTIONTK Type;}</p>
         *
         * @param t1 {@code LISTKW}.
         * @param t3 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType12(Token t1, ToolDefType t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @SETKW Type;}</p>
         *
         * @param t1 {@code SETKW}.
         * @param t2 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType13(Token t1, ToolDefType t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @SETKW QUESTIONTK Type;}</p>
         *
         * @param t1 {@code SETKW}.
         * @param t3 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType14(Token t1, ToolDefType t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @MAPKW PAROPENTK Type COLONTK Type PARCLOSETK;}</p>
         *
         * @param t1 {@code MAPKW}.
         * @param t3 {@code Type}.
         * @param t5 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType15(Token t1, ToolDefType t3, ToolDefType t5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @MAPKW QUESTIONTK PAROPENTK Type COLONTK Type PARCLOSETK;}</p>
         *
         * @param t1 {@code MAPKW}.
         * @param t4 {@code Type}.
         * @param t6 {@code Type}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType16(Token t1, ToolDefType t4, ToolDefType t6);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @TUPLEKW PAROPENTK Type COMMATK Types PARCLOSETK;}</p>
         *
         * @param t1 {@code TUPLEKW}.
         * @param t3 {@code Type}.
         * @param l5 {@code Types}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType17(Token t1, ToolDefType t3, List<ToolDefType> l5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @TUPLEKW QUESTIONTK PAROPENTK Type COMMATK Types PARCLOSETK;}</p>
         *
         * @param t1 {@code TUPLEKW}.
         * @param t4 {@code Type}.
         * @param l6 {@code Types}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType18(Token t1, ToolDefType t4, List<ToolDefType> l6);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @OBJECTKW;}</p>
         *
         * @param t1 {@code OBJECTKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType19(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : @OBJECTKW QUESTIONTK;}</p>
         *
         * @param t1 {@code OBJECTKW}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType20(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Type : Name;}</p>
         *
         * @param t1 {@code Name}.
         * @return The parser call back hook result.
         */
        public ToolDefType parseType21(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Expressions : Expression;}</p>
         *
         * @param e1 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseExpressions1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Expressions : Expressions COMMATK Expression;}</p>
         *
         * @param l1 {@code Expressions}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<Expression> parseExpressions2(List<Expression> l1, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptExpression : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public Expression parseOptExpression1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptExpression : Expression;}</p>
         *
         * @param e1 {@code Expression}.
         * @return The parser call back hook result.
         */
        public Expression parseOptExpression2(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Expression : AndExpression;}</p>
         *
         * @param e1 {@code AndExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Expression : Expression @ORKW AndExpression;}</p>
         *
         * @param e1 {@code Expression}.
         * @param t2 {@code ORKW}.
         * @param e3 {@code AndExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AndExpression : CompareExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseAndExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AndExpression : AndExpression @ANDKW CompareExpression;}</p>
         *
         * @param e1 {@code AndExpression}.
         * @param t2 {@code ANDKW}.
         * @param e3 {@code CompareExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseAndExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : AddExpression;}</p>
         *
         * @param e1 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @LTTK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code LTTK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @LETK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code LETK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression3(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @EQEQTK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code EQEQTK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression4(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @NETK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code NETK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression5(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @GETK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code GETK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression6(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code CompareExpression : CompareExpression @GTTK AddExpression;}</p>
         *
         * @param e1 {@code CompareExpression}.
         * @param t2 {@code GTTK}.
         * @param e3 {@code AddExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseCompareExpression7(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddExpression : MulExpression;}</p>
         *
         * @param e1 {@code MulExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseAddExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddExpression : AddExpression @MINUSTK MulExpression;}</p>
         *
         * @param e1 {@code AddExpression}.
         * @param t2 {@code MINUSTK}.
         * @param e3 {@code MulExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseAddExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code AddExpression : AddExpression @PLUSTK MulExpression;}</p>
         *
         * @param e1 {@code AddExpression}.
         * @param t2 {@code PLUSTK}.
         * @param e3 {@code MulExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseAddExpression3(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MulExpression : UnaryExpression;}</p>
         *
         * @param e1 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseMulExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MulExpression : MulExpression @ASTERISKTK UnaryExpression;}</p>
         *
         * @param e1 {@code MulExpression}.
         * @param t2 {@code ASTERISKTK}.
         * @param e3 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseMulExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MulExpression : MulExpression @SLASHTK UnaryExpression;}</p>
         *
         * @param e1 {@code MulExpression}.
         * @param t2 {@code SLASHTK}.
         * @param e3 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseMulExpression3(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MulExpression : MulExpression @DIVKW UnaryExpression;}</p>
         *
         * @param e1 {@code MulExpression}.
         * @param t2 {@code DIVKW}.
         * @param e3 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseMulExpression4(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MulExpression : MulExpression @MODKW UnaryExpression;}</p>
         *
         * @param e1 {@code MulExpression}.
         * @param t2 {@code MODKW}.
         * @param e3 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseMulExpression5(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code UnaryExpression : ProjExpression;}</p>
         *
         * @param e1 {@code ProjExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseUnaryExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code UnaryExpression : @MINUSTK UnaryExpression;}</p>
         *
         * @param t1 {@code MINUSTK}.
         * @param e2 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseUnaryExpression2(Token t1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code UnaryExpression : @PLUSTK UnaryExpression;}</p>
         *
         * @param t1 {@code PLUSTK}.
         * @param e2 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseUnaryExpression3(Token t1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code UnaryExpression : @NOTKW UnaryExpression;}</p>
         *
         * @param t1 {@code NOTKW}.
         * @param e2 {@code UnaryExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseUnaryExpression4(Token t1, Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ProjExpression : ExpressionFactor;}</p>
         *
         * @param e1 {@code ExpressionFactor}.
         * @return The parser call back hook result.
         */
        public Expression parseProjExpression1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ProjExpression : ProjExpression @SQOPENTK Expression SQCLOSETK;}</p>
         *
         * @param e1 {@code ProjExpression}.
         * @param t2 {@code SQOPENTK}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public Expression parseProjExpression2(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ProjExpression : ProjExpression @SQOPENTK OptExpression COLONTK OptExpression SQCLOSETK;}</p>
         *
         * @param e1 {@code ProjExpression}.
         * @param t2 {@code SQOPENTK}.
         * @param e3 {@code OptExpression}.
         * @param e5 {@code OptExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseProjExpression3(Expression e1, Token t2, Expression e3, Expression e5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @TRUEKW;}</p>
         *
         * @param t1 {@code TRUEKW}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor01(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @FALSEKW;}</p>
         *
         * @param t1 {@code FALSEKW}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor02(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @NUMBERTK;}</p>
         *
         * @param t1 {@code NUMBERTK}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor03(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @DOUBLETK;}</p>
         *
         * @param t1 {@code DOUBLETK}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor04(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @NULLKW;}</p>
         *
         * @param t1 {@code NULLKW}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor05(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @STRINGTK;}</p>
         *
         * @param t1 {@code STRINGTK}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor06(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @LTTK Type GTTK ExpressionFactor;}</p>
         *
         * @param t1 {@code LTTK}.
         * @param t2 {@code Type}.
         * @param e4 {@code ExpressionFactor}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor07(Token t1, ToolDefType t2, Expression e4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @SQOPENTK SQCLOSETK;}</p>
         *
         * @param t1 {@code SQOPENTK}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor08(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @SQOPENTK Expressions OptComma SQCLOSETK;}</p>
         *
         * @param t1 {@code SQOPENTK}.
         * @param l2 {@code Expressions}.
         * @param t3 {@code OptComma}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor09(Token t1, List<Expression> l2, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @CUROPENTK CURCLOSETK;}</p>
         *
         * @param t1 {@code CUROPENTK}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor10(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @CUROPENTK Expressions OptComma CURCLOSETK;}</p>
         *
         * @param t1 {@code CUROPENTK}.
         * @param l2 {@code Expressions}.
         * @param t3 {@code OptComma}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor11(Token t1, List<Expression> l2, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @CUROPENTK MapEntries OptComma CURCLOSETK;}</p>
         *
         * @param t1 {@code CUROPENTK}.
         * @param l2 {@code MapEntries}.
         * @param t3 {@code OptComma}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor12(Token t1, List<MapEntry> l2, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : @PAROPENTK Expression COMMATK Expressions OptComma PARCLOSETK;}</p>
         *
         * @param t1 {@code PAROPENTK}.
         * @param e2 {@code Expression}.
         * @param l4 {@code Expressions}.
         * @param t5 {@code OptComma}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor13(Token t1, Expression e2, List<Expression> l4, Token t5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : PAROPENTK Expression PARCLOSETK;}</p>
         *
         * @param e2 {@code Expression}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor14(Expression e2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : ToolInvokeExpression;}</p>
         *
         * @param t1 {@code ToolInvokeExpression}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor15(ToolInvokeExpression t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ExpressionFactor : Name;}</p>
         *
         * @param t1 {@code Name}.
         * @return The parser call back hook result.
         */
        public Expression parseExpressionFactor16(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MapEntries : Expression @COLONTK Expression;}</p>
         *
         * @param e1 {@code Expression}.
         * @param t2 {@code COLONTK}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<MapEntry> parseMapEntries1(Expression e1, Token t2, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code MapEntries : MapEntries COMMATK Expression @COLONTK Expression;}</p>
         *
         * @param l1 {@code MapEntries}.
         * @param e3 {@code Expression}.
         * @param t4 {@code COLONTK}.
         * @param e5 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<MapEntry> parseMapEntries2(List<MapEntry> l1, Expression e3, Token t4, Expression e5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolInvokeExpression : ToolRef @PAROPENTK ToolArgs OptComma PARCLOSETK;}</p>
         *
         * @param t1 {@code ToolRef}.
         * @param t2 {@code PAROPENTK}.
         * @param l3 {@code ToolArgs}.
         * @param t4 {@code OptComma}.
         * @return The parser call back hook result.
         */
        public ToolInvokeExpression parseToolInvokeExpression1(ToolRef t1, Token t2, List<ToolArgument> l3, Token t4);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolInvokeExpression : ToolRef @PAROPENTK PARCLOSETK;}</p>
         *
         * @param t1 {@code ToolRef}.
         * @param t2 {@code PAROPENTK}.
         * @return The parser call back hook result.
         */
        public ToolInvokeExpression parseToolInvokeExpression2(ToolRef t1, Token t2);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolRef : BuiltInTool;}</p>
         *
         * @param t1 {@code BuiltInTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseToolRef1(ToolRef t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolRef : Name;}</p>
         *
         * @param t1 {@code Name}.
         * @return The parser call back hook result.
         */
        public ToolRef parseToolRef2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInTool : BuiltInIoTool;}</p>
         *
         * @param t1 {@code BuiltInIoTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseBuiltInTool1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInTool : BuiltInGenericTool;}</p>
         *
         * @param t1 {@code BuiltInGenericTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseBuiltInTool2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInTool : BuiltInPathTool;}</p>
         *
         * @param t1 {@code BuiltInPathTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseBuiltInTool3(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInTool : BuiltInFileTool;}</p>
         *
         * @param t1 {@code BuiltInFileTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseBuiltInTool4(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code BuiltInTool : BuiltInDataTool;}</p>
         *
         * @param t1 {@code BuiltInDataTool}.
         * @return The parser call back hook result.
         */
        public ToolRef parseBuiltInTool5(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolArgs : Expression;}</p>
         *
         * @param e1 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<ToolArgument> parseToolArgs1(Expression e1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolArgs : @IDENTIFIERTK EQTK Expression;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<ToolArgument> parseToolArgs2(Token t1, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolArgs : ToolArgs COMMATK Expression;}</p>
         *
         * @param l1 {@code ToolArgs}.
         * @param e3 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<ToolArgument> parseToolArgs3(List<ToolArgument> l1, Expression e3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code ToolArgs : ToolArgs COMMATK @IDENTIFIERTK EQTK Expression;}</p>
         *
         * @param l1 {@code ToolArgs}.
         * @param t3 {@code IDENTIFIERTK}.
         * @param e5 {@code Expression}.
         * @return The parser call back hook result.
         */
        public List<ToolArgument> parseToolArgs4(List<ToolArgument> l1, Token t3, Expression e5);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Names : Name;}</p>
         *
         * @param t1 {@code Name}.
         * @return The parser call back hook result.
         */
        public List<Token> parseNames1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Names : Names COMMATK Name;}</p>
         *
         * @param l1 {@code Names}.
         * @param t3 {@code Name}.
         * @return The parser call back hook result.
         */
        public List<Token> parseNames2(List<Token> l1, Token t3);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Name : @IDENTIFIERTK;}</p>
         *
         * @param t1 {@code IDENTIFIERTK}.
         * @return The parser call back hook result.
         */
        public Token parseName1(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code Name : @RELATIVENAMETK;}</p>
         *
         * @param t1 {@code RELATIVENAMETK}.
         * @return The parser call back hook result.
         */
        public Token parseName2(Token t1);

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptComma : ;}</p>
         *
         * @return The parser call back hook result.
         */
        public Token parseOptComma1();

        /**
         * Parser call back hook for rule/production:
         *
         * <p>{@code OptComma : @COMMATK;}</p>
         *
         * @param t1 {@code COMMATK}.
         * @return The parser call back hook result.
         */
        public Token parseOptComma2(Token t1);
    }
}
